/*
 * range.h - define data/buffer range and related constats
 *
 *      by k-chinen@is.aist-nara.ac.jp, 1997
 *
 *  $Id$
 *
 */

#ifndef __RANGE_H__
#define __RANGE_H__ /* block for forever(or nest) loop */


/***
 ***
 ***/

#define _KB_CONST_  (1024L)
#define _MB_CONST_  (1024L*1024L)
#define _GB_CONST_  (1024L*1024L*1024L)

#define TOKB(x) ((x)/_KB_CONST_)
#define TOMB(x) ((x)/_MB_CONST_)
#define TOGB(x) ((x)/_GB_CONST_)

#define KB(x)   (x*_KB_CONST_)
#define MB(x)   (x*_MB_CONST_)
#define GB(x)   (x*_GB_CONST_)

#define K(x)    (x*1024)
#define M(x)    (x*1024*1024)
#define G(x)    (x*1024*1024*1024)

#define dK(x)   (x/1024)
#define mK(x)   (x%1024)
#define dM(x)   (x/(1024*1024))
#define mM(x)   (x%(1024*1024))
#define dG(x)   (x/(1024*1024*1024))
#define mG(x)   (x%(1024*1024*1024))

#define fdK(x)  (((double)(x))/(1024.0))
#define fdM(x)  (((double)(x))/(1024.0*1024.0))
#define fdG(x)  (((double)(x))/(1024.0*1024.0*1024.0))

#define _HOUR_CONST_    (3600)
#define _DAY_CONST_     (3600*24)

#define HOUR(x)     (x*_HOUR_CONST_)
#define DAY(x)      (x*_DAY_CONST_)



#ifndef MAX
#define MAX(a,b) (((a)>(b))?(a):(b))
#endif
#ifndef MIN
#define MIN(a,b) (((a)<(b))?(a):(b))
#endif

/*
#ifndef BCEIL
#define BCEIL(x,r)  (((x)+(r)-1)/(r))
#endif
#ifndef BFLOOR
#define BFLOOR(x,r) ((x)/(r))
#endif
*/

#define NBCEIL(x, blen)  (( (x) + (blen) -1)/ (blen) )
#define BCEIL(x, blen)   (NBCEIL( (x), (blen) )* (blen) )



        /* x(sec,usec) - y(sec,usec) */
#define KOTETU_SUB_MSEC(x,y) \
        ( (x.tv_sec  - y.tv_sec )*1000 + (x.tv_usec - y.tv_usec)/1000 )
#define KOTETU_SUB_USEC(x,y) \
        ( (x.tv_sec  - y.tv_sec )*1000000 + (x.tv_usec - y.tv_usec))
#define KOTETU_SUB_TIME(x,y)    KOTETU_SUB_MSEC(x,y)

        /* x(sec,usec) += z(msec) */
#define KOTETU_ADD_MSEC(x,y) {\
        x.tv_usec += (y%1000)*1000; \
        x.tv_sec  += y/1000+(x.tv_usec/1000000); \
        x.tv_usec = x.tv_usec%1000000; \
        }

        /* x(sec,usec) += z(usec) */
#define KOTETU_ADD_USEC(x,y) {\
        x.tv_sec  += y/1000000; \
        x.tv_usec += y%1000000+(x.tv_usec/1000000); \
        x.tv_usec = x.tv_usec%1000000; \
        }


/***
 *** strings
 ***/

#ifndef STRING_SIZE
#define STRING_SIZE     512
#endif
#ifndef STRING_BLEN
#define STRING_BLEN     (32)
#endif

#ifndef L_URL
#define L_URL           (KB(2))
#endif
#ifndef L_PATH
#define L_PATH          (256)
#endif
#ifndef L_HOST
#define L_HOST          (64)
#endif

/***
 *** buffer (long string)
 ***/

#ifndef L_BUF
#define L_BUF           (KB(8))
#endif
#ifndef L_REQBUF
#define L_REQBUF        (KB(4))
#endif


#endif /* __RANGE_H_ */


