/*
 * KOTETU: the prefetching WWW proxy server
 *
 * proxy_main.c : main body for proxy server.
 *
 *      by k-chinen@is.aist-nara.ac.jp, 1999-2001.
 *
 * $Id$
 */

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

/* public headers */

#include <stdio.h>
#include <stdlib.h>
#include <sched.h>
#include <pthread.h>
#ifdef HAVE_UNISTD_H
#include <unistd.h>
#endif
#ifdef HAVE_STROPTS_H
#include <stropts.h>
#endif
#ifdef HAVE_POLL_H
#include <poll.h>
#include <sys/poll.h>
#endif
#ifdef HAVE_SELECT_H
#include <sys/select.h>
#endif
#ifdef __STDC__
#include <stdarg.h>
#else
#include <varargs.h>
#endif
#ifdef HAVE_ALLOCA_H
#include <alloca.h>
#endif
#include <strings.h>
#include <limits.h>
#include <sys/types.h>
#include <time.h>
#include <sys/time.h>
#include <sys/wait.h>
#include <sys/resource.h>
#include <signal.h>
#include <setjmp.h>
#include <fcntl.h>
#include <netinet/in.h>
#include <netdb.h>
#include <sys/socket.h>
#include <sys/file.h>
#include <sys/ioctl.h>
#include <sys/uio.h>
#include <assert.h>
#include <errno.h>

/* private headers */

#include "range.h"
#include "msg.h"
#include "trace.h"
#include "mem.h"
#include "mlist.h"

#include "hname.h"
#include "accept.h"

#include "socket.h"
#include "sigs.h"
#include "sim_stat.h"
#include "sim_hist.h"
#include "misc.h"
#include "http.h"
#include "ocache.h"
#include "sess.h"
#include "squeue.h"
#include "parse.h"
#include "mlist.h"
#include "reason.h"

#include "proxy_global.h"


TRACE_REGIST_NIC("main");

#ifndef DEFAULT_CONFIG_ENVNAME
#define DEFAULT_CONFIG_ENVNAME "KOTETU"
#endif

#ifndef DEFAULT_CONFIGFILE
#define DEFAULT_CONFIGFILE      "/etc/kotetu.conf"
#endif
#ifndef DEFAULT_LOGFILE
#define DEFAULT_LOGFILE         "kotetu.log"
#endif

#ifndef MONITOR_INTERVAL
#define MONITOR_INTERVAL    (600)
#endif


#ifndef MIN_FRAG_LEN
/*
#define MIN_FRAG_LEN        (1460)
*/
#define MIN_FRAG_LEN        (0)
#endif



pthread_mutex_t stat_lock = PTHREAD_MUTEX_INITIALIZER;
time_t boot_date = 0;
time_t keep_offset = 60;
time_t service_start_date = 0;
int    session_queue_report_flag = 0;

volatile long long request_sirial_count = 0;
volatile int receive_request_count = 0;
volatile int process_request_count = 0;
volatile int issue_prefetch_count  = 0;
volatile int report_request_count  = 0;
volatile int reject_request_count  = 0;
volatile int ignore_request_count  = 0;

volatile long long swapout_req_serial = 0;

volatile int send_reply_count    = 0;
volatile int hit_reply_count     = 0;
volatile int miss_reply_count    = 0;
volatile int error_reply_count   = 0;

volatile int friend_count       = 0;

volatile int hash_colision      = 0;
volatile int expire_count       = 0;

volatile int skip_cache_count   = 0;
volatile int alloc_tmp_buf_count = 0;
volatile int alloc_sess_buf_count = 0;


#ifndef THRU_FACTOR
#define THRU_FACTOR  (-1)
#endif

volatile int thru_factor = THRU_FACTOR;
int require_thru_factor;


/* ocache_mem.c */
extern volatile int compaction_count;
extern volatile int msweeper_count;

extern sim_stat_rec msweep_time;
extern sim_stat_rec msweep_time_short;
extern sim_stat_rec compaction_time;

extern sim_stat_rec reapar_call_reason;

/* ocache_disk.c */
extern volatile int dsweeper_seq;
extern volatile int dsweeper_count;
extern volatile int dsweeper_phase;
extern volatile int dsweeper_pos;

extern volatile int swapin_count;
extern volatile int swapout_count;
extern volatile int swapin_success;
extern volatile int swapout_success;

#if 0
extern volatile int swapout_token;
extern volatile int swapout_token_init;
extern volatile int swapout_token_interval;
#endif

extern long long swap_count;
extern long long swap_size;

extern sim_stat_rec swapin_time;
extern sim_stat_rec swapout_time;
extern sim_stat_rec swapin_fail_reason;
extern sim_stat_rec swapout_fail_reason;
extern sim_hist_rec swapin_hist;
extern sim_hist_rec swapout_hist;

extern sim_stat_rec swo_t01, swo_t12, swo_t23, swo_t34, swo_t45;

extern volatile int checkdir_dir_count;
extern volatile int checkdir_file_read_count;
extern volatile int checkdir_file_handle_count;
extern volatile int checkdir_file_left_count;
extern volatile int checkdir_file_delete_count;
extern volatile int checkdir_file_erase_count;

extern sim_stat_rec checkdir_time;
extern sim_stat_rec checkdir_time_short;

int read_reply_total   = 0;
int read_reply_success = 0;
int read_reply_fail    = 0;

int cache_newover_count = 0;
int cache_newfree_count = 0;
int cache_newmin_count = 0;



volatile long long intra_incoming = (off_t)0; /* requests from clients */
volatile long long extra_outgoing = (off_t)0; /* requests to servers */
volatile long long extra_incoming = (off_t)0; /* replys from servers */
volatile long long intra_outgoing = (off_t)0; /* replys to clients */


sim_stat_rec method_stat;
long method_stat_count[M_XDUMMY];

sim_stat_rec rcode_stat;
long    rcode_stat_count[1000];

sim_stat_rec ret_time;
long    ret_time_count[K(7)];

sim_stat_rec ret_time_short;
long    ret_time_short_count[K(32)];

sim_stat_rec len_perread_stat;
static long server_buffer_stat_count[K(32)];

sim_stat_rec object_size_stat;
static long object_size_stat_count[K(1)];

sim_stat_rec url_first_hash_stat;
static long url_first_hash_stat_count[K(2)];
sim_stat_rec url_second_hash_stat;
static long url_second_hash_stat_count[K(2)];
sim_stat_rec url_third_hash_stat;
static long url_third_hash_stat_count[K(10)];
sim_stat_rec url_fourth_hash_stat;
static long url_fourth_hash_stat_count[K(10)];

sim_stat_rec req_field_type_stat;
static long req_field_type_stat_count[K(10)];

sim_stat_rec object_alloc_stat;
static long  object_alloc_stat_count[K(10)];

sim_stat_rec reaper_call_reason;
static long  reaper_call_reason_count[K(1)];

/* host name resolving */
sim_stat_rec hname_rtime_stat;
static long  hname_rtime_stat_count[K(10)];

volatile long hname_hit_count = 0;
volatile long hname_miss_count = 0;

sim_stat_rec hname_rtime_short;
long    hname_rtime_short_count[K(32)];
sim_stat_rec hname_rtime;
long    hname_rtime_count[K(32)];



pthread_t th_listener;
pthread_mutex_t accept_lock = PTHREAD_MUTEX_INITIALIZER;

volatile int swfactor=1;

pthread_t th_handlers[N_HANDLER_MAX];
pthread_t th_dsweepers[N_HANDLER_MAX];
pthread_t th_swapper[N_SWAPPER_MAX];
pthread_t th_monitor;
pthread_t th_signalhandler;

time_t handler_beacon[N_HANDLER_MAX];
int handler_focus[N_HANDLER_MAX];
volatile int handler_phase[N_HANDLER_MAX];

extern int swapper_focus_bk[N_SWAPPER_MAX];
extern int swapper_focus_oid[N_SWAPPER_MAX];
extern int swapper_phase[N_SWAPPER_MAX];

int n_listener=0, n_handlers=0, n_dsweepers=0, n_swappers=0, n_monitors=0;

sigset_t handler_sig_mask;

int require_nsess_total;

int think_queue_length;
sess_queue_t X_think_queue;
sess_queue_t *think_queue;

sess_queue_t X_wait_queue;
sess_queue_t *wait_queue;

sess_queue_t X_msweep_queue;
sess_queue_t *msweep_queue;

sess_queue_t X_swap_queue[N_SWAPPER_MAX];
sess_queue_t *swap_queue[N_SWAPPER_MAX];
volatile long long swap_op_th_count[N_SWAPPER_MAX][6];
volatile long long swap_op_repush_th_count[N_SWAPPER_MAX];
volatile long long swap_op_release_th_count[N_SWAPPER_MAX];
volatile long long swap_op_retry_th_count[N_SWAPPER_MAX];
volatile long long swap_op_all_count[6];

#define SWO_HISTLEN     (32)
#define SWI_HISTLEN     (SWO_HISTLEN)

sim_hist_rec swapper_swo_hist[N_SWAPPER_MAX];
static long swapper_swo_hist_area[N_SWAPPER_MAX][SWO_HISTLEN];
sim_hist_rec swapper_swi_hist[N_SWAPPER_MAX];
static long swapper_swi_hist_area[N_SWAPPER_MAX][SWI_HISTLEN];

extern volatile int fs_swapin_count[];
extern volatile int fs_swapout_count[];

extern sim_hist_rec fs_swapin_hist[];
extern sim_hist_rec fs_swapout_hist[];


extern int reaper(int, bucket_t*, int, int, int, int);
extern volatile int reaper_requested, reaper_called;


#ifdef CHECK_QUEUE

#define push_sess(q,c) \
    RawTrace("push sess# %d, %p to %p : %d/%d : %s %5d\n",\
        c->sid, c, q, q->count, q->cmax, __FILE__ , __LINE__), sq_push(q,c)
#define pull_sess(q) \
    RawTrace("pull from %p : %s %5d\n", q, __FILE__ , __LINE__), sq_pull(q)

#else
#define push_sess(q,c) sq_push(q,c)
#define pull_sess(q) sq_pull(q)
#endif
#define pull_sess_nonblock(q) sq_pull_nonblock(q)



sim_hist_rec comp_hist;
static long comp_hist_area[128];
sim_hist_rec expire_hist;
static long expire_hist_area[128];



int dlack_limit;

extern sim_hist_rec fratio_hist;

/*
 * externals
 */

extern int nhot;
extern int nfriend;



int InitSession(int);

char* skcache_label_long(void *pp);
char* skcache_label4_ref(void *pp);



/* automatic */
pthread_mutex_t config_lock = PTHREAD_MUTEX_INITIALIZER;

char config_filename[L_PATH];
char *log_filename;
int trace_flag;
int monitor_flag;
int prefetch_flag=1;
int service_portno;
int require_n_handler;
int require_n_dsweeper;
int require_n_msweeper;
int require_nsess_handler;
off_t require_total_memory_size;

int require_nbucket;
int require_level_bucket_skiplist;
int require_nentry_per_bucket;
int require_frag_size;
int require_ratio_frag_length;

int num_prefetch_referedpages;
int num_prefetch_includedobjs;


int nfrag_obj       = HARD_NFRAG_OBJ;
int nfrag_nwrite    = HARD_NFRAG_NWRITE;
int nfrag_nread     = HARD_NFRAG_NREAD;
int nfrag_dwrite    = HARD_NFRAG_DWRITE;
int nfrag_dread     = HARD_NFRAG_DREAD;

int nindex_dread    = HARD_NINDEX_DREAD;
int nindex_bdread   = HARD_NINDEX_BDREAD;
int nindex_bdwrite  = HARD_NINDEX_BDWRITE;

int require_nfrag_obj;
int require_nfrag_nwrite;
int require_nfrag_nread;
int require_nfrag_dwrite;
int require_nfrag_dread;

int require_nindex_dread;
int require_nindex_bdread;
int require_nindex_bdwrite;

char *localdomain_padding;
char *report_hook_hostname;

/* static */
pid_t    wcol_pid;
char     *progname;


extern off_t sess_memory_size;
off_t cache_memory_size;


extern int sq_check_count();
extern int sk_emptyentity_check(bucket_t* bk);


#if 1
/* nanosleep is useful, because it is MT-safe and supports very short time.
 * however, nsec is too short for network I/O.
 * then, msleep is made.
 */
/*
inline
*/
static
int
msleep(int x)
{
    struct timespec w;
    long long tw;

    /* convert msec to nsec */
    tw = x * 1000000;
    w.tv_nsec = tw % 1000000000;
    w.tv_sec =  tw / 1000000000;

    nanosleep(&w, NULL);

    return 0;
}
#endif



/***
 *** screed flag access routines
 *** they are useful in resource selection
 *** resouces is locakble but its lock takes several waiting
 *** if you can avoid waiting with this routines
 ***
 *** following functions expect several conditions.
 ***    - flags are screend with mutex 
 ***    - flags are setted -1 in initial state
 ***    - flag value is zero or positive
 ***/
/* 
 * return
 *      0   win
 *      1   lose
 *      -1  error
 */

int
hold_screend_flag(pthread_mutex_t *lockgate, int *locktarget, int value)
{
    int ret;

#if 1
    if(value<0) {
        Error("hold_screend_flag: specified value is negative %d", value);
        return -1;
    }
#endif
    ret = 0;
    MUTEX_LOCK(lockgate);
    if(*locktarget==-1) {
        *locktarget = value;
        ret = 0;
    }
    else {
        ret = 1;
    }
    MUTEX_UNLOCK(lockgate);
    
    return ret;
}

int
release_screend_flag(pthread_mutex_t *lockgate, int *locktarget, int value)
{
    int ret;

#if 1
    if(value<0) {
        Error("release_screend_flag: specified value is negative %d", value);
        return -1;
    }
#endif
    ret = 0;
    MUTEX_LOCK(lockgate);
    if(*locktarget==value) {
        *locktarget = -1;
        ret = 0;
    }
    else {
        ret = 1;
    }
    MUTEX_UNLOCK(lockgate);

    return ret;
}



int
check_sq(char *msg)
{
    Trace("# %s: sq_count(free) %d, diff %d, think Q %d/%d, wait Q %d/%d, msweep Q %d/%d\n",
        msg,
        sq_check_count(),
        sq_check_count()
            - (think_queue->count + wait_queue->count + msweep_queue->count),
        think_queue->count, think_queue->cmax,
        wait_queue->count, wait_queue->cmax,
        msweep_queue->count, msweep_queue->cmax);
    return 0;
}

int
CHKTIME(time_t thetime)
{
    int diff;
    diff = time(NULL) - thetime;
    if(diff<0) diff = -diff;
    if(diff>86400) {
        return 0;
    }
    else {
        return 1;
    }
}



/* free list of entry or frag is empty, when the number of use is smaller
 * than high water.
 */
int
check_bkinfo()
{
    int i;
    bucket_t *b;
    int r, c;

    c = 0;
    for(i=0;i<radix_h1;i++) {
        b = &skcache_bucket_base[i];
        r = 0;
        if(b->entry_freelist==NULL && b->entry_use <  b->entry_hwater) {
            r++;
        }
#if 0
        if(b->frag_freelist==NULL && b->own_frag <  b->frag_hwater) {
            r++;
        }
#endif

        if(r) {
#if 0
          Trace(" be %3d: entry %4d/%d/%d %08x, frag %4d/%d/%d %08x\n",
            i,
            b->entry_use, b->entry_hwater, b->entry_all, b->entry_freelist,
            b->own_frag, b->frag_hwater, b->frag_all, b->frag_freelist);
#endif
          Trace(" bk# %d, entry u %4d f %d hw %d all %d, %08x, frag %4d\n",
            i,
            b->entry_use, b->entry_free, b->entry_hwater, b->entry_all,
            b->entry_freelist,
            b->own_frag);

            c++;
        }
    }

    if(c==0)
        return 1;
    else
        return 0;
}

pthread_mutex_t wait_check_lock;

inline int check_timeout(sess_t *sessp, time_t now);

int
check_friend_lock(sess_t *this)
{
    sess_t *cu;
    int n;
    int i;
    int chk;
    int w, d;
    time_t now;
    int idle;

    if(this==NULL || this->cache_entry==NULL) {
        return -1;
    }
Trace("check_friend_lock:\n");
Trace("  target sess# %d, oid# %d\n",
    this->sid, ((skcache_entry_t*)this->cache_entry)->oid);


    MUTEX_LOCK(&wait_check_lock);

    now = time(NULL);

    n = wait_queue->count*2; /* XXX */
    i = 0;
    w = 0;
    d = 0;
    while(i<n) {
        cu = pull_sess_nonblock(wait_queue);
        if(cu==NULL) {
            break;
        }
        idle = now - cu->last_action;

#if 0
  if(cu->cache_entry) {
    Trace("  %3d: sess# %d, %p %s : entry %p, oid# %d, ref %d, owner %p, idle %d\n",
    i,
    cu->sid, cu, MSG_STATE_[cu->state],
    cu->cache_entry,
    ((skcache_entry_t*)cu->cache_entry)->oid,
    ((skcache_entry_t*)cu->cache_entry)->ref,
    ((skcache_entry_t*)cu->cache_entry)->owner, idle
    );
  }
#endif

        if(check_timeout(cu, now)) {
            cu->state = STATE_QUERY_ADDR;
            cu->cachable = SESS_UNCACHABLE;

            chk = push_sess(think_queue, cu);
            if(chk) {
Trace("timeout waited friend sess# %d from wait Q, fail to push think Q\n",
                    cu->sid);
                d++;

                DoSendMessage(cu);
                DoCloseSess(cu);
                DoReleaseSess(cu);
                cu = NULL;

            }
            else {
Trace("timeout waited friend sess# %d from wait Q, push think Q\n",
                    cu->sid);
                w++;
            }
        }
        else
        if(cu->cache_entry &&
            ((skcache_entry_t*)cu->cache_entry)->oid ==
                ((skcache_entry_t*)this->cache_entry)->oid) {

            /* re-push to think Q */
            chk = push_sess(think_queue, cu);
            if(chk) {
Trace("pick up waited friend sess# %d from wait Q, fail to push think Q\n",
                    cu->sid);
                d++;

                DoSendMessage(cu);
                DoCloseSess(cu);
                DoReleaseSess(cu);
                cu = NULL;

            }
            else {
Trace("pick up waited friend sess# %d from wait Q, push think Q bk# %d,\n",
                    cu->sid, cu->fhash);
                w++;
            }
            cu = NULL;
        }
        else {
#if 0
            chk = push_sess(wait_queue, cu);
#endif
            chk = sq_timedpush(wait_queue, cu, 5000);
            if(chk) {
                DoSendMessage(cu);
                DoCloseSess(cu);
                DoReleaseSess(cu);

            }
            cu = NULL;
        }
        i++;
    }

    MUTEX_UNLOCK(&wait_check_lock);

    Trace("check_friend_lock: sess# %d, oid# %d, n %d, w %d, d %d\n",
        this->sid, ((skcache_entry_t*)this->cache_entry)->oid,
        n, w, d);

    return w;
}

/*
 * release_buf - release allocated area
 *
 */
int
release_buf(sess_t *this, int lock_required)
{
    int ret;
    int chk;
    bucket_t *bk;
    skcache_entry_t *centry;

    ret = 0;
    if(this==NULL) {
        Error("release_buf: given session is empty");
        ret = -1;
        goto out;
    }
#if 0
    Trace("release sess# %d, centry %p, lock? %d\n",
        this->sid, this->cache_entry, lock_required);
#endif

    centry = this->cache_entry;
    if(centry==NULL) {
        goto out;
    }

    if(lock_required) {
        bk = &skcache_bucket_base[this->fhash];
        LOCK_BK(bk);
#if 0
    chk = sk_entity_check(bk, __FILE__, __LINE__);
#endif
    }
    else {
        bk = NULL;
    }

#if 0
    if(this->clen+this->hlen != centry->totallength) {
        Error("release_buf: oid# %d, totallength %lld; hlen %lld, clen %lld",
            centry->oid, (long long)centry->totallength,
            (long long)this->hlen, (long long)this->clen);
        centry->cracked++;
    }
#endif

    centry->ref--;
    if(centry->owner==this) {
        centry->owner = NULL;
    }
    if(centry->ref>0) {
#ifdef USE_WQUEUE
        check_friend_lock(this);
#endif
    }

    /* forget entry */
    this->cache_entry = NULL;


    if(bk) {
#if 0
    chk = sk_entity_check(bk, __FILE__, __LINE__);
#endif
        UNLOCK_BK(bk);
        bk = NULL;
    }
out:
    return ret;
}


#define PARENT_MAX  (16)

int parent_num = 0;
struct sockaddr_in parent_addr[PARENT_MAX];
int parent_port[PARENT_MAX];

int
ShowParent()
{
    int i;
    char *xaddr;
    char tmp[32];

    if(parent_num<=0) {
        Trace("no parent\n");
        return 0;
    }

    Trace("This proxy has %d parent\n", parent_num);
    for(i=0;i<parent_num;i++) {
        sprintf(tmp, "parent# %d", i);
        xaddr = (char*)&parent_addr[i];
        show_addr(tmp,  xaddr);
    }

    return 0;
}

int
AppendParent(char *xparent_name)
{
    int chk;
    struct sockaddr_in xparent_addr;
    int dummy_port = 80;
    char *taddr;
    struct hostent *hp;
    int ret;

    Trace("AppendParent: parent '%s'\n", xparent_name);

    hp = gethostbyname(xparent_name);
    if(hp==NULL) {
        Error("AppendParent: fail gethostbyname()");
        return -1;
    }
    
    xparent_addr.sin_family = AF_INET;
    memcpy(&(xparent_addr.sin_addr.s_addr), hp->h_addr_list[0], hp->h_length);

    taddr = (char*)&xparent_addr;
    show_addr("  temporary addr", taddr);

    MUTEX_LOCK(&config_lock);
    
    ret = 0;
    
    if(parent_num<PARENT_MAX) {
        parent_addr[parent_num] = xparent_addr;
        parent_port[parent_num] = dummy_port;
        parent_num++;
    }
    else {
        Error("AppendParent: too many parent");
        ShowParent();
        ret = -1;
    }
    
    MUTEX_UNLOCK(&config_lock);

    return ret;
}



int
DoAccept(int listen_fd)
{
    struct sockaddr_in from;
    int len;
    int tmpfd;


    len = sizeof(from);

    MUTEX_LOCK(&accept_lock);
    tmpfd = accept(listen_fd, (struct sockaddr*)&from, &len);
    MUTEX_UNLOCK(&accept_lock);

    if(tmpfd<0) {
#if 1
        Error("accept error (%d)", errno);
#endif
        tmpfd = -1;
        goto done;
    }

    MUTEX_LOCK(&stat_lock);
    receive_request_count++;
    request_sirial_count++;
    MUTEX_UNLOCK(&stat_lock);

done:

    return tmpfd;
}


int
DoReadReq(int dnum, sess_t *this)
{
    int nread;
    int c;
    int method;
    char url[L_URL];
    char version[L_URL];
    char hostbuf[L_HOST];
    void *cpos;
    int chk;
    int err;
    int ims;
    int xcachable, xreload;
    char parent[L_HOST];

#if 0
    Trace("DoReadReq : sess# %d, cfd %d\n", this->sid, this->cfd);
#endif
#if 0
dump_stringsegment("before", this->reqbuf, this->reqlen);
#endif
#if 0
    if(this->cread>0) {
        Trace("DoReadReq: sess# %d, read %ld and re-read pos %ld\n",
            this->sid, (long)this->cread, (long)this->reqlen);
    }
#endif

try_read:
    nread = read(this->cfd,
                &this->reqbuf[this->reqlen], L_REQBUF-this->reqlen);
    err = errno;
    if(nread<0) {
        if(err==EINTR) {
            goto try_read;
        }
        Error("sess# %d, read() fail (%d)", this->sid, err);
        DoHalfClientCloseSess(this);

        this->reason = R_FAIL_CLIENT_READ;
        this->state = STATE_MESSAGE;

        MUTEX_LOCK(&stat_lock);
        ignore_request_count++;
        MUTEX_UNLOCK(&stat_lock);

        return -1;
    }
    if(nread==0) {
        Error("DoReadReq: sess# %d, read() empty, fd# %d",
            this->sid, this->cfd);
#if 0
        Error("sess# %d, th %x, fd# %d, empty client request (%d)",
            this->sid, pthread_self(), this->cfd, err);
#endif
        DoHalfClientCloseSess(this);

        this->reason = R_FAIL_CLIENT_READ_EMPTY;
        this->state = STATE_MESSAGE;

        MUTEX_LOCK(&stat_lock);
        ignore_request_count++;
        MUTEX_UNLOCK(&stat_lock);

        return -1;
    }

    this->reqlen += nread;
    this->cread += nread;
    this->loc[0] = '\0';
#if 0
    this->last_action = time(NULL);
#endif
#if 0
dump_stringsegment("o.req.", this->reqbuf, this->reqlen);
#endif

    c = HTTP_find_header_term(this->reqbuf, this->reqlen);
#if 0
Trace("DoReadReq: sess %p, read %d, header term %d\n", this->sid, nread, c);
#endif

    if(c>0) {
#if 1
        dump_stringsegment("request", this->reqbuf, this->reqlen);
#endif
#if 0
 Trace(" 1 sfd# %d, cfd# %d\n", this->sfd, this->cfd);
#endif

        hostbuf[0] = '\0';
        version[0] = '\0';
        ims = -1;
        xcachable = this->cachable;
        xreload = this->reload;

        c = HTTP_parse_request_header(this->reqbuf,
                &method, url, version,
                hostbuf,
                &ims, &xcachable, &xreload);

#ifdef DONT_CACHE
        this->cachable = SESS_UNCACHABLE;
#endif
        if(c) {
            /* fail */
            Error("ignore request from fd #%d", this->cfd);
#if 1
            dump_stringsegment("request", this->reqbuf, this->reqlen);
#endif

            if(c==-2) {
                this->reason = R_TOOLONG_URL;
            }
            else {
                this->reason = R_IGNORE_URL;
            }

            this->state = STATE_MESSAGE;
            return -1;
        }

        /* uncachable is strong than cachable */
        if(xcachable==SESS_UNCACHABLE
            && this->cachable == SESS_CACHABLE) {
            this->cachable = SESS_UNCACHABLE;
        }
        /* reload is strong than noreload */
        if(xreload==SESS_RELOAD
            && this->reload == SESS_NORELOAD) {
            this->reload = SESS_RELOAD;
        }


        if(url[0]=='/') {
            this->abs_or_rel = REL_PATH;    /* rel */
        }
        else {
            this->abs_or_rel = ABS_PATH;    /* abs */
        }

        chk = -1;
        if(version[0]) {
            chk =
             HTTP_parse_version(version, &this->cver_major, &this->cver_minor);
        }
        if(chk<0) {
            this->cver_major = 0;
            this->cver_minor = 9;
        }
#if 0
        Trace("sess# %d, chk %d, client HTTP ver %d.%d\n",
            this->sid, chk, this->cver_major, this->cver_minor);
#endif
#if 0
#ifdef TRACE_SESS
        Trace("sess# %d, <client> method <%s>,URL '%s' version <%s>\n\
    hash %d:%d:%d:%d\n",
            this->sid, MSG_M_[method], url, version,
            this->fhash, this->shash, this->thash, this->ffhash
            );
#endif
#endif

        this->method = method;
        sim_stat_add_value(&method_stat, method);

        /* if the proxy received absolute URL (URI),
         * the program has no problem.
         * otherwise, the proxy must make absoluted URL with value of
         * Host field.
         */
#if 1
        /* absolute */
        if(this->abs_or_rel==ABS_PATH) {
            strcpy(this->loc, url);
        }
        else
        /* relative */
        if(this->abs_or_rel==REL_PATH) {
            if(hostbuf[0]) {
                strcpy(this->loc, "http://");
                strcat(this->loc, hostbuf);
                if(url[0]!='/') {
                    strcat(this->loc, "/");
                }
                strcat(this->loc, url);
            }
            else {
                Error("not found Host field, but relative path '%s'",
                    url);
            }
        }
        else {
            Error("no absoluted and no relative path '%s'\n", url);
        }   
#endif


#if 1
    Trace("sess# %d, url '%s'(%d) host '%s' parent %d\n  => loc '%s'\n",
        this->sid, url, this->abs_or_rel, hostbuf, parent_num, this->loc);
#endif

        calc_hash(this->loc,
            &this->fhash, &this->shash, &this->thash, &this->ffhash);

#ifdef TRACE_SESS
        Trace("sess# %d, <client> method <%s>,URL '%s' version <%s>\n\
    hash %d:%d:%d:%d\n",
            this->sid, MSG_M_[method], url, version,
            this->fhash, this->shash, this->thash, this->ffhash
            );
#endif
#if 0
Trace("rreq: %03d:%03d:%03d:%03d %s\n",
    this->fhash, this->shash, this->thash, this->ffhash, this->loc);
#endif


/*****
 ***** check cachable or not
 *****/

        if(istempURL(url)) {
            this->cachable  = SESS_UNCACHABLE;
            this->reload    = SESS_RELOAD;
        }

        if(ims>0) {
            this->ims = ims;
        }

#if 0
 Trace(" 3 sfd# %d, cfd# %d\n", this->sfd, this->cfd);
#endif

done_cachable_check:
#if 0
 Trace(" 4 sfd# %d, cfd# %d\n", this->sfd, this->cfd);
#endif

        this->state = STATE_THINK;
    }
    else {
        Error("DoReadReq: HTTP_find_header_term() returns %d", c);
#if 1
        dump_stringsegment("e.req", this->reqbuf, this->reqlen);
#endif
    }
#if 0
 Trace(" 5 sfd# %d, cfd# %d\n", this->sfd, this->cfd);
#endif

    return 0;
}


int
DoReadReqFirst(int dnum, sess_t *this)
{
    int ret;
    int b_state;


    b_state = this->state;
    this->state = STATE_RECV_REQ;
    ret = DoReadReq(dnum, this);
#if 1
    if(b_state == this->state) {
    Trace("DoReadReqFirst: sess# %d, %s -> %s , ret %d\n",
        this->sid, MSG_STATE_[b_state], MSG_STATE_[this->state], ret);
    }
#endif
#if 0
    Trace("DoReadReqFirst: sess# %d, %s -> %s , ret %d\n",
        this->sid, MSG_STATE_[b_state], MSG_STATE_[this->state], ret);
#endif

    return ret;
}


int
DoReadReqRest(int dnum, sess_t *this)
{
    int ret;
    int b_state;


    b_state = this->state;
    ret = DoReadReq(dnum, this);
#if 1
    if(b_state == this->state) {
    Trace("DoReadReqRest: sess# %d, %s -> %s , ret %d\n",
        this->sid, MSG_STATE_[b_state], MSG_STATE_[this->state], ret);
    }
#endif
#if 0
    Trace("DoReadReqRest: sess# %d, %s -> %s , ret %d\n",
        this->sid, MSG_STATE_[b_state], MSG_STATE_[this->state], ret);
#endif

    return ret;
}

int
old_DoSetReq(int dnum, sess_t *this, char *aurl)
{
    int nread;
    int c;
    int method;
    char url[L_URL], version[L_URL];
    char protocol[L_URL], portstr[L_URL];
    void *cpos;
    int istmp;


#if 0
    Trace("DoSetReq : cfd %d\n", this->cfd);
#endif

    this->reqlen = sprintf(this->reqbuf,
            "GET %s HTTP/1.0\r\nAccept: */*\r\n\r\n", aurl);

    this->loc[0] = '\0';

#if 0
    this->last_action = time(NULL);
#endif

    c = HTTP_parse_simple_request(this->reqbuf, &method, url, version);
    if(c) {
        Error("ignore request from fd #%d", this->cfd);
#if 1
        dump_stringsegment("request", this->reqbuf, this->reqlen);
#endif

        this->reason = R_IGNORE_URL;
        this->state = STATE_MESSAGE;
        return -1;
    }

#if 0
    Trace("receive request\n");
    Trace("  method  <%s>\n  URL     <%s>\n  version <%s>\n",
        method, url, version);
#endif

    this->method = method;

    strcpy(this->loc, url);
    calc_hash(this->loc,
        &this->fhash, &this->shash, &this->thash, &this->ffhash);

#if 0
Trace("sreq: %03d:%03d:%03d:%03d %s\n",
    this->fhash, this->shash, this->thash, this->ffhash, this->loc);
#endif


    this->state = STATE_THINK;

    return 0;
}


int
DoSetReq(int dnum, sess_t *this, char *xurl)
{
    int nread;
    int c;
    int method;
    char url[L_URL], version[L_URL];
    char protocol[L_URL], host[L_HOST], portstr[L_URL], path[L_PATH];
    void *cpos;
    int istmp;
    int chk;


#if 0
    Trace("DoSetReq : cfd %d\n", this->cfd);
#endif
    chk = ParseURL(xurl,
        protocol, host, portstr, path);

#if 0
    this->reqlen = sprintf(this->reqbuf,
            "GET %s HTTP/1.0\r\nAccept: */*\r\n\r\n", xurl);
#endif
    this->reqlen = sprintf(this->reqbuf,
            "GET %s HTTP/1.0\r\nHost: %s\r\nAccept: */*\r\n\r\n",
        path, host);

#if 0
    dump_stringsegment("setted request", this->reqbuf, this->reqlen);
#endif

    this->loc[0] = '\0';

#if 0
    this->last_action = time(NULL);
#endif

    c = HTTP_parse_simple_request(this->reqbuf, &method, url, version);
    if(c) {
        Error("ignore request from fd #%d", this->cfd);
#if 0
        dump_stringsegment("ignore request", this->reqbuf, this->reqlen);
#endif

        this->reason = R_IGNORE_URL;
        this->state = STATE_MESSAGE;
        return -1;
    }

#if 0
    Trace("receive request\n");
    Trace("  method  <%s>\n  URL     <%s>\n  version <%s>\n",
        method, url, version);
#endif

    this->method = method;

    strcpy(this->loc, url);
    calc_hash(this->loc,
        &this->fhash, &this->shash, &this->thash, &this->ffhash);

#if 0
Trace("sreq: %03d:%03d:%03d:%03d %s\n",
    this->fhash, this->shash, this->thash, this->ffhash, this->loc);
#endif


    this->state = STATE_THINK;

    return 0;
}

int
HostnameNormalize(char *src)
{
    register char *p;
    register int c;
    int d;

    p = src;
    c = 0;
    while(*p) {
        c++;
        if(*p=='.') {
            goto have_dot;
        }
        p++;
    }

not_have_dot:

    MUTEX_LOCK(&config_lock);
    if(c+strlen(localdomain_padding)+1<L_HOST) {
        strcat(p, localdomain_padding);
    }
    MUTEX_UNLOCK(&config_lock);

    return 0;

have_dot:
    return 0;
}


#if 0
int check_bkentry(bucket_t*,char*);
#endif


extern int skcache_mem_keep_min;
extern int skcache_mem_keep_cur;
extern int skcache_mem_keep_max;
extern int skcache_entry_keep_min;
extern int skcache_entry_keep_cur;
extern int skcache_entry_keep_max;


int
scan_frags_in_bucket(bucket_t *bk)
{
    skiplist_t *list;
    skiplist_cell_t *x;
    skcache_entry_t *ent;
    skcache_frag_t *cur;
    int in_entry;
    int in_bucket;

    list = &bk->cup;
    x = list->header->skip[0];

    in_bucket = 0;

    while(x!=list->term) {
        ent = (skcache_entry_t*) x->entity;
        cur = ent->m_recorded;

        in_entry = 0;

        while(cur) {
            if(cur->next==cur) {
                Error("bk#%d, entity %p, %d th frag %p is looped itself",
                    bk->bid, ent, in_entry, cur);
                ent->cracked = 1;
                break;
            }
            in_entry++;

            cur = cur->next;
        }
        in_bucket += in_entry;
        
        x = x->skip[0];
        if(x==NULL)
            break;
    }

#if 0
    Trace("bk# %d, has %d frag\n", bk->bid, in_bucket);
#endif

    return in_bucket;
}





int
DoThink(int dnum, sess_t *this)
{
    int ihave;
    int chk;
    char serverInURL[L_URL];
    char tmpURL[L_URL];
    char protocol[L_URL], portstr[L_URL];
    static char *HIT_msg    = "HIT ";
    static char *MISS_msg   = "MISS";
    char *msg;
    bucket_t *bk;
    skcache_entry_t *stored_pos;
    int check_already_have;
    skcache_entry_t *newone;

    int sig_pos;
    int dcount; 
    int dtime;

    struct timeval xbefore, xafter;
    int last_num;

    extern int sq_check_count();


    chk = ParseURL(this->loc, protocol,
            this->servername, portstr, this->serverpath);

    chk = HostnameNormalize(this->servername);
    if(portstr[0]=='\0') {
        this->serverport = 80;
    }
    else {
        this->serverport = atoi(portstr);
    }

#if 0
    Trace("DoThink: sess# %d, '%s' [%04d:%04d:%04d] '%s' %s %s\n",
        this->sid,
        this->loc, this->fhash, this->shash, this->thash, this->loc,
        this->cachable==SESS_CACHABLE ? "cachable" : "no-cachable",
        this->reload==SESS_RELOAD ? "reload" : "not-reload");
#endif
#if 0
    Trace("  sess# %d, server '%s', port %d\n",
        this->sid, this->servername, this->serverport);
#endif

    handler_phase[dnum] = 121;

    /* this system permit only GET and POST method */
    if( ! (this->method == M_GET
        || this->method == M_HEAD
        || this->method == M_POST ) ) {
        Trace("ignore method, sess %p (#%d)\n", this, this->sid);

        MUTEX_LOCK(&stat_lock);
        ignore_request_count++;
        MUTEX_UNLOCK(&stat_lock);

        handler_phase[dnum] = 129;

        this->reason = R_UNSUPPORT_METHOD;
        this->state = STATE_MESSAGE;
        return 0;
    }

    if(strncasecmp(this->loc, "http:", 5)!=0) {
        this->reason = R_UNSUPPORT_PROTOCOL;
        this->state = STATE_MESSAGE;
        return 0;
    }

#if 0
    if(strncasecmp(this->loc, "http:", 5)!=0) {
        if(this->loc[0]=='/' && this->servername[0]!='\0') {
            /* nothing*/
        }
        else
        if(strncasecmp(this->loc, "http:", 5)!=0) {
            this->reason = R_UNSUPPORT_PROTOCOL;
            this->state = STATE_MESSAGE;
            return 0;
        }
    }
#endif

    if(strcmp(this->servername, report_hook_hostname)==0)
    {
#if 0
        Trace("report request. sess# %d %p\n", this->sid, this);
#endif

        MUTEX_LOCK(&stat_lock);
        report_request_count++;
        MUTEX_UNLOCK(&stat_lock);

        handler_phase[dnum] = 128;

        this->state = STATE_REPORT;
        this->cachable = SESS_UNCACHABLE;
        this->reload   = SESS_RELOAD;
        return 0;
    }


    sim_stat_add_value(&url_first_hash_stat,  this->fhash);
    sim_stat_add_value(&url_second_hash_stat, this->shash);
    sim_stat_add_value(&url_third_hash_stat,  this->thash);
    sim_stat_add_value(&url_fourth_hash_stat,  this->ffhash);

    sim_stat_add_value(&req_field_type_stat, 
        this->reload + this->cachable + this->publish);

    switch(this->method) {
    /* GET method */
    case M_GET:
    case M_HEAD:

get_first:

        bk = &skcache_bucket_base[this->fhash];
        handler_phase[dnum] = 123;
        handler_focus[dnum] = bk->bid;

        LOCK_BK(bk);
        handler_phase[dnum] = 124;


try_get_newone:
    newone = skcache_pull_new_entry(bk);
    if(newone==NULL) {
        Error("think: sess# %d, no free entry element in bk# %d, %p <2b>",
            this->sid, this->fhash, bk);

        this->state  = STATE_MESSAGE;
        this->reason = R_MEMORY_OVERFLOW;

        goto get_last;
    }


    newone->oid = 0;
    newone->owner      = NULL;
    newone->m_recorded = NULL;
    newone->d_recorded = 0;
    newone->h1 = this->fhash;
    newone->h2 = this->shash;
    newone->h3 = this->thash;
    newone->h4 = this->ffhash;
    strcpy(newone->name, this->loc);


    /*
     * assign to the entry of skiplist.
     * if it is not found, this function allocate new entry area and assign.
     */

    last_num = bk->cup.num;
    handler_phase[dnum] = 125;
    gettimeofday(&xbefore, NULL);
    stored_pos =
        (skcache_entry_t*) sk_assign(&bk->cup, newone,
            &bk->elem_freelist, skcache_entry_cmp,
            &check_already_have, 0);
    gettimeofday(&xafter, NULL);

    if(stored_pos==NULL) {
        Error("think: cannot assign to entry free list of bk# %d, <1b>",
                this->fhash);
        Trace("think: stored_pos %p, check_already_have %d\n",
            stored_pos, check_already_have);

        this->state  = STATE_MESSAGE;
        this->reason = R_UNKNOW_ERROR;

        if(stored_pos!=newone) {
            skcache_push_idle_entry(bk, newone);
        }

        goto get_last;
    }

    /* NOTE:
     * stored_pos != NULL
     */
    this->cache_entry = stored_pos;
    stored_pos->ref++;
    stored_pos->hot = xafter.tv_sec;

    if(stored_pos!=newone) {
        /* HIT */
        /* 'newone' is not stored in bucket, because same old entry
         * is stored already.  use old one */
        skcache_push_idle_entry(bk, newone);
        newone = NULL;
        msg = HIT_msg;
    }
    else {
        /* MISS */
        /* 'newone' is stored in bucket */
        newone = NULL;
        msg = MISS_msg;
    }


    /* not found in memory, consider to seek disk or not
     * the object is allocated new area
     */
    if(check_already_have==0 && stored_pos->m_recorded==NULL) {
        if(this->reload==SESS_RELOAD || this->cachable!=SESS_CACHABLE) {
            /* nothing, dont seek disk */
        }
        else {
            int sig;

            sig_pos = 
                DSIG_POS(stored_pos->h1, stored_pos->h2, stored_pos->h3);

            MUTEX_LOCK(&dir_mutex);

            sig     = DSIG_ISSET(sig_pos, stored_pos->h4);
            dcount  = dir_count[sig_pos];
            dtime   = dir_time[sig_pos];

            MUTEX_UNLOCK(&dir_mutex);

            if(sig) {
                /*
                 * object is expected in disk.
                 * change to swap-in state
                 */
                stored_pos->issue_time  = this->last_action;
                stored_pos->oid         = 0;
                stored_pos->owner       = this;
                
                this->state = STATE_WAIT_SWAPIN;
                goto get_last;
            }
        }
    }


    /***
     *** not RELOAD and cachable
     ***/
    if(this->reload!=SESS_RELOAD && this->cachable==SESS_CACHABLE) {
        if(check_already_have==0) {
#if 0
Trace("  sess# %d, oid# %d, cachable, *not* have 782\n",
            this->sid, stored_pos->oid);
#endif

            /* it is new object, initialize attributes */
            stored_pos->owner       = this;
            stored_pos->oid         = this->sid;
            stored_pos->issue_time  = this->last_action;
            stored_pos->totallength = (off_t) 0L;
            stored_pos->m_recorded = NULL;
            stored_pos->d_recorded = 0;

#if 0
            Trace("\
  stored_pos        %p oid# %d, m_recorded %p\n\
  this->cache_entry %p oid# %d, m_recorded %p\n",
                stored_pos, stored_pos->oid, stored_pos->m_recorded,
                this-> cache_entry,
                ((skcache_entry_t*)this->cache_entry)->oid,
                ((skcache_entry_t*)this->cache_entry)->m_recorded);
#endif

            MUTEX_LOCK(&stat_lock);
            miss_reply_count++;
            MUTEX_UNLOCK(&stat_lock);

            this->state = STATE_QUERY_ADDR;
        }
        else {

#if 0
            Trace("known object: request sess# %d, %d:%d:%d:%d %s\n\
found %p oid# %d, ref %d, %d:%d:%d:%d %s\n",
    this->sid,
    this->fhash, this->shash, this->thash, this->ffhash, this->loc,
    stored_pos, stored_pos->oid, stored_pos->ref,
    stored_pos->h1, stored_pos->h2, stored_pos->h3, stored_pos->h4,
    stored_pos->name);

#endif

            if(stored_pos->ref>1) {
                this->state = STATE_WAIT_FRIEND;

                MUTEX_LOCK(&stat_lock);
                nfriend++;
                friend_count++;
                MUTEX_UNLOCK(&stat_lock);

#if 0
            Trace("sess# %d, wait friend session with %p %p\n",
                this->sid, this->cache_entry, stored_pos);

            Trace("stored %p oid# %4d ref %3d, %4d %4d %4d %4d %s\n",
                stored_pos, stored_pos->oid, stored_pos->ref,
                stored_pos->h1, stored_pos->h2,
                stored_pos->h3, stored_pos->h4, stored_pos->name);
#endif

            }
            else
            if(stored_pos->owner==this) {
#ifdef TRACE_SESS
                Trace("sess# %d, cachable, not have [%d:%d]\n",
                    this->sid, this->fhash, this->shash);
#endif

                MUTEX_LOCK(&stat_lock);
                miss_reply_count++;
                MUTEX_UNLOCK(&stat_lock);

                this->state = STATE_QUERY_ADDR;


            }
            else {

                if(stored_pos->cracked) {
                /* cracked object
                 * don't warry other session
                 */
#ifdef TRACE_SESS
                    Trace("sess# %d, cachable, have and cracked [%d:%d]\n",
                        this->sid, this->fhash, this->shash);
#endif
                    MUTEX_LOCK(&stat_lock);
                    miss_reply_count++;
                    MUTEX_UNLOCK(&stat_lock);

                    this->state = STATE_QUERY_ADDR;
                }
                else
                if(stored_pos->owner==NULL) {
                    /* the object is not included other sessions
                     * this session can use the object
                     */
#ifdef TRACE_SESS
                    Trace("sess# %d, cachable, have [%d:%d], cold\n",
                        this->sid, this->fhash, this->shash);
#endif
                    if(stored_pos->expire>0 &&
                        xafter.tv_sec > stored_pos->expire) {

                        MUTEX_LOCK(&stat_lock);
                        miss_reply_count++;
                        MUTEX_UNLOCK(&stat_lock);

                        this->state = STATE_QUERY_ADDR;

                    }
                    else {
                        MUTEX_LOCK(&stat_lock);
                        hit_reply_count++;
                        MUTEX_UNLOCK(&stat_lock);

#if 0
Trace("to be SEND_CACHE, entry %p, oid# %d, ref %d\n",
    stored_pos, stored_pos->oid, stored_pos->ref);
#endif

                        this->state = STATE_SEND_CACHE;
                        this->ishit = SESS_HIT;

                        stored_pos->count++;
                        stored_pos->hot = this->last_action;
  assert(CHKTIME(stored_pos->hot));
                        this->count = stored_pos->count;
                        this->oid = stored_pos->oid;
#if 0
    if(this->count>1) {
        Trace("&# oid# %8d, %3d, %d, name %s\n",
        stored_pos->oid, stored_pos->count, stored_pos->hot, stored_pos->name);
    }
#endif

                    }
                }
                else {
                    /* the object is included another session
                     * this session have to wait complete of that
                     */
#ifdef TRACE_SESS
                    Trace("sess# %d, cachable, have [%d:%d], hot\n",
                        this->sid, this->fhash, this->shash);
#endif
#if 0
                    Trace("sess# %d, cachable, have [%d:%d], hot\n",
                        this->sid, this->fhash, this->shash);
#endif

                    /* not hit and not miss */

                    this->state = STATE_WAIT_FRIEND;
                    this->hf++;

                    MUTEX_LOCK(&stat_lock);
                    nfriend++;
                    MUTEX_UNLOCK(&stat_lock);
#if 0
                    this->reason2 = stored_pos->owner;
#endif
#if 0
                    if(this->mode==MODE_CLIENT) {
                    Trace("sess# %d, to waiting owner %p, client\n",
                        this->sid, stored_pos->owner);
                    }
                    else {
                    Trace("sess# %d, to waiting owner %d, self\n",
                        this->sid, stored_pos->owner);
                    }
#endif
                }
            }
        }

        if(stored_pos->issue_time<=0) {
            Trace("Think: sess# %d, state %s(%d) <addr %p> ignore issue_time\n",
                this->sid, MSG_STATE_[this->state], this->state, stored_pos);
        }

#if 0
        chk = sk_entity_check(bk, __FILE__, __LINE__);
#endif

    }

    /***
     *** RELOAD or not cachable
     ***/
    else {

#if 0
        Trace("sess# %d, uncachable, make new entry\n", this->sid);
#endif

    /*
        release_buf(this, 0);
    */

        if(check_already_have==1) {
#if 0
Trace("  sess# %d, oid# %d, uncachable, have\n",
            this->sid, stored_pos->oid);
#endif

#if 0
            Trace("th: uncahable, have entry %p, oid# %d, ref %d\n",
                stored_pos, stored_pos->oid, stored_pos->ref);
#endif

            if(stored_pos->owner==NULL) {
#if 0
                Trace("Think: sess# %d, state %s(%d) <addr %p> no owner\n",
                    this->sid, MSG_STATE_[this->state], this->state, stored_pos);
#endif

                /* the program have previous object but it has not owner.
                 * delete the object and assign new entry to session. */

                stored_pos->cracked = 1;
                MUTEX_LOCK(&stat_lock);
                miss_reply_count++;
                MUTEX_UNLOCK(&stat_lock);

                this->state = STATE_QUERY_ADDR;
            }
            else {
                this->state = STATE_WAIT_FRIEND;

                MUTEX_LOCK(&stat_lock);
                nfriend++;
                MUTEX_UNLOCK(&stat_lock);
#if 0
                this->reason2 = stored_pos->owner;
#endif
            }
        }
        else {
#if 0
Trace("  sess# %d, oid# %d, uncachable, *not* have\n",
            this->sid, stored_pos->oid);
#endif

#if 0
            Trace("th: uncahable, not have entry %p, oid# %d, ref %d\n",
                stored_pos, stored_pos->oid, stored_pos->ref);
#endif

            this->oid = this->sid;

#if 0
            stored_pos->owner       = this->sid;
#endif
            stored_pos->owner       = this;
            stored_pos->oid         = this->sid;
            stored_pos->issue_time  = this->last_action;
if(stored_pos->issue_time<=0) {
    Trace("no2 stored_pos->issue_time %d, this->last_action %d\n",
        stored_pos->issue_time, this->last_action);
}
#if 0
            Trace("sess# %d, be not cachable\n", this->sid);
#endif

            stored_pos->cracked = 1;
            MUTEX_LOCK(&stat_lock);
            miss_reply_count++;
            MUTEX_UNLOCK(&stat_lock);

            this->state = STATE_QUERY_ADDR;
        }

 assert(check_bkinfo());
 assert(bk->cup.num==bk->entry_use);

#if 0
        chk = sk_entity_check(bk, __FILE__, __LINE__);
#endif
    }

#if 1
    if(this->state == STATE_THINK) {
        Trace("sess# %d, condition leak, 9\n", this->sid);
    }
#endif


    /* last of GET method */
get_last:

#if 0
    if(this->state==STATE_QUERY_ADDR) {
        Trace(
"th: sess# %d, will be retrieve, hlen %ld, clen %ld, entry %p, totallength %ld\n",
            this->sid, (long)this->hlen, (long)this->clen, 
            this->cache_entry,
            this->cache_entry ? (long)((skcache_entry_t*)this->cache_entry)->totallength: -1
            );
    }
#endif

    if(bk) {

#if 0
#ifdef TRACE_SK
    Trace("get_last:\n");
    fflush(stdout);
    fflush(stderr);
    sk_dump(&bk->cup, stderr, skcache_label_long);
    fflush(stdout);
    fflush(stderr);
#endif
#endif

 assert(check_bkinfo());
 assert(bk->cup.num==bk->entry_use);
#if 0
    chk = sk_entity_check(bk, __FILE__, __LINE__);
    if(!chk) {
        Error("sid# %d, stored_pos %p, oid# %d, check_already_have %d\n",   
            this->sid, 
            stored_pos, stored_pos ? stored_pos->oid : -999,
            check_already_have
            );
    }
#endif
        UNLOCK_BK(bk);

        bk = NULL;
    }

#if 0
Trace("sess# %d, end of GET, state %d %s\n",
    this->sid, this->state, MSG_STATE_[this->state]);
#endif


        break;


    /* POST method */
    case M_POST:
#ifdef TRACE_POST
Trace("sess# %d, POST method <%s>\n", this->sid, this->loc);
#endif
        MUTEX_LOCK(&stat_lock);
        miss_reply_count++;
        MUTEX_UNLOCK(&stat_lock);

        this->state = STATE_QUERY_ADDR;

        break;

    default:
        Error("sess# %d, ignore method %d '%s'",
            this->sid, this->state, MSG_STATE_[this->state]);

        MUTEX_LOCK(&stat_lock);
        miss_reply_count++;
        MUTEX_UNLOCK(&stat_lock);

        this->reason = R_UNSUPPORT_METHOD;
        this->state = STATE_MESSAGE;

        break;
    }

#if 0
    MUTEX_LOCK(&stat_lock);
    process_request_count++;
    MUTEX_UNLOCK(&stat_lock);
#endif

out:
    handler_phase[dnum] = 127;

    return 0;
}


/*
#ifndef TRACE_SESS
#define TRACE_SESS
#endif
*/


int
DoCheckEndFriendSess(int dnum, sess_t *this)
{
    struct timeval xbefore, xafter;
    int chk;
    bucket_t *bk;
    skcache_entry_t *stored_pos;
    int check_already_have;

    skcache_entry_t tmp;
    int idle;

#ifdef TRACE_SESS
    Trace("DoCheckEndFriendSess: sess# %d, entry 0x%x, '%s' [%d:%d:%d:%d] %s\n",
        this->sid,
        this->cache_entry,
        this->loc,
        this->fhash, this->shash, this->thash, this->ffhash,
        MSG_STATE_[this->state]);
#endif

    bk = &skcache_bucket_base[this->fhash];

    LOCK_BK(bk);

#if 0
    chk = sk_entity_check(bk, __FILE__, __LINE__);
#endif

    stored_pos = this->cache_entry;

    /* error */
    if(stored_pos==NULL) {
        Error("sess# %d, not found such entry", this->sid);

        goto do_retrieve;
    }

#ifdef TRACE_SESS
        Trace("stored %p ref %d hash %4d %4d %4d %4d %s\n",
            stored_pos, stored_pos->ref,
            stored_pos->h1, stored_pos->h2,
            stored_pos->h3, stored_pos->h4, stored_pos->name);
#endif

    if(stored_pos->h4!=this->ffhash||stored_pos->h3!=this->thash
        ||stored_pos->h2!=this->shash||stored_pos->h1!=this->fhash||
            strcmp(stored_pos->name, this->loc)!=0) {

        Trace("checkfriend: sess# %d, entry %p was changed. maybe expired\n",
            this->sid, stored_pos);

#ifdef TRACE_SESS
        Trace("stored %p %4d %4d %4d %4d %s\n",
            stored_pos,
            stored_pos->h1, stored_pos->h2,
            stored_pos->h3, stored_pos->h4, stored_pos->name);
#endif

        goto do_retrieve;
    }

#if 0
 assert(CHKTIME(stored_pos->hot));
    stored_pos->hot = time(NULL);
#endif

    if(stored_pos->owner==this) {
#ifdef TRACE_SESS
        Trace("sess# %d, the line is mine. *strange*\n", this->sid);
#endif
        goto do_retrieve;
    }
    else {
        if(stored_pos->cracked) {
#ifdef TRACE_SESS
            Trace("sess# %d, line was cracked\n", this->sid);
#endif
            goto do_retrieve;
        }
        else
#if 0
        if(stored_pos->ref==1 && stored_pos->owner==NULL)
#endif
        if(stored_pos->owner==NULL)
        {
#ifdef TRACE_SESS
            Trace("sess# %d, line is free\n", this->sid);
#endif
            stored_pos->owner = this;

            goto do_send;
        }
        else {
            idle = this->last_action - stored_pos->hot;
            if(idle < 0 && idle > 3*WFRIEND_TIMEOUT/4) {
#ifdef TRACE_SESS
                Trace("sess# %d, give up wait (%d sec)\n",
                    this->sid, idle);
#endif
                goto do_retrieve;
            }
            else {
#ifdef TRACE_SESS
                Trace("sess# %d, oid# %d is still hold by sess %p\n",
                    this->sid, stored_pos->oid, stored_pos->owner);
#endif
                /* not hit and not miss */
                goto still_wait;
            }
        }
    }

#ifdef TRACE_SESS
    Trace("reach to end\n");
#endif
    goto skip;

do_retrieve:
#ifdef TRACE_SESS
    Trace("do retrieve\n");
#endif
    if(stored_pos) {
#if 0
        if(this->cache_entry &&
            ((skcache_entry_t*)this->cache_entry)->ref<=0) {
            Trace("target is already reg ref %p %d %s %d\n",
                this->cache_entry,
                ((skcache_entry_t*)this->cache_entry)->ref,
                __FILE__, __LINE__ );
        }
#endif
        release_buf(this, 0);
        stored_pos = NULL;
        this->cache_entry = NULL;
    }

    this->cachable = SESS_UNCACHABLE;
    this->state = STATE_QUERY_ADDR;

    MUTEX_LOCK(&stat_lock);
    miss_reply_count++;
    nfriend--;
    MUTEX_UNLOCK(&stat_lock);

    goto skip;

do_send:
#ifdef TRACE_SESS
    Trace("do send\n");
#endif
    MUTEX_LOCK(&stat_lock);
    hit_reply_count++;
    MUTEX_UNLOCK(&stat_lock);

    this->state = STATE_SEND_CACHE;
    MUTEX_LOCK(&stat_lock);
    nfriend--;
    MUTEX_UNLOCK(&stat_lock);

    goto skip;

still_wait:
    /* not hit and not miss */
#ifdef TRACE_SESS
    Trace("still wait\n");
#endif

#if 0
    this->state = STATE_WAIT_FRIEND;
    MUTEX_LOCK(&stat_lock);
    nfriend++;
    MUTEX_UNLOCK(&stat_lock);
#endif

    goto skip;


skip:

#ifdef TRACE_SESS
    if(this->state != STATE_WAIT_FRIEND) {
        Trace("DoCheckEndFriendSess: sess# %d, change to %s\n",
            this->sid, MSG_STATE_[this->state]);
    }
#endif
#if 1
    if(this->state != STATE_WAIT_FRIEND) {
        Trace("DoCheckEndFriendSess: sess# %d, change to %s\n",
            this->sid, MSG_STATE_[this->state]);
    }
#endif

    if(bk) {

#if 0
    chk = sk_entity_check(bk, __FILE__, __LINE__);
#endif
 assert(bk->cup.num==bk->entry_use);
        UNLOCK_BK(bk);
        bk = NULL;
    }

out:

    return 0;
}


/*
#ifdef TRACE_SESS
#undef TRACE_SESS
#endif
*/


int
DoFindServer(int dnum, sess_t *this)
{
    int chk;
    int ret;
    int pnum;

#if 0
    Trace("DoFindServer: URL '%s'\n\t host '%s', port %d, path '%s'\n",
        this->loc, this->servername, this->serverport, this->serverpath);
#endif
    if(this->servername==NULL || this->servername[0]=='\0') {
        Error("sess# %d, empty hostname is specified", this->sid);
        return -1;
    }

#if 0
    hcache_list();
#endif

#if 1
    if(parent_num>=1) {
        pnum = this->sid%parent_num;
#if 1
        Trace("DoFindServer: switch to parent server# %d\n", pnum);
        show_addr("  target", &(parent_addr[pnum].sin_addr));
#endif
        sprintf(this->servername, "parent-%d", pnum);
/*
        this->serveraddr = parent_addr[pnum];
*/
        memcpy(&this->serveraddr, &parent_addr[pnum],
            sizeof(struct sockaddr_in));

        this->serverport = parent_port[pnum];
#if 1
        show_addr("  setted", &(this->serveraddr.sin_addr));
#endif

        this->state = STATE_CONN_SERV;

        goto out;
    }
#endif

    chk = hcache_seek_addr_incache(this->servername, &(this->serveraddr));
    if(chk) {
        /* miss */
        MUTEX_LOCK(&stat_lock);
        hname_miss_count++;
        MUTEX_UNLOCK(&stat_lock);
#if 0
        Trace("fs: '%s' hcache miss (%d).  ask it to resolver\n",
            this->servername, chk);
#endif
        gettimeofday(&this->r_start, NULL);

        chk = hcache_send_query_addr_direct(this->servername,
                &(this->serveraddr), &this->rfd);
#if 0
        Trace("    ret %d\n", chk);
#endif
        if(chk) {
            Error("fs: fail hcache_send_query_addr_direct() (%d)\n", chk);
            this->reason = R_RESOLVER_DOWN;
            this->state = STATE_MESSAGE;
            goto out;
        }

        this->state = STATE_WAIT_ADDR;
        ret = 0;
    }
    else {
        /* hit */
        MUTEX_LOCK(&stat_lock);
        hname_hit_count++;
        MUTEX_UNLOCK(&stat_lock);
#if 0
        Trace("fs: hit in hostname cache, '%s'\n",
            this->servername);
#endif
        this->serveraddr.sin_family = AF_INET;

        this->state = STATE_CONN_SERV;
        ret = 0;
    }

out:
    return ret;
}


int
DoServerConnect(int dnum, sess_t *this)
{
    int chk;

#if 1
    Trace("DoServerConnect: server '%s' [%s], port %d\n",
        this->servername, inet_ntoa(this->serveraddr.sin_addr),
        this->serverport);
#endif
#if 1
    show_addr(" trial target server sin_addr", &(this->serveraddr.sin_addr));
#endif

    /* asyncronus connect */
    this->sfd = TCP_aconnect_addr(&this->serveraddr, this->serverport);
    if(this->sfd<0) {
        if(this->sfd == KOTETU_SOCK_SOCKETERROR) {
            this->reason = R_FAIL_SERVER_SOCKET;
#if 0
            exit(437);
#endif
        }
        else {
            Error("DoServerConnect: sess# %d, reason %d",
                this->sid, this->sfd);
#if 1
            show_addr(" fail target server", &this->serveraddr.sin_addr);
#endif
            this->reason = R_FAIL_SERVER_CONNECT;
        }
        this->state = STATE_MESSAGE;
        return 0;
    }

    this->state = STATE_WAIT_CONN_SERV;

    return 0;
}

int
DoWaitServerConnect(int dnum, sess_t *this)
{
    volatile int errno_backup;
    int err, len;
    int chk;


#if 0
    Trace("DoWaitServerConnect: server '%s' [%s], port %d\n",
        this->servername, inet_ntoa(this->serveraddr.sin_addr),
        this->serverport);
#endif

    chk = iswritable_via_poll(this->sfd, 1, 0);
    if(chk>0) {
        this->state = STATE_SEND_REQUEST;
    }

    return 0;
}


int
DoSendRequest(int dnum, sess_t *this)
{
    char req[L_BUF];
    int len, rqlen;
    register char *p, *q, *r;
    int  nw;
    char line[STRING_SIZE];
    char *cpos;
    int c;
    int has_host = 0;
    int tclen = -1;
    int restlen = -1;


    /*
     * several server requires HOST field, independly protocol versions.
     * then, the program put HOST field.
     */
    if(this->method==M_POST) {
        sprintf(req, "POST %s HTTP/1.0\r\n", this->serverpath);
#if 0
    dump_stringchunk("original", this->reqbuf);
#endif
#if 0
    dump_stringsegment("original", this->reqbuf, this->reqlen);
    dump_stringchunk("first ", req);
#endif
    }
    else {
        if(this->abs_or_rel==ABS_PATH && parent_num>=1) {
#if 1
            Trace("case #1\n");
#endif
            sprintf(req, "GET %s HTTP/1.0\r\n", this->loc);
        }
        else {
            sprintf(req, "GET %s HTTP/1.0\r\n", this->serverpath);
        }
    }

#if 0
    dump_stringsegment("r.req.", this->reqbuf, this->reqlen);
#endif

    rqlen = HTTP_find_header_term(this->reqbuf, this->reqlen);
    if(rqlen>=L_REQBUF-1) {
        Error("too long requst (meybe rqlen is %d)", rqlen);
        dump_stringsegment("the request", this->reqbuf, this->reqlen);

        this->state = R_TOOLONG_REQ;
        this->state = STATE_MESSAGE;
        return -1;
    }

    p = this->reqbuf;
    r = this->reqbuf + rqlen;

    while(*p && *p!='\n') {
        p++;
    }
    p++;

    /* skip first line, because it was already copied */
    q = req;
    while(*q) {
        q++;
    }

    /* copy rest of header */
    cpos = p;
    while((cpos = sgets(p, cpos, line, STRING_SIZE))!=NULL) {
        if(line[0]=='\0') {
            break;
        }
        if((line[0]=='H' || line[0]=='h')
            && strncasecmp(line, "Host:", 5)==0) {
        has_host++;
#if 0
            continue;
#endif
        }
    if((line[0]=='C' || line[0]=='c')
        && strncasecmp(line, "Content-Length:", 15)==0) {
        tclen = atoi(line+16);
    }
        if((line[0]=='P' || line[0]=='p')
            && strncasecmp(line, "Proxy-Connection:", 17)==0) {
            continue;
        }
#if 1
        if((line[0]=='C' || line[0]=='c')
            && strncasecmp(line, "Connection:", 11)==0) {
            continue;
        }
#endif

    if(strlen(req)>=L_REQBUF-1) {
        Error("too long requst (current %d, original %d)", len, this->reqlen);
        dump_stringchunk("the requst", req);

        this->state = R_TOOLONG_REQ;
        this->state = STATE_MESSAGE;
        return -1;
    }

        strcat(req, line);

        if(line[0]=='\r'||line[0]=='\n') {
            break;
        }
    }

    if(has_host==0) {
#if 0
    Trace("  add host field\n");
#endif
        sprintf(line, "Host: %s:%d\r\n", this->servername, this->serverport);
        strcat(req, line);
    }
#if 0
        sprintf(line, "Connection: close\r\n");
        strcat(req, line);
#endif

    len = strlen(req);

#if 0
    dump_stringchunk("cooked request", req);
#endif


    if(this->method==M_POST) {
#if 0
        dump_stringchunk("header", req);
#endif

        restlen = this->reqlen - (cpos-&this->reqbuf[0]);
    Trace("sess# %d, rest %d, tclen %d\n", this->sid, restlen, tclen);
#if 0
    this->clen = tclen;
#endif

        if(restlen) {
        c = restlen;
#if 0
            dump_stringsegment("rest  ", cpos, c);
#endif
            p = cpos;
            q = req + len;
            while(c>0) {
                *q++ = *p++;
                c--;
                len++;
            }
        *q = '\0';
#if 0
            dump_stringchunk("cooked", req);
#endif
        }
#if 0
        dump_stringsegment("final", req, len);
#endif
    }

#if 0
  if(this->mode == MODE_SELF ) {
    Trace("sess# %d, request final form, length %d\n", this->sid, len);
    dump_stringsegment("s.req.", req, len);
  }
#endif
#if 1
    Trace("sess# %d, request final form, mode %d, length %d\n",
        this->sid, this->mode, len);
    dump_stringsegment("s.req.", req, len);
#endif

    c = 0;
try_write:
    c++;
    nw = write(this->sfd, req, len);
    if(nw<0) {
        if(errno==EINTR) {
            goto try_write;
        }

        if(errno==EPIPE) {
            this->reason = R_LOST_SERVER_CONNECT;
#if 0
            Error("sess# %d, server pipe (fd# %d) error (%d)",
                this->sid, this->sfd, errno);
#endif
        }
#if 0
        else
        if(errno==EAGAIN) {
        }
#endif
        else {
            this->reason = R_FAIL_SERVER_WRITE;

            Error("cannot write request to server sess %p fd #%d (%d)",
                this, this->sfd, errno);
        }

        this->state = STATE_MESSAGE;

        return -1;
    }
    if(nw==0) {
        this->state = STATE_CLOSE;
        return -1;
    }
#if 0
    Trace("write request %d byte(s)\n", nw);
#endif

    this->swrite += (off_t) nw;


#if 0
    this->last_action = time(NULL);
#endif


    if(this->method == M_GET || this->method == M_HEAD ) {
        this->state = STATE_RECV_RES;
    }
    else
    if(this->method == M_POST) {
        this->state = STATE_RELAY_DIRECT;
    }
    else {
    }

    return 0;
}


/*
 * for POST method
 */
int
DoRelayDirect(int dnum, sess_t *this)
{
    int rest;
    int use_tmpbuf;
    char tmpbuf[L_BUF];
    int l;
    struct iovec iovec[2];
    int ciovec;
    int blen;
    int nr;
    int nw;
    int chk;
    int err;

    int dir;
    int cr, cw, sr, sw;

#if 0
    Trace("relay: th# %x, sess# %d, \n",
        pthread_self(), this->sid);
#endif



    dir = 0;
    cr = cw = sr = sw = (off_t)0L;

    /*
     * Since connection starts by client, client has high priority.
     */

client_side:
    if(this->cfd<0) {
        goto server_side;
    }
    chk = isreadable_via_poll(this->cfd, 0, 0);
    if(chk>0) {
        dir = 1; /* client */
    }
    else
    if(chk<0) {
        Error("relay: th# %d, sess# %d, cfd# %d is unreadable, error (%d)\n",
            pthread_self(), this->sid, this->cfd, chk);
    }
    else {
        goto server_side;
    }

try_c_read:
    nr = read(this->cfd, tmpbuf, L_BUF);
#if 0
    Trace("relay: th# %x, sess# %d, read client %d\n",
        pthread_self(), this->sid, nr);
#endif
    if(nr<0) {
        if(errno==EINTR)
            goto try_c_read;

        this->reason = R_FAIL_CLIENT_READ;
        this->state = STATE_MESSAGE;
        goto out;
    }
    else
    if(nr==0) {
        DoHalfClientCloseSess(this);
        goto server_side;
    }

#if 0
    dump_stringsegment("c-said", tmpbuf, MIN(nr, 64));
#endif

    cr += nr;

try_s_write:
    nw = write(this->sfd, tmpbuf, nr);
    if(nw<0) {
        if(errno==EINTR)
            goto try_s_write;

        this->reason = R_FAIL_SERVER_WRITE;
        this->state = STATE_MESSAGE;
        goto out;
    }

    sw += nw;


server_side:
    if(this->sfd<0) {
        goto disconn_check;
    }
    chk = isreadable_via_poll(this->sfd, 0, 0);
    if(chk>0) {
        dir += 2; /* server */
    }
    else
    if(chk<0) {
        Error("relay: th# %d, sess# %d, sfd# %d is unreadable, error\n",
            pthread_self(), this->sid, this->cfd);
    }
    else {
        goto disconn_check;
    }

try_s_read:
    nr = read(this->sfd, tmpbuf, L_BUF);
#if 0
    Trace("relay: th# %x, sess# %d, read server %d\n",
        pthread_self(), this->sid, nr);
#endif
    if(nr<0) {
        if(errno==EINTR)
            goto try_s_read;

        this->reason = R_FAIL_SERVER_READ;
        this->state = STATE_MESSAGE;
        goto out;
    }
    else
    if(nr==0) {
        DoHalfServerCloseSess(this);
        goto disconn_check;
    }

#if 0
    dump_stringsegment("s-said", tmpbuf, MIN(nr, 64));
#endif

    sr += nr;

try_c_write:
    nw = write(this->cfd, tmpbuf, nr);
    if(nw<0) {
        if(errno==EINTR)
            goto try_c_write;

        this->reason = R_FAIL_CLIENT_WRITE;
        this->state = STATE_MESSAGE;
        goto out;
    }

    cw += nw;


disconn_check:

    if(this->cfd<0 || this->sfd<0) {
        this->state = STATE_CLOSE;
    }
#if 0
    if(dir==0) {
        this->state = STATE_CLOSE;
    }
#endif

out:
    if(cr>0) this->cread  += cr;
    if(cw>0) this->cwrite += cw;
    if(sr>0) this->sread  += sr;
    if(sw>0) this->swrite += sw;


#if 0
    Trace("relay: th# %d, sess# %d, dir %x, fd %d/%d r/w=c %d/%d, s %d/%d %s\n",
    pthread_self(), this->sid, dir, this->cfd, this->sfd,
        cr, cw, sr, sw, MSG_STATE_[this->state]);
#endif

    return 0;
}



/*
 *
 */

int
DoServerReply(int dnum, sess_t *this)
{
    int rest;
    int use_tmpbuf;
    char tmpbuf[L_BUF];
    int l;
    struct iovec iovec[2];
    int ciovec;
    int blen;
    int nr;
    int nw;
    int chk;
    int err;
    struct timeval xbefore, xafter;

    int hlen;
    int xvmajor, xvminor;
    time_t xdate, xlmd, xexpire;
    off_t xclen;
    int xrcode;
    int xcachable;
    int xreload;

    bucket_t *bk;
    skcache_entry_t *centry;
    int check_already_have;
    skcache_entry_t tmp;

    skcache_frag_t *flist;
    skcache_frag_t *first;
    skcache_frag_t *last;
    skcache_frag_t *cur;
    off_t frag_sum;
    int u;

    int c;

    int res=-1;

/*
#ifdef TRACE_CACHE
    Trace("DoServerReply: self %#x, sess# %d, hash %d:%d\n",
        pthread_self(), this->sid, this->fhash, this->shash);
#endif
*/

    /* init. values */
    bk = NULL;
    use_tmpbuf = 0;

    centry = NULL;
    first  = NULL;
    last   = NULL;
    cur    = NULL;
    blen   = 0;

    FCHK();

    if(this->cachable==SESS_UNCACHABLE) {
        res = 10;
        goto alloc_tmpbuf;
    }

    /*****
     ***** alloc buffer
     *****/

alloc_buf:
    FCHK();
    /* NOTE: if bk is setted, it means bucket is locked */
    bk = &skcache_bucket_base[this->fhash];
    handler_phase[dnum] = 201;
    LOCK_BK(bk);

  assert(sk_entity_check(bk, __FILE__, __LINE__));
  assert(sk_emptyentity_check(bk));

    /*
     * load centry and check its attibutes
     */
    centry = (skcache_entry_t*) this->cache_entry;
    if(centry==NULL) {
        res = 20;
        goto alloc_tmpbuf;
    }
#ifdef CHECK_MAGIC
    if(centry->magic[0]!=MAGIC_0 || centry->magic[1]!=MAGIC_1) {
        Error("sr: ignore magic bk# %d, centry %p, sess# %d",
            bk->bid, centry, this->sid);

        release_buf(this, 0);
        centry = NULL;
        this->cache_entry = NULL;

        res = 30;
        goto alloc_tmpbuf;
    }
#endif
    if(centry->cracked) {
        res = 40;
        goto alloc_tmpbuf;
    }
    if(centry->oid==0) {
        res = 45;
        goto alloc_tmpbuf;
    }
    if(centry->h4!=this->ffhash||centry->h3!=this->thash
        ||centry->h2!=this->shash||centry->h1!=this->fhash||
            strcmp(centry->name, this->loc)!=0) {
#if 1
        Trace("sess# %d, hash miss match, here %d:%d:%d:%d there %d:%d:%d:%d\n",
            this->sid, this->fhash, this->shash, this->thash, this->ffhash,
            centry->h1, centry->h2, centry->h3, centry->h4);
#endif

        res = 47;
        goto alloc_tmpbuf;
    }
    if(centry->owner != this) {
        res = 49;
        goto alloc_tmpbuf;
    }


    /* seek last position of object frags in this object entry */
    /* retrieving object must be upon memory */

    handler_phase[dnum] = 202;

    last = NULL;
    frag_sum = 0L;
    u = 0;
    first = centry->m_recorded;
    cur = centry->m_recorded;
    while(cur) {
        frag_sum += cur->len;
        last = cur;

        if(cur->next==cur) {
            Error("sess# %d, %dth frag %p is looped itself, %ld byte(s)",
                this->sid, u, cur, frag_sum);
            centry->cracked = 1;
            res = 50;
            goto alloc_tmpbuf;
        }

        cur = cur->next;

        u++;
        if(u>=nfrag_obj) {
#if 0
            Trace("sess# %d, too large, %d frags %ldB / max %d frags\n",
                this->sid, u, (long)frag_sum, nfrag_obj);
#endif
            res = 60;
            centry->cracked = 1;
            goto alloc_tmpbuf;
        }
    }

#if 0
    Trace("sr: sess# %d, u %d, cur %p, last %p\n",
        this->sid, u, cur, last);
#endif

    handler_phase[dnum] = 203;

#if 0
    /* that routine is very heavy, handle with care ! */
    skcache_frag_freelist_check(z_frag_freelist);
#endif

#ifdef TRACE_IO
    if(last) {
        Trace("sr: be sess# %d, last addr %p, len %d/%d, rest %d\n",
            this->sid, last, last->len, last->size, last->size - last->len);
    }
    else {
        Trace("sr: be sess# %d,\n", this->sid);
    }
    if(centry) {
        skcache_dump_entry_frag("sr:net-read alloc before", centry);
    }
    else {
        Trace("sr: centry is empty\n");
    }
#endif

    {

        /* get new frag */
try_get_frag:
        FCHK();
 assert(bk->cup.num==bk->entry_use);
        cur = skcache_pull_new_frag(bk);
 assert(bk->cup.num==bk->entry_use);
        FCHK();
        if(cur==NULL) {
            Error("ServerReply: sess# %d, cannot get new frag on bk# %d, %p",
                this->sid, bk->bid, bk);

            centry->cracked = 1;
            res = 70;
            goto alloc_tmpbuf;
        }
        bk->own_frag++;


        if(last) {
            last->next = cur;
        }
        else {
            if(centry->m_recorded) {
                Trace(
"sr: assign current sess# %d, entry %p, oid# %d, m_recorded %p, cur %p,\n",
                this->sid, centry, centry->oid, centry->m_recorded, cur);
            }
            
            centry->m_recorded = cur;
        }

#if 0
        skcache_dump_entry_frag("alloc", centry);
#endif

#ifdef TRACE_IO
        Trace("sess# %d, new cur frag %p, ent %p, len %d/%d\n",
            this->sid, cur, cur->ent, cur->len, cur->size);
#endif
        handler_phase[dnum] = 204;

        blen = 0;
        if(last && last->len<last->size) {
            iovec[blen].iov_base = (void*)((char*)last->ent + last->len );
            iovec[blen].iov_len  = last->size - last->len;
            blen++;
        }
        iovec[blen].iov_base = cur->ent;
        iovec[blen].iov_len  = cur->size;
        blen++;

    }

    MUTEX_LOCK(&stat_lock);
    alloc_sess_buf_count++;
    MUTEX_UNLOCK(&stat_lock);


#ifdef TRACE_IO
    if(centry) {
        skcache_dump_entry_frag("sr:net-read alloc after ", centry);
    }
#endif

    goto alloc_done;



alloc_tmpbuf:
    FCHK();
    handler_phase[dnum] = 205;
#ifdef TRACE_IO
    Trace("sess# %d, alloc tmpbuf, reason %d\n", this->sid, res);
#endif
    use_tmpbuf = 1;

    if(centry) {
#if 0
        Trace("alloc_tmpbuf, sess# %d, centry %p, m_recorded %p\n",
            this->sid, centry, centry->m_recorded);
#endif
        if(centry->m_recorded && bk!=NULL) {
#if 0
            Trace("ATT: purge stored entry sess# %d, oid# %d, res %d\n",
                this->sid, centry->oid, res);
#endif
            /*
            chk = skcache_entry_delete(bk, centry);
            if(chk) {
                Trace("  skcache_entry_delete() return %d\n", chk);
            }
            */
#if 0
        if(this->cache_entry &&
            ((skcache_entry_t*)this->cache_entry)->ref<=0) {
            Trace("target is already reg ref %p %d %s %d\n",
                this->cache_entry,
                ((skcache_entry_t*)this->cache_entry)->ref,
                __FILE__, __LINE__ );
        }
#endif


            release_buf(this, 0);
        }
/*
        release_buf(this, 0);
*/

        centry = NULL;
        this->cache_entry = NULL;
    }

    this->cachable = SESS_UNCACHABLE;
#if 1
    cur = NULL;
    last = NULL;
#endif

#ifdef TRACE_IO
    Trace("sess# %d, cur tmpbuf %p, len %d\n",
        this->sid, tmpbuf, sizeof(tmpbuf));
#endif
    handler_phase[dnum] = 206;

    blen = 1;
    iovec[0].iov_base = tmpbuf;
    iovec[0].iov_len  = sizeof(tmpbuf);

    MUTEX_LOCK(&stat_lock);
    alloc_tmp_buf_count++;
    MUTEX_UNLOCK(&stat_lock);

    goto alloc_done;


alloc_done:
    handler_phase[dnum] = 207;
    FCHK();

    if(blen==1) {
        rest = iovec[0].iov_len;
    }
    else
    if(blen==2) {
        rest = iovec[0].iov_len + iovec[1].iov_len;
    }
    else {
        rest = -1;
    }


#ifdef TRACE_IO
    if(blen>=2) {
        Trace("\
read-net: sr: sess# %d, fd# %d, blen %d, rest %d\n\
  iovec[0] base %p, len %d\n\
  iovec[1] base %p, len %d\n",
            this->sid, this->cfd, blen, rest,
            iovec[0].iov_base, iovec[0].iov_len,
            iovec[1].iov_base, iovec[1].iov_len);
    }
    else {
        Trace("\
read-net: sr: sess# %d, fd# %d, blen %d, rest %d\n\
  iovec[0] base %p, len %d\n",
            this->sid, this->cfd, blen, rest,
            iovec[0].iov_base, iovec[0].iov_len);
    }
#endif


    /***
     *** read socket
     ***/
    MUTEX_LOCK(&stat_lock);
    read_reply_total++;
    MUTEX_UNLOCK(&stat_lock);

try_read:
    FCHK();
    handler_phase[dnum] = 221;
    errno = 0;
    nr = readv(this->sfd, iovec, blen);
    err = errno;
    FCHK();


#ifdef TRACE_CACHE
    if(use_tmpbuf) {
        Trace("  sess# %d, fd# %d, read %4d/%-4d (temporaly area)\n",
            this->sid, this->sfd, nr, rest);
    }
    else {
        Trace(
            "  sess# %d, fd# %d, read %4d/%-4d (cache area) bk# %d, centry %p\n",
            this->sid, this->sfd, nr, rest, bk->bid, this->cache_entry);
    }
#endif

#ifdef TRACE_IO
    if(blen==1) {
        Trace("sess# %d, fd# %d, nr %ld/%ld, single buffer %ld <%d>\n",
            this->sid, this->sfd,
            (long)nr, (long)rest,
            (long)iovec[0].iov_len, err);
    }
    else
    if(blen==2) {
        Trace("sess# %d, fd# %d, nr %ld/%ld, double buffer %ld+%ld <%d>\n",
            this->sid, this->sfd,
            (long)nr, (long)rest,
            (long)iovec[0].iov_len, (long)iovec[1].iov_len, err);
    }
    else {
        Error("sess# %d, too many iov[] length\n", this->sid);
    }
#endif

    /***
     *** read error
     ***/
    if(nr<0) {
        if(err==EINTR) {
            goto try_read;
        }
        /* for OSF/1 */
        if(err==0) {
            goto try_read;
        }

        MUTEX_LOCK(&stat_lock);
        read_reply_fail++;
        MUTEX_UNLOCK(&stat_lock);

        switch(err) {
        case EAGAIN:
            goto out;
        case ECONNRESET:
            goto lost_connect;
        case EPIPE:
            Error("sr: sess# %d, pipe error fd# %d, sread %d",
                this->sid, this->sfd, this->sread);
            break;
        default:
            Error(
              "sr: sess# %d, cannot read server reply fd# %d, sread %d (%d)",
                this->sid, this->sfd, this->sread, err);
        }

        goto fail_read;
    }

    MUTEX_LOCK(&stat_lock);
    read_reply_success++;
    MUTEX_UNLOCK(&stat_lock);


#ifdef TRACE_IO
    if(centry) {
        skcache_dump_entry_frag("sr:net-read read after ", centry);
    }
#endif

    /***
     *** read complete
     ***/
    if(nr==0) {
#if 0
        Trace("sess# %d, read end, centry %p\n", this->sid, centry);
        skcache_dump_entry_frag("before", centry);
#endif

#if 0
        skcache_dump_entry_frag("after", centry);
        Trace("===\n");
        if(first) {
            dump_stringsegment("header", first->ent, this->hlen);
        }
#endif

#if 0
        if(centry) {
            Trace(
        "sr: sess# %d, totallength %7ld vs sum* %7ld <hlen %3ld clen %7ld>\n",
            this->sid, (long)centry->totallength,
            this->clen>0 ?  (long)this->hlen+this->clen : (long)this->hlen,
            (long)this->hlen, (long)this->clen);

            skcache_dump_entry_frag("after", centry);
            if(first) {
                dump_stringsegment("header", first->ent, this->hlen);
            }
        }
#endif

#ifdef TRACE_IO
    if(centry) {
        skcache_dump_entry_frag("sr:net-read read done  ", centry);
    }
#endif

        this->reason = -1;
        goto reach_end;
    }



    /***
     *** read blocks (frag)
     ***/

#if 0
 dump_stringsegment("res", iovec[0].iov_base, MIN(nr, 128));
#endif


    this->sread += (off_t) nr;
    sim_stat_add_value(&len_perread_stat, (long)nr);

    FCHK();
    if(this->cwrite == (off_t)0 ) {

        hlen = HTTP_find_header_term(iovec[0].iov_base,
                MIN(nr, iovec[0].iov_len));
#if 0
 Trace("response read %d, hlen %d (%d %x)\n",
    nr, hlen,   (int)*((char*)iovec[0].iov_base+hlen),
                (int)*((char*)iovec[0].iov_base+hlen));
 dump_stringsegment("res ",
    iovec[0].iov_base, MIN(nr, MIN(iovec[0].iov_len,384)));
 if(hlen>0) {
 dump_stringsegment("head",
    iovec[0].iov_base, MIN(hlen, MIN(384, nr)));
 }
#endif

        if(hlen>0) {

            if(hlen>=iovec[0].iov_len) {
Trace("sess# %d, r $ header term %4d / %5d\n",
        this->sid, hlen, MIN(nr, iovec[0].iov_len));
/*
                dump_stringsegment("broken",
                    iovec[0].iov_base, iovec[0].iov_len);
*/
            }

            this->hlen  = hlen;
            xcachable   = this->cachable;
            xreload     = this->reload;

            chk = HTTP_parse_response_header(iovec[0].iov_base, hlen,
                    &xvmajor, &xvminor, &xrcode,
                    &xdate, &xlmd, &xexpire, &xclen,
                    &xcachable, &xreload);

#ifdef DONT_CACHE
            xcachable = SESS_UNCACHABLE;
#endif

            if(!chk) {
                /* success */
#if 0
Trace("%c$B%c(B", 0x1b, 0x1b);
Trace("%c(@", 0x1b);
#endif
#if 0
Trace("sess# %d, <hlen %d><chk %d> ver %d.%d, rcode %d, lmd %d, expire %d, clen %d\n",
    this->sid, hlen, chk,
    xvmajor, xvminor, xrcode, xlmd, xexpire, xclen);
#endif
                this->sver_major    = xvmajor;
                this->sver_minor    = xvminor;
                this->rcode         = xrcode;
                this->lmd           = xlmd;
                this->expire        = xexpire;
                this->clen          = xclen;

                if(centry) {
                    centry->lmd     = xlmd;
                    centry->expire  = xexpire;
                }

                if(xcachable==SESS_UNCACHABLE) {
                    this->publish = SESS_PRIVATE;

                    if(centry) {
                        centry->cracked = 1;
                    }
                }
                else {
                    this->publish = SESS_PUBLIC;
                }

                /* uncachable is strong than cachable */
                if(xcachable==SESS_UNCACHABLE
                    && this->cachable == SESS_CACHABLE) {
                    this->cachable = SESS_UNCACHABLE;
                }
                /* reload is strong than noreload */
                if(xreload==SESS_RELOAD
                    && this->reload == SESS_NORELOAD) {
                    this->reload = SESS_RELOAD;
                }
            }
            else {
                /* fail */

                this->sver_major    = 0;
                this->sver_minor    = 0;
                this->rcode         = -1;
                this->lmd           = -1;
                this->expire        = -1;
                this->clen          = -1;
                this->publish       = SESS_PRIVATE;
            }

            this->pos = (off_t) this->sread;
        }
        else {
            Trace("sess# %d, no found header termination\n", this->sid);
        }

    }
    else {
        this->pos += (off_t) nr;
    }

    if(this->len<0) {
        this->len = (off_t) nr;
    }
    else {
        this->len += (off_t) nr;
    }

    FCHK();

    if(centry) {
        if(centry->totallength<=0)
            centry->totallength = nr;
        else
            centry->totallength += nr;

        if(blen==1) {
            if(cur) {
                cur->len += nr;
            }
            else {
                Error("no cur frag to record length");
            }
        }
#if 1
        else
        if(blen==2) {
            if(nr <= iovec[0].iov_len) {
                last->len += nr;
            }
            else {
                last->len += iovec[0].iov_len;
                cur->len  = (nr - iovec[0].iov_len);
            }
        }
#endif
        else {
            Error("ignore blen %d", blen);
        }
    }
#if 0
    else {
        Trace("does not have centry to save, sess# %d\n", this->sid);
    }
#endif

    if(centry) {
        centry->hot = this->last_action;
 assert(CHKTIME(centry->hot));
    }

#ifdef TRACE_IO
    if(centry) {
        skcache_dump_entry_frag("sr:net-read read after2", centry);
    }
#endif


    FCHK();

    if(this->cfd<0) {
        goto skip_write_body;
    }

#if 1
    if(this->method==M_HEAD) {
        if(this->cwrite!=0) {
            Error("sr: sess# %d, why HEAD apperes many position %d\n",
                this->sid, this->cwrite);
        }
        Trace("sr: sess# %d, fd# %d, hlen %d\n",
            this->sid, this->cfd, this->hlen);

try_write:
    FCHK();
        nw = write(this->cfd, iovec[0].iov_base, this->hlen);
    FCHK();
        if(nw<0) {
            if(errno==EINTR) {
                goto try_write;
            }
            Error("sr: sess# %d, cannot write to client fd# %d (%d)",
                this->sid, this->cfd, errno);
            this->reason = R_FAIL_CLIENT_WRITE;
        }

        DoHalfClientCloseSess(this);
        this->cwrite += (off_t) nw;
    } /* end of M_HEAD */
    else
    if(this->method==M_GET) 
#else
    if(1)
#endif
    {
        if(blen==2) {
            if(nr<=iovec[0].iov_len) {
                blen = 1;
                iovec[0].iov_len = nr;
            }
            else {
                if(nr<=iovec[0].iov_len + iovec[1].iov_len) {
                    iovec[1].iov_len = nr - iovec[0].iov_len;
                }
                else {
        Error("length of read <%d> is large than buffer <%d(%d+%d)>\n",
            nr, iovec[0].iov_len + iovec[1].iov_len);
                }
            }
        }
        else
        if(blen==1) {
            if(nr<iovec[0].iov_len) {
                iovec[0].iov_len = nr;
            }
        }


#ifdef TRACE_IO
        if(blen>=2) {
            Trace("\
write-net: sr: sess# %d, fd# %d, blen %d\n\
  iovec[0] base %p, len %d\n\
  iovec[1] base %p, len %d\n", 
                this->sid, this->cfd, blen,
                iovec[0].iov_base, iovec[0].iov_len,
                iovec[1].iov_base, iovec[1].iov_len);
        }
        else {
            Trace("\
write-net: sr: sess# %d, fd# %d, blen %d\n\
  iovec[0] base %p, len %d\n",
                this->sid, this->cfd, blen,
                iovec[0].iov_base, iovec[0].iov_len);
        }
#endif

try_writev:
        handler_phase[dnum] = 241;
    FCHK();
        nw = writev(this->cfd, iovec, blen);
    FCHK();

        if(nw<0) {
            if(errno==EINTR) {
                goto try_writev;
            }
            if(errno==EPIPE) {
                this->reason = -2;
                DoHalfClientCloseSess(this);
                goto reach_end;
            }

            Error("sr: sess# %d, cannot write to client fd# %d (%d)",
                this->sid, this->cfd, errno);
            this->reason = R_FAIL_CLIENT_WRITE;
            DoHalfClientCloseSess(this);

            goto fail_write;
        }
        if(nw<nr) {
            Error("sr: sess# %d, wrote client size (%d) is smaller than read size (%d)",
                this->sid, nw, nr);
            goto fail_write;
        }
        if(nw>nr) {
            Error("sr: sess# %d, wrote client size (%d) is larger than read size (%d)",
                this->sid, nw, nr);
        }
        if(nw==0) {
            Error("sr: sess# %d, wrote client size (%d) is zero blen %d",
                this->sid, nw, blen);
        }

        this->cwrite += (off_t) nw;

#if 0
Trace("sess# %d, nw %ld, cwrite %ld\n", (long)nw, (long)this->cwrite);
#endif

    } /* end of M_GET */

#if 0
    if(this->pos != this->len) {
    Trace("sess# %d, pos %ld, len %ld\n",
        this->sid, (long)this->pos, (long)this->len);
    }
#endif

skip_write_body:

    handler_phase[dnum] = 279;

    goto out;

/*
 * error recovery
 */

fail_memory:
    Error("sr: fail memory arrengment or memory trouble, sess# %d",
        this->sid);
    this->reason = R_LOST_BLOCK;

    goto fail;

lost_connect:
    Error("sr: lost conection establishment to server with some reason, sess# %d",
        this->sid);
    this->reason = R_LOST_SERVER_CONNECT;

    goto fail;

fail_connect:
    Error("sr: fail conection establishment to server with some reason, sess# %d",
        this->sid);
    this->reason = R_FAIL_SERVER_CONNECT;

    goto fail;

fail_read:
    Error("sr: fail reading from server with some reason, sess# %d",
        this->sid);
    this->reason = R_FAIL_SERVER_READ;

    goto fail;

fail_write:
    Error("sr: fail writing to client with some reason, sess# %d",
        this->sid);
    this->reason = R_FAIL_CLIENT_WRITE;

    goto fail;

fail:
    this->state = STATE_MESSAGE;

    goto out;




reach_end:
    FCHK();

    this->state = STATE_CLOSE;
#ifdef TRACE_CACHE
    Trace("Ok,sess# %d [%d:%d]                 read %12ld / %4ldK / %4ldM\n",
        this->sid, this->fhash, this->shash,
        (long)this->len,
        (long)dK(this->len), (long)dM(this->len) );
#endif

    sim_stat_add_value(&object_size_stat, (long)(this->len));

    if(this->len==0) {
        Log("; sess# %d, empty ?", this->sid);
    }

#if 0
    Trace("sr: sess# %d, %d %d diff %d, cl %ld, hl %ld, sr %ld, cw %ld, pos %ld\n",
        this->sid,
        (this->sread==this->cwrite && this->cwrite==this->pos),
        (this->clen+this->hlen == this->sread),
        (long)(this->clen + this->hlen - this->sread),
        (long)this->clen,
        (long)this->hlen,
        (long)this->sread, (long)this->cwrite, (long)this->pos);
#endif

    if(centry) {
        /* discard cached object */
        if(this->rcode == 304) {
#if 0
Trace("sess# %d, be cracked, because rcode %d\n", this->sid, this->rcode);
#endif
            centry->cracked = 1;
        }

        centry->owner = NULL;
    }
    handler_phase[dnum] = 289;

    goto out;



out:


#if 1
    /* if the entry has 2 and more frags, tail frag is may empty.
     * this routine remove empty tail frags to save memory space.
     * however, because single empty frags means empty object,
     * don't remove such case.
     */
    if(cur && last && cur!=last) {
        if(cur->len==0) {
#ifdef TRACE_IO
    Trace("sr: sess# %d, tail frag is empty, clear it\n", this->sid);
#endif

            if(last) {
                last->next = NULL;
            }
            else {
                if(centry && centry->totallength > 0) {
#ifdef TRACE_IO
Trace("sr: flush sess# %d, centry %p, oid# %d, m_recorded %p\n",
    this->sid, centry, centry->oid, centry->m_recorded);
#endif
                    centry->m_recorded = NULL;
                    centry->d_recorded = 0;
                }
            }

            chk = skcache_push_idle_frag(bk, cur);
            cur = NULL;
            bk->own_frag--;
            blen--;
        }
    }
#endif

#ifdef TRACE_IO
    if(centry) {
        Trace("sess# %d, state %s, URL '%s'\n",
            this->sid, MSG_STATE_[this->state], this->loc);
        skcache_dump_entry_frag("sr:net-read read end-of-turn", centry);
    }
#else
#if 0
    if(centry && this->sid%1000==0) {
        Trace("sess# %d, URL '%s'\n", this->sid, this->loc);
        skcache_dump_entry_frag("sr:net-read read end-of-turn", centry);
    }
#endif
#endif


    if(centry) {
#if 0
        centry->hot = xafter.tv_sec;
#endif
        centry->hot = this->last_action;
 assert(CHKTIME(centry->hot));
    }
    else {
#if 0
 Trace("centry is empty\n");
#endif
    }

    if(bk) {
 assert(sk_entity_check(bk, __FILE__, __LINE__));
 assert(bk->cup.num==bk->entry_use);
        UNLOCK_BK(bk);
        bk = NULL;
    }
    else {
#if 0
 Trace("bk is empty\n");
#endif
    }

#ifdef TRACE_CACHE
#if 0
Trace(" @\n\n");
#endif
#endif

    FCHK();

    return 0;
}

#if 0
    if(centry->h4!=this->ffhash||centry->h3!=this->thash
        ||centry->h2!=this->shash||centry->h1!=this->fhash||
            strcmp(centry->name, this->loc)!=0) {
#endif

/* entry x, session y */
#define comp_hash_name(ex,sy) \
    (ex->h4!=sy->ffhash||centry->h3!=sy->thash \
        ||ex->h2!=sy->shash||centry->h1!=sy->fhash|| \
            strcmp(ex->name, sy->loc)!=0)


int
DoSendCache(int dnum, sess_t *this)
{
    int chk;
    int sum;
    int nw, nwx;
    int l;
    int i;
    struct iovec iov[HARD_NFRAG_NWRITE];
    int ciov;
    time_t now;
    int hlen;
    int xvmajor, xvminor, xrcode;
    time_t xdate, xlmd, xexpire;
    off_t xclen;
    int xcachable, xreload;
    bucket_t *bk;
    skcache_entry_t *centry;
    skcache_frag_t *cur;
    skcache_frag_t *first;

    int skcache_dump_entry_frag(char*, skcache_entry_t*);


/*
    now = time(NULL);
*/
    bk  = &skcache_bucket_base[this->fhash];
    LOCK_BK(bk);

    centry = this->cache_entry;
    if(chk = skcache_entry_check(centry, __FILE__, __LINE__)) {
        Error("sc: hit sess# %d [%d:%d:%d:%d], ignore entry %p",
            this->sid, this->fhash, this->shash, this->thash, this->ffhash,
            centry);
        goto tobe_miss;
    }
#if 0
    if(centry==NULL) {
        Trace("sc: hit sess# %d [%d:%d:%d:%d], however entry is empty\n",
            this->sid, this->fhash, this->shash, this->thash, this->ffhash);
        goto tobe_miss;
    }
#if 0
    Trace("stored %p oid# %d, ref %d, [%d:%d:%d:%d] %s\n",
        centry, centry->oid, centry->ref,
        centry->h1, centry->h2, centry->h3, centry->h4, centry->name);
#endif

    if(centry->ref<0) {
        Trace("sc: hit sess# %d [%d:%d:%d:%d], it was dead. maybe expired\n",
            this->sid, this->fhash, this->shash, this->thash, this->ffhash);
        goto tobe_miss;
    }
#endif

#if 0
    Trace("comp centry %x vs this\n\
%d/%d %d/%d %d/%d %d/%d\n  %s\n  %s\n",
    centry,
    centry->h1, this->fhash,
    centry->h2, this->shash,
    centry->h3, this->thash,
    centry->h4, this->ffhash,
    centry->name, this->loc);
#endif

    if(comp_hash_name(centry, this)) {

    Trace("sc: hit sess# %d [%d:%d:%d:%d], entry was changed from oid# %d, %d:%d:%d:%d . lost the object, maybe expired\n",
            this->sid, this->fhash, this->shash, this->thash, this->ffhash,
            centry->oid, centry->h1, centry->h2, centry->h3, centry->h4);

#if 0
        Trace("comp centry %x vs this\n\
%d/%d %d/%d %d/%d %d/%d\n  %s\n  %s\n",
    centry,
    centry->h1, this->fhash,
    centry->h2, this->shash,
    centry->h3, this->thash,
    centry->h4, this->ffhash,
    centry->name, this->loc);
#endif

        goto tobe_miss;
    }


 assert(bk->cup.num==bk->entry_use);

    if(centry->m_recorded == NULL) {
        if(centry->d_recorded!=0) {
#if 1
            Trace("DoSendCache: hit sess# %d that object is stored in disk\n",
                this->sid);
#endif

            chk = skcache_entry_swapin(bk, centry);
#if 1
            Trace("DoSendCache: sess# %d, that object is stored in disk, %d\n",
                this->sid, chk);
#endif
            if(chk) {
#if 1
    if(chk==XSK_SWAP_MISS) {
        Trace("sess# %d, swapin() return MISS\n", this->sid);
    }
#endif
                Trace("sess# %d, fail to swapin oid# %d from disk <%d>\n",
                    this->sid, centry->d_recorded, chk);
                first = NULL;
            }
            else {
                first = centry->m_recorded;
#if 0
                centry->oid = this->sid;
#endif
            }
        }
        else {
#if 1
            Trace("DoSendCache: hit sess# %d, but object is not stored in memory and disk\n",
                this->sid);
#endif
            first = NULL;
        }
    }
    else {
        first = centry->m_recorded;
    }

 assert(bk->cup.num==bk->entry_use);

    /* not found */
    if(first==NULL) {
        Trace("sc: hit sess# %d [%d:%d:%d:%d], however first flag is empty\n",
            this->sid, this->fhash, this->shash, this->thash, this->ffhash);
        goto tobe_miss;
    }

#if 0
    Trace("DoSendCache: sess# %d, len %d, pos %d\n",
        this->sid, this->len, this->pos);
#endif

#if 0
    Trace("  object# %d <%p>, '%s'\n\
  create time %d, hot %d, lmd %d, expire %d\n\
  totallength %d\n",
        centry->oid, centry, centry->name,
        centry->issue_time, centry->hot, centry->lmd, centry->expire,
        centry->totallength);
#endif

    if(centry->oid<0) {
        Error("sendcache: sess# %d, stored oid is negative oid# %d",
            this->sid, centry->oid);

#if 1
    Trace("  object# %d <%p>, '%s'\n\
  create time %d, hot %d, lmd %d, expire %d\n\
  totallength %d\n",
        centry->oid, centry, centry->name,
        centry->issue_time, centry->hot, centry->lmd, centry->expire,
        centry->totallength);
#endif

        goto tobe_miss;
    }

    /*
     * length check
     */

    if(centry->totallength<=0) {
#if 1
        Trace("sess# %d, totallength %d, clen %ld\n",
            this->sid, centry->totallength, (long)this->clen);
#endif
        goto tobe_miss;
    }

    this->oid = centry->oid;

  if((off_t)this->pos==(off_t)0L) {

#if 0
    Trace("sc: sess# %d, first->ent %p, len %d/%d, this->pos %ld\n",
        this->sid, first->ent, first->len, first->size, (long)this->pos);
#endif

    hlen = HTTP_find_header_term( (char*)(first->ent + this->pos), first->len);
    if(hlen<=0) {
#if 1
        Trace("sc: sess# %d, oid# %d, not found header %d/%d\n",
            this->sid, this->oid, hlen, first->len);
#endif

#if 0
        dump_stringsegment("sc:header", (char*)(first->ent + this->pos), first->len);
#endif

        centry->cracked = 1;
        goto tobe_miss;
    }

    chk = HTTP_parse_response_header(
            (char*)(first->ent + this->pos), hlen,
            &xvmajor, &xvminor, &xrcode,
            &xdate, &xlmd, &xexpire, &xclen,
            &xcachable, &xreload);

    if(chk) {
#if 1
        Trace("sc: sess# %d, ignore header\n", this->sid);
#endif
#if 0
        dump_stringsegment("sc:header", (char*)(first->ent + this->pos), hlen);
#endif

        goto tobe_miss;
    }
    else {
        this->clen = xclen;
    }
#if 0
    Trace("sc: version %d.%d, rcode %d\n", xvmajor, xvminor, xrcode);
    Trace("sc: lmd %d, expire %d, clen %ld\n", xlmd, xexpire, (long)xclen);
#endif

    if(xrcode<0) {
#if 1
        Trace("sess# %d, rcode is ignore (%d)\n",
            this->sid, xrcode);
#endif

        goto tobe_miss;
    }
    this->rcode = xrcode;

    if(this->clen>0) {
        if((centry->totallength-hlen)!=this->clen) {
#if 0
 Error("sc: sess# %d, oid# %d, size miss match stored %ld header said %ld",
                this->sid, centry->oid,
                (long)centry->totallength-hlen, (long)this->clen);
#endif
#if 1
 Trace("sc: sess# %d, size-miss oid# %d, stored %ld header said %ld, diff %ld\n",
                this->sid, centry->oid,
                (long)centry->totallength-hlen, (long)this->clen,
                (long)this->clen - (long)centry->totallength-hlen);
            Trace("sc: totallength %ld, hlen %ld, clen %ld, sum %ld\n",
                (long)centry->totallength,
                (long)hlen, (long)this->clen, (long)(hlen+this->clen));
            skcache_dump_entry_frag("sc:frags", centry);
#endif
#if 0
            dump_stringsegment("sc:header",
                (char*)(first->ent + this->pos), hlen);
#endif

            centry->cracked = 1;

            goto tobe_miss;
        }
        else {
        }
    }

    this->len = centry->totallength;


    /* cracked check */

    if(centry->cracked) {
#if 1
        Trace("sess# %d, cracked\n", this->sid);
#endif
        goto tobe_miss;
    }


    /* expire check */

    if(centry->expire>0 && this->last_action > centry->expire) {
#if 1
        Trace("sess# %d, should be expire\n", this->sid);
#endif
        goto tobe_miss;
    }


    /*
     *
     */
    if(this->ims>0) {
#if 0
        Trace("sc: sess# %d, ims %d, lmd %d, expire %d\n",
                this->sid, this->ims, centry->lmd, centry->expire);
#endif
    }


    /*
     *
     */
#if 0
    centry->count++;
    this->count = centry->count;
    centry->hot = this->last_action;
 assert(CHKTIME(centry->hot));

    this->ishit = SESS_HIT;
    this->oid = centry->oid;
#endif

    centry->hot = this->last_action;
 assert(CHKTIME(centry->hot));

    if(bk) {
    }

 }
 else {
#if 0
    Trace("sc: sess# %d, sent %ld/%ld\n",
        (long)this->pos, (long)centry->totallength);
#endif
 }


    if(this->pos>=centry->totallength) {
#if 1
        Trace("sc: sess# %d, all content of object was send pos/len=%d/%d\n",
            this->sid, this->pos, this->len);
#endif
        goto done;
    }


    /*
     * skip current point to last sending
     */
    if(this->pos>(off_t)0)
    {
        off_t sum;
        int a;

        sum = (off_t)0L;
        cur = first;
        a = 0;

        do {
            sum += cur->len;

            if(cur==cur->next) {
                Error("sc; frag looped, broken data was send");
                centry->cracked = 1;

                goto done;
            }

            cur = cur->next;
            a++;
        } while(cur && sum<this->pos);

        if(cur==NULL) {
            Error("sess #d, maybe reach to end", this->sid);
            goto done;
        }
    }
    else {
        cur = first;
    }


    if(bk) {
    }

    /*
     *
     */

#if 1
    if(this->method==M_HEAD) {
        l = 0;
        iov[l].iov_base = first->ent;
        iov[l].iov_len  = MIN(first->len, this->hlen);
        sum = iov[l].iov_len;
        nwx = sum;
        l++;
        ciov = l;

        Trace("sc: sess# %d, response for HEAD, %d vec, hlen %d, sum %ld, nwx %ld\n",
            this->sid, ciov, this->hlen, (long)sum, (long)nwx);

        goto skip_entry_first_vec;
    }
#endif

    sum = 0;
/*
    cur = first;
*/

    do
    {
        /* set frags as buffer and count the length of them */
        nwx = 0;
        l = 0;
        do {
            iov[l].iov_base = cur->ent;
            iov[l].iov_len  = cur->len;
            sum += cur->len;
            nwx += cur->len;

            l++;

            cur = cur->next;
        } while(cur && l < nfrag_nwrite && cur->len>0 );
        ciov = l;

skip_entry_first_vec:

        if(this->cfd<0) {
            break;
        }

#ifdef TRACE_IO
    {
        int i;
        int tmp_sum;
    
        tmp_sum = 0;
        for(i=0;i<ciov;i++) {
            tmp_sum += iov[i].iov_len;
        }
        Trace("write-net: sc: sess# %d, ciov %d, tmp_sum %dB\n",
            this->sid, ciov, tmp_sum);

        tmp_sum = 0;
        for(i=0;i<ciov;i++) {
            tmp_sum += iov[i].iov_len;
            Trace("  sess# %d, iov %2d: %4d %7d\n",
                this->sid, i, iov[i].iov_len, tmp_sum);
        }
    }
#endif


try_writev:
        nw = writev(this->cfd, iov, ciov);
        if(nw<0) {
            if(errno==EINTR) {
                goto try_writev;
            }
            if(errno==EPIPE) {
                DoHalfClientCloseSess(this);
                goto done;
            }
            Error("sess# %d, cannot write to client fd# %d, ciov %d, (%d)",
            this->sid, this->cfd, ciov, errno);
            this->reason = R_FAIL_CLIENT_WRITE;
            this->state = STATE_CLOSE;

            goto out;
        }
        if(nw!=nwx) {
            Error("sc: sess# %d, fd# %d, write size missmatch expect %ld, actual %ld ; %d buffers",
                this->sid, this->cfd, (long)nwx, (long)nw, ciov);
            if(centry)
                skcache_dump_entry_frag("sc: net-write", centry);
            {
            int i;
            
            for(i=0;i<ciov;i++) {
                Trace("  %2d: iov %p len %d\n",
                    i, iov[i].iov_base, iov[i].iov_len);
            }
            }
        }

        this->cwrite += (off_t) nw;
        this->pos += nw;

    } while(sum<nfrag_nwrite && cur!=NULL && this->method==M_GET);

    this->last_action = time(NULL);

#if 1
    if(this->method==M_HEAD) {
        goto done;
    }
#endif

    if(this->pos>=centry->totallength) {
        goto done;
    }

still:
    /* do nothing */
    goto out;

done:
    this->state = STATE_CLOSE;
    goto out;


tobe_miss:

    /* when enter this routine, the program increment hit counter.
     * if miss, the program has to decrement that and increment miss counter.
     */
    MUTEX_LOCK(&stat_lock);
    miss_reply_count++;
    hit_reply_count--;
    skip_cache_count++;
    MUTEX_UNLOCK(&stat_lock);

    if(centry) {
#if 0
        Trace(
          "sc: miss: to be miss sess# %d, hf %d, oid# %d, cwrite %ld, pos %ld\n",
          this->sid, this->hf, centry->oid, (long)this->cwrite, (long)this->pos);
#endif
        Trace(
          "sc: miss: to be miss sess# %d, hf %d, oid# %d, cwrite %ld, pos %ld ; entry %p, oid# %d, \n",
          this->sid, this->hf, this->oid, (long)this->cwrite, (long)this->pos,
            centry, centry->oid);
#if 0
        fflush(stderr);
        skcache_entry_show(centry, stdout);
        fflush(stdout);
#endif

        if((long)this->cwrite>0L) {
            Trace("sc: miss: during sending. rest of buffer is lost\n");
        }
        else {
        }

#if 0
        if(this->cache_entry &&
            ((skcache_entry_t*)this->cache_entry)->ref<=0) {
            Trace("target is already reg ref %p %d %s %d\n",
                this->cache_entry,
                ((skcache_entry_t*)this->cache_entry)->ref,
                __FILE__, __LINE__ );
        }
#endif

        release_buf(this, 0);
    }
    else {
        Trace(
            "sc:miss: to be miss sess# %d, hf %d, oid# ?, cwrite %ld, pos %ld\n",
            this->sid, this->hf, (long)this->cwrite, (long)this->pos);
    }
    centry = NULL;
    this->cache_entry = NULL;
    this->state = STATE_QUERY_ADDR;
    this->cachable = SESS_UNCACHABLE;

    goto out;

out:
    if(bk) {
#if 0
    chk = sk_entity_check(bk, __FILE__, __LINE__);
#endif
 assert(bk->cup.num==bk->entry_use);
        UNLOCK_BK(bk);
    }

    return 0;
}





/* support only IPv4 */
static
int
store_scrambled_name(char *dst, struct sockaddr_in *addr, int sc_key)
{
    register char *p, *q;
    register int i;
    register int c;

    q = (char*) &addr->sin_addr;

    c = 0xc634d3a5;
    c |= sc_key;
    for(i=3;i>=0;i--) {
        p = &q[i];
        c += *p;
        c = c << 3 + 0x01;

#if 0
        Trace(" #%d %3u %2x -> %12u %12x\n",
            i, (unsigned int)*p, (unsigned int)*p,
            (unsigned int)c, (unsigned int)c);
#endif
    }

    sprintf(dst, "c%u", c);

    return 0;
}

static
int
store_direct_name(char *dst, struct sockaddr_in *addr)
{
    register char *p, *q;
    register int i;
    register int c;

    p = (char*) &addr->sin_addr;
    q = dst;

    for(i=0;i<4;i++) {
        if(*p>100)
            *q++ = '0' + (*p / 100);
        if(*p>10)
            *q++ = '0' + ((*p % 100)/10);
        *q++ = '0' + (*p % 10);
        *q++ = '.';
        *q = '\0';

#if 0
        Trace(" #%d %3u %2x -> '%s'\n",
            i, (unsigned int)*p, (unsigned int)*p, dst);
#endif

        p++;
    }

    return 0;
}


static
int client_scramble_key;

void*
Listener(void *called_option)
{
    int chk;
    struct sockaddr_in from;
    int len;
    int cfd;
    int find;
    int p, c;
    int op;
    int listen_fd;
    sess_t *sessp;
    int t_req, t_rjq;
    int t_nhot;
    int err;
    int try_c;
    struct timeval tmp_accept_time;
    char tmp_clientname[L_HOST];
    unsigned char *caddr;
    off_t nr, nw;


    listen_fd = *(int*)called_option;
    len = sizeof(from);

    while(1) {
try_accept:
#ifdef DO_ACCEPT_LOCK
        chk = MUTEX_LOCK(&accept_lock);
        if(chk) {
            Error("Listener: fail lock (%d)", chk);
            if(chk==EBUSY) {
                Trace(" ---  busy\n");
                goto try_accept;
            }

            goto try_accept;
        }
#endif

        err = errno = -1;
        cfd = accept(listen_fd, (struct sockaddr*)&from, &len);
        err = errno;
        gettimeofday(&tmp_accept_time, NULL);

#if 0
        Trace("Listener<%p> accept fd# %d (errno %d)\n",
            pthread_self(), cfd, err);
#endif

#ifdef DO_ACCEPT_LOCK

        try_c=0;
try_unlock:
        try_c++;

        chk = MUTEX_UNLOCK(&accept_lock);
        if(chk) {
            Error("Listener: fail unlock (%d) [%d]", chk, try_c);
            goto try_unlock;
        }
#endif

        if(cfd<0) {
            if(err==EINTR)
                goto try_accept;
#if 0
            if(err==ENFILE || err==EMFILE) {
                sleep(5);
                /*
                exit(143);
                */
            }
#endif

            Error("accept error (%d)", err);

            goto next;
        }


        MUTEX_LOCK(&stat_lock);
        receive_request_count++;
        request_sirial_count++;
        t_req = request_sirial_count;
        MUTEX_UNLOCK(&stat_lock);

#if 0
        Trace("th %d, conn. count %6d, cfd %3d\n",
            pthread_self(), t_req, cfd);
#endif


        /*
         * store peer (client or lower proxy) name
         */
#ifdef LOG_DIRECTCLIENTIPADDRESS
        store_direct_name(tmp_clientname, &from);
#else
        store_scrambled_name(tmp_clientname, &from, client_scramble_key);
#endif

#if 0
        Trace("peer <%s>\n", tmp_clientname);
#endif


        /*
         * check permition
         */
        caddr = (unsigned char*) &from.sin_addr.s_addr;
        if(!Acceptable(caddr)) {
            goto not_permitted;
        }


found_free:

        sessp = (sess_t*)sq_get_free();
        if(sessp==NULL) {
            Error("listener: not enough memory for session to push thinkQ");
            goto not_found_free;
        }


        /*
         * NOTE:
         *   # of hot session will be discrease.
         *   however, it is not increase. because increasing is only
         *   happen in this routines.
         */

        MUTEX_LOCK(&sess_lock);
        nhot++;
        MUTEX_UNLOCK(&sess_lock);



        chk = pthread_mutex_init(&(sessp->busy), NULL);

        sessp->sid    = t_req;
        sessp->psid   = -1;
        sessp->mode   = MODE_CLIENT;
        sessp->level  = 0;
        sessp->state  = STATE_ACCEPT;

        sessp->accept_time = tmp_accept_time;
        sessp->last_action = tmp_accept_time.tv_sec;

        sessp->reported = 0;
        sessp->reason = -1;

        sessp->hf   = 0;

        sessp->pos    =  0;
        sessp->len    = -1;
        sessp->rcode  = -1;
        sessp->count  = 0;
        sessp->lmd    = -1;
        sessp->expire = -1;

        sessp->hlen   = 0;
        sessp->clen   = -1; /* field 'conetent-length' */

        sessp->cver_major = -1;
        sessp->cver_minor = -1;
        sessp->sver_major = -1;
        sessp->sver_minor = -1;

#ifndef USE_REQUEST_THRU
        sessp->cachable = SESS_CACHABLE;
#else
        if(thru_factor>=100) {
            sessp->cachable = SESS_UNCACHABLE;
        }
        else
        if(thru_factor>0) {
            if(rand()%100<=thru_factor) {
                sessp->cachable = SESS_UNCACHABLE;
            }
            else {
                sessp->cachable = SESS_CACHABLE;
            }
        }
        else {
            sessp->cachable = SESS_CACHABLE;
        }
#endif

        sessp->reload   = SESS_NORELOAD;
        sessp->ishit    = SESS_MISS;
        sessp->publish  = SESS_PUBLIC;

        sessp->cache_entry = NULL;

        sessp->oid    = -1;

        sessp->cfd    = cfd;
        sessp->sfd    = -1;
        sessp->rfd    = -1;
        sessp->rcount = 3;
        sessp->r_start.tv_sec  = 0;
        sessp->r_start.tv_usec = 0;

        strcpy(sessp->clientname, tmp_clientname);

        sessp->method = M_UNKNOW;
        memset(sessp->loc, 0, sizeof(sessp->loc));
        sessp->abs_or_rel = 0;

        memset(sessp->reqbuf, 0, sizeof(sessp->reqbuf));
        sessp->reqlen = 0;

        sessp->ims = -1;

#ifdef TRACE_SESS
        Trace("sess# %d, new sess, addr %p\n", sessp->sid, sessp);
#endif

        sessp->state  = STATE_RECV_REQ;


        chk = push_sess(think_queue, sessp);
        if(chk) {
            Error("Listener: sess# %d, fail push to think Q", sessp->sid);
            sessp->reason = R_MEMORY_OVERFLOW;

            DoSendMessage(sessp);
            DoCloseSess(sessp);
            DoReleaseSess(sessp);
            sessp = NULL;

            goto next;
        }

#if 0
        MUTEX_LOCK(&think_queue->lock);
        fflush(stderr);
        sq_show(stdout, think_queue);
        fflush(stdout);
        MUTEX_UNLOCK(&think_queue->lock);
#endif

        goto next;



not_found_free:
#if 0
        Error("not found idle session cell");
#endif
        MUTEX_LOCK(&stat_lock);
        reject_request_count++;
        t_rjq = reject_request_count;
        MUTEX_UNLOCK(&stat_lock);
#if 1
        if(t_rjq%100==0) {
            LogLine("; session list overflow");
        }
#endif


        nw = HTTP_SendIgnoreMessage(cfd, 501,
            "service denided", "please wait few minutus");
        shutdown(cfd, 2);
        close(cfd);
        cfd = -1;

        MUTEX_LOCK(&stat_lock);
        intra_outgoing += (off_t) nw;
        MUTEX_UNLOCK(&stat_lock);

        goto next;



not_permitted:
#if 0
        Error("not permitted host");
#endif
        MUTEX_LOCK(&stat_lock);
        reject_request_count++;
        t_rjq = reject_request_count;
        MUTEX_UNLOCK(&stat_lock);
#if 1
        LogLine("; request from not permitted host <%s>");
#endif

        nw = HTTP_SendIgnoreMessage(cfd, 403,
            "access denided", "you are not permitted this server");
        shutdown(cfd, 2);
        close(cfd);
        cfd = -1;

        MUTEX_LOCK(&stat_lock);
        intra_outgoing += (off_t) nw;
        MUTEX_UNLOCK(&stat_lock);

        goto next;



next:
        chk = 0;

    }

}



int
old_DoParseAnchor(int dnum, sess_t *this)
{
    int chk;
    int rest;
    int nw;
    int l;

    bucket_t *bk;
    skcache_entry_t *centry;
    skcache_frag_t *first, *cur;

    int t_req=1234; /* dummy */

    int nc;
    int ntag;
    int ihave;

    int howprefetch;

    tags_t  *tags;
    char    **urllist;
    int     nofref;

    sess_t *psessp;
    char **aurl;
    char nurl[L_URL];

    int fh, sh, th, ff;

#ifdef TRACE_THREADS
    Trace("DoParseAnchor: sid %d, [%d:%d]\n",
        this->sid, this->fhash, this->shash);
#endif



    tags = NULL;

    if(this->cachable==SESS_UNCACHABLE) {
#ifdef TRACE_PREFETCH
        Trace("DoParseAnchor: sess# %d is not cachable\n", this->sid);
#endif
        goto out_nothing;
    }
#ifdef TRACE_PREFETCH
    Trace("DoParseAnchor: sess# %d, level %d, URL '%s'\n",
        this->sid, this->level, this->loc);
#endif

    /* allow level 0 or 1 */
    if(this->level<0 || this->level>2) {
#if 0
        Trace("sess# %d %p, strange level %d\n",
            this->sid, this, this->level);
#endif
        goto out;
    }

    /*
     *
     */
    bk = &skcache_bucket_base[this->fhash];
    LOCK_BK(bk);
#if 0
    /* XXX */
    if(chk) {
        Trace("DoParseAnchor: fail lock block #%d [%d:%d:%d]\n",
            this->fhash, this->fhash, this->shash, this->thash);
        goto out_pending;
    }
#endif
#if 0
    chk = sk_entity_check(bk, __FILE__, __LINE__);
#endif

    centry = (skcache_entry_t*) this->cache_entry;

    /* not found object */
    if(centry==NULL) {
#if 0
        Trace("sess# %d, no entry in block# %d [%d:%d:%d]\n",
            this->sid, this->fhash, this->fhash, this->shash, this->thash);
#endif
#if 0
        cache_showblockaddr(this->fhash, 0);
#endif

 assert(bk->cup.num==bk->entry_use);
#if 0
    chk = sk_entity_check(bk, __FILE__, __LINE__);
#endif
        UNLOCK_BK(bk);
        bk = NULL;
        goto not_found;
    }

    first = centry->m_recorded;
/* XXX */
#if 0
    if(centry->d_recorded>=0) {
    }
#endif
    if(first==NULL) {
        Trace("sess# %d, no frag in block# %d [%d:%d]\n",
            this->sid, this->fhash, this->fhash, this->shash);
#if 0
        cache_showblockaddr(this->fhash, 0);
#endif

 assert(bk->cup.num==bk->entry_use);
#if 0
    chk = sk_entity_check(bk, __FILE__, __LINE__);
#endif
        UNLOCK_BK(bk);
        bk = NULL;
        goto not_found;
    }


    /***
     ***
     ***/

    tags = HTML_NewTags();

    if(this->level==0) {
#ifdef TRACE_PREFETCH
        Trace("parse refered: '%s' %db\n",
            this->loc, first->length);
#endif
        chk = MUTEX_LOCK(&config_lock);
        howprefetch = num_prefetch_referedpages;
        chk = MUTEX_UNLOCK(&config_lock);

        ntag = HTML_ParseTags_FromMemory(tags, PARSE_REFERED,
                first->ent, first->len);
#ifdef TRACE_PREFETCH
        Trace("parse refered: #%d %ldb %d\n",
            this->sid, first->length, ntag);
#endif
    }
    else
    if(this->level==1) {
#ifdef TRACE_PREFETCH
        Trace("parse included: '%s' %db\n",
            this->loc, first->length);
#endif
        chk = MUTEX_LOCK(&config_lock);
        howprefetch = num_prefetch_includedobjs;
        chk = MUTEX_UNLOCK(&config_lock);

        ntag = HTML_ParseTags_FromMemory(tags, PARSE_INCLUDED,
                first->ent, first->len);

#ifdef TRACE_PREFETCH
        Trace("parse included: #%d %db %d\n",
            this->sid, first->length, ntag);
#endif
    }


#if 0
    dump_stringchunk("entity", (char*)&line_pos->body);
    Trace("there are %d tag(s).\n", ntag);
#endif

 assert(bk->cup.num==bk->entry_use);
#if 0
    chk = sk_entity_check(bk, __FILE__, __LINE__);
#endif
    UNLOCK_BK(bk);
    bk = NULL;
    centry = NULL;
    first = NULL;




    if(ntag<=0) {
        FREE(tags);
        tags = NULL;
        goto out;
    }

    if(tags==NULL) {
        goto out;
    }
    else {
        if(tags->count==0) {
            FREE(tags);
            tags = NULL;
            goto out;
        }
    }

    urllist = HTML_ConvURLList(tags, &nofref);
    HTML_DestroyTags_withoutvalue(tags);
    tags = NULL;



    /*
     *
     */

#if 0
    /*
    HTML_ShowIndependURLList(this->loc, urllist);
    */
    HTML_ShowURLList(urllist);
#endif

#ifdef TRACE_PREFETCH
    if(urllist) {
        Trace("DoParseAnchor<%d>: decide prefetch targets about\n  '%s'\n",
            pthread_self(), this->loc);
    }
    else {
        Trace("DoParseAnchor<%d>: prefetch target list is empty\n");
    }
#endif

    nc = 0;
    aurl = urllist;
    while(*aurl!=NULL && nc<howprefetch) {
#if 0
        Trace("  newone '%s'\n", *aurl);
#endif


        URL_JoinStr(nurl, L_URL, this->loc, *aurl);
        if(nurl[0]=='\0') {
            goto next;
        }
#ifdef TRACE_PREFETCH
        Trace("  full URL '%s'\n", nurl);
#endif

        calc_hash(nurl, &fh, &sh, &th, &ff);
#if 0
Trace("pan: %03d:%03d:%03d:%03d %s\n",
        fh, sh, th, ff, this->loc);
#endif

#if 0
        Trace("  check object existance in cache\n");
#endif
#if 0
        ihave = cache_have(fh, sh, nurl, 1, 0);
#endif
        ihave = skcache_have(fh, sh, th, ff, nurl, 1, 0);

#if 0
        Trace("  ihave %d\n", ihave);
#endif
        if(ihave>0) {
            goto next;
        }
        /* URL is not empty and it is not hold in cache */
        else
        if(ihave==0) {
            psessp = (sess_t*)sq_get_free();
            if(psessp==NULL) {
                Error("not enough memory for new prefetching session");
                goto skip;
            }

            chk = pthread_mutex_init(&(psessp->busy), NULL);

            MUTEX_LOCK(&sess_lock);
            nhot++;
            MUTEX_UNLOCK(&sess_lock);


#if 1
            MUTEX_LOCK(&stat_lock);
            request_sirial_count++;
            t_req = request_sirial_count;

            issue_prefetch_count++;

            MUTEX_UNLOCK(&stat_lock);
#endif


            /***
             ***
             ***/

            psessp->sid    = t_req;
            psessp->psid   = this->sid;
            psessp->mode   = MODE_SELF;
            psessp->level  = this->level+1;
            psessp->state  = STATE_THINK;
            psessp->last_action = this->last_action;

            gettimeofday(&(psessp->accept_time), NULL);

            psessp->reported = 0;
            psessp->reason  = -1;

            psessp->hf      = 0;

            psessp->pos     =  0;
            psessp->len     = -1;
            psessp->rcode   = -1;
            psessp->count   = 0;
            psessp->lmd     = -1;
            psessp->expire  = -1;

            psessp->cachable = SESS_CACHABLE;
            psessp->reload   = SESS_NORELOAD;
            psessp->ishit    = SESS_MISS;
            psessp->publish  = SESS_PUBLIC;

            psessp->oid     = -1;

            psessp->cfd     = -1;
            psessp->sfd     = -1;
            psessp->rfd     = -1;
            psessp->rcount  = 2;


            strcpy(psessp->clientname, "self");

            memset(psessp->loc , 0, sizeof(psessp->loc));
            memset(psessp->reqbuf, 0, sizeof(psessp->reqbuf));
            psessp->reqlen = 0;

            psessp->cver_major = 0;
            psessp->cver_minor = 0;
            psessp->sver_major = -1;
            psessp->sver_minor = -1;
            psessp->ims = -1;

            DoSetReq(dnum, psessp, nurl);

#if 0
            dump_stringchunk("generated request", psessp->reqbuf);
#endif

#ifdef TRACE_PREFETCH
            Trace("nurl = %4d-%02d %p (#%d) '%s'\n",
                this->sid, nc, psessp, psessp->sid, psessp->loc);
#endif


            chk = DoThink(dnum, psessp);
            if(chk==0 && psessp->state==STATE_QUERY_ADDR) {
                handler_phase[dnum] = 1241;

                DoFindServer(dnum, psessp);
                if(psessp->state==STATE_CONN_SERV) {
#if 0
                    Trace("connect prefetch target '%s'\n", psessp->loc);
#endif
                    DoServerConnect(dnum, psessp);
                }

#ifdef TRACE_PREFETCH
                Trace("sess# %d, <self>   method <%s>,URL '%s' version ?\n",
                    psessp->sid, MSG_M_[psessp->method], psessp->loc);
#else
#ifdef TRACE_SESS
                Trace("sess# %d, <self>   method <%s>,URL '%s' version ?\n",
                    psessp->sid, MSG_M_[psessp->method], psessp->loc);
#endif
#endif

#if 0
                Trace("     push to think Q as sess# %d %s\n",
                    psessp->sid, MSG_STATE_[psessp->state]);
#endif
                if(psessp) {
                    chk = push_sess(think_queue, psessp);
                    if(chk) {
                        Error("DoParseAnchor: sess# %d, fail push to think Q",
                            psessp->sid);
                        sq_be_free(psessp);
                        psessp = NULL;
                    }
                    psessp = NULL;

#if 0
        MUTEX_LOCK(&think_queue->lock);
        fflush(stderr);
        sq_show(stdout, think_queue);
        fflush(stdout);
        MUTEX_UNLOCK(&think_queue->lock);
#endif

                }
            }
            else {
                handler_phase[dnum] = 1271;

                DoReleaseSess(psessp);
                psessp = NULL;
            }

#if 0
            Trace("  ..done\n");
#endif

skip:
            (void)1;    /* dummy for label */
#if 0
            Trace("  skip\n");
#endif

        }
        else {
            /*
            Trace("DoParseAnchor: fail cache_have(), return %d\n", ihave);
            */
        }
next:
#if 0
        Trace("  next\n");
#endif

        aurl++;
        nc++;
#if 0
        Trace("  ? next\n");
#endif
    }

#ifdef TRACE_PREFETCH
    Trace("DoParseAnchor<%d>: loop end\n");
#endif

    HTML_FreeURLList(urllist);
    FREE(urllist);
    urllist = NULL;

    tags = NULL;


#ifdef TRACE_PREFETCH
    Trace("DoParseAnchor<%d>: block end\n");
#endif

    goto out;

done:

not_found:
#if 0
    /*
    Error("DoParseAnchor: cache was not found #%d [%d:%d] when hit",
        this->sid, this->fhash, this->shash);
    */
    Error("DoParseAnchor: sess#%d [%d:%d:%d] does not have cache entry",
        this->sid, this->fhash, this->shash, this->thash);
#endif
    goto out;


out:

out_nothing:

    return 0;


out_pending:

    return 1;

}


int
DoParseAnchor(int dnum, sess_t *this)
{
    int chk;
    int rest;
    int nw;
    int l;

    bucket_t *bk;
    skcache_entry_t *centry;
    skcache_frag_t *first, *cur;

    int t_req=1234; /* dummy */

    int no, nc;
    int ntag;
    int ihave;

    int howprefetch;

    tags_t  *tags;
    char    **urllist;
    int     nofref;

    sess_t *psessp;
    char **aurl;
    char nurl[L_URL];

    int fh, sh, th, ff;

#ifdef TRACE_THREADS
    Trace("DoParseAnchor: sid %d, [%d:%d]\n",
        this->sid, this->fhash, this->shash);
#endif



    tags = NULL;

    if(this->cachable==SESS_UNCACHABLE) {
#ifdef TRACE_PREFETCH
        Trace("DoParseAnchor: sess# %d is not cachable\n", this->sid);
#endif
        goto out_nothing;
    }
#ifdef TRACE_PREFETCH
    Trace("DoParseAnchor: sess# %d, level %d, URL '%s'\n",
        this->sid, this->level, this->loc);
#endif

    /* allow level 0 or 1 */
    if(this->level<0 || this->level>2) {
#ifdef TRACE_PREFETCH
        Trace("sess# %d %p, strange level %d\n",
            this->sid, this, this->level);
#endif
        goto out;
    }
    if(!IsHTML(this->loc)) {
#ifdef TRACE_PREFETCH
        Trace("sess# %d %p, is not HTML '%s'\n",
            this->sid, this, this->loc);
#endif
        goto out;
    }

    /*
     *
     */
    bk = &skcache_bucket_base[this->fhash];
    LOCK_BK(bk);
#if 0
    /* XXX */
    if(chk) {
        Trace("DoParseAnchor: fail lock block #%d [%d:%d:%d]\n",
            this->fhash, this->fhash, this->shash, this->thash);
        goto out_pending;
    }
#endif
#if 0
    chk = sk_entity_check(bk, __FILE__, __LINE__);
#endif

    centry = (skcache_entry_t*) this->cache_entry;

    /* not found object */
    if(centry==NULL) {
#if 0
        Trace("sess# %d, no entry in block# %d [%d:%d:%d]\n",
            this->sid, this->fhash, this->fhash, this->shash, this->thash);
#endif
#if 0
        cache_showblockaddr(this->fhash, 0);
#endif

 assert(bk->cup.num==bk->entry_use);
#if 0
    chk = sk_entity_check(bk, __FILE__, __LINE__);
#endif
        UNLOCK_BK(bk);
        bk = NULL;
        goto not_found;
    }

    first = centry->m_recorded;
/* XXX */
#if 0
    if(centry->d_recorded>=0) {
    }
#endif
    if(first==NULL) {
        Trace("sess# %d, no frag in block# %d [%d:%d]\n",
            this->sid, this->fhash, this->fhash, this->shash);
#if 0
        cache_showblockaddr(this->fhash, 0);
#endif

 assert(bk->cup.num==bk->entry_use);
#if 0
    chk = sk_entity_check(bk, __FILE__, __LINE__);
#endif
        UNLOCK_BK(bk);
        bk = NULL;
        goto not_found;
    }


    /***
     ***
     ***/
 {
#ifndef PREFETCH_PARSE_RANGE
#define PREFETCH_PARSE_RANGE    (K(32))
#endif
    char pbuf[PREFETCH_PARSE_RANGE];
    int plen, nlen;
    int pc;

    FCHK();

    pc = 0;
    plen = 0;
    cur = first;
    while(cur && plen<PREFETCH_PARSE_RANGE-1) {
        nlen = MIN(PREFETCH_PARSE_RANGE-1 - plen, cur->len);
#if 0
        Trace(" p %2d: addr %p len %4d : %4d // stored len %6d -> %6d\n",
            pc, cur->ent, cur->len, nlen, plen, plen + nlen);
#endif
        memcpy(&pbuf[plen], cur->ent, nlen);
        plen += nlen;

        cur = cur->next;
        pc++;
    }
    pbuf[plen] = '\0';

    FCHK();

    tags = HTML_NewTags();

    if(this->level==0) {
#ifdef TRACE_PREFETCH
        Trace("parse refered: '%s' %db\n",
            this->loc, plen);
#endif
        chk = MUTEX_LOCK(&config_lock);
        howprefetch = num_prefetch_referedpages;
        chk = MUTEX_UNLOCK(&config_lock);

        ntag = HTML_ParseTags_FromMemory(tags, PARSE_REFERED,
                pbuf, plen);
#ifdef TRACE_PREFETCH
        Trace("parse refered: sess# %d, len %ldb, got %d\n",
            this->sid, plen, ntag);
#endif
    }
    else
    if(this->level==1) {
#ifdef TRACE_PREFETCH
        Trace("parse included: '%s' %db\n",
            this->loc, plen);
#endif
        chk = MUTEX_LOCK(&config_lock);
        howprefetch = num_prefetch_includedobjs;
        chk = MUTEX_UNLOCK(&config_lock);

        ntag = HTML_ParseTags_FromMemory(tags, PARSE_INCLUDED,
                pbuf, plen);

#ifdef TRACE_PREFETCH
        Trace("parse included: sess# %d, len %db, got %d\n",
            this->sid, plen, ntag);
#endif
    }

 }


#if 0
    dump_stringchunk("entity", (char*)&line_pos->body);
    Trace("there are %d tag(s).\n", ntag);
#endif

 assert(bk->cup.num==bk->entry_use);
#if 0
    chk = sk_entity_check(bk, __FILE__, __LINE__);
#endif
    UNLOCK_BK(bk);
    bk = NULL;
    centry = NULL;
    first = NULL;




    if(ntag<=0) {
        FREE(tags);
        tags = NULL;
        goto out;
    }

    if(tags==NULL) {
        goto out;
    }
    else {
        if(tags->count==0) {
            FREE(tags);
            tags = NULL;
            goto out;
        }
    }

    urllist = HTML_ConvURLList(tags, &nofref);
    HTML_DestroyTags_withoutvalue(tags);
    tags = NULL;



    /*
     *
     */

#if 0
    /*
    HTML_ShowIndependURLList(this->loc, urllist);
    */
    HTML_ShowURLList(urllist);
#endif

#ifdef TRACE_PREFETCH
    if(urllist) {
        Trace("DoParseAnchor<%d>: decide prefetch targets about\n  '%s'\n",
            pthread_self(), this->loc);
    }
    else {
        Trace("DoParseAnchor<%d>: prefetch target list is empty\n");
    }
#endif

    no = nc = 0;
    aurl = urllist;
    while(*aurl!=NULL && nc<howprefetch) {
#if 0
        Trace("  newone '%s'\n", *aurl);
#endif

        URL_JoinStr(nurl, L_URL, this->loc, *aurl);
        if(nurl[0]=='\0') {
            goto next;
        }
/*
#ifdef TRACE_PREFETCH
        Trace("  full URL '%s'\n", nurl);
#endif
*/

        calc_hash(nurl, &fh, &sh, &th, &ff);
#if 0
Trace("pan: %03d:%03d:%03d:%03d %s\n",
        fh, sh, th, ff, this->loc);
#endif

#if 0
        Trace("  check object existance in cache\n");
#endif
#if 0
        ihave = cache_have(fh, sh, nurl, 1, 0);
#endif
        ihave = skcache_have(fh, sh, th, ff, nurl, 1, 0);

#ifdef TRACE_PREFETCH
        Trace("  target# %d, %d/%d %s '%s'\n",
        no, nc, howprefetch, ihave? "have" : "not-have", nurl);
#endif
#if 0
        Trace("  ihave %d\n", ihave);
#endif
        if(ihave>0) {
            goto next;
        }
        /* URL is not empty and it is not hold in cache */
        else
        if(ihave==0) {
            psessp = (sess_t*)sq_get_free();
            if(psessp==NULL) {
                Error("not enough memory for new prefetching session");
                goto skip;
            }

            chk = pthread_mutex_init(&(psessp->busy), NULL);

            MUTEX_LOCK(&sess_lock);
            nhot++;
            MUTEX_UNLOCK(&sess_lock);


#if 1
            MUTEX_LOCK(&stat_lock);
            request_sirial_count++;
            t_req = request_sirial_count;

            issue_prefetch_count++;

            MUTEX_UNLOCK(&stat_lock);
#endif


            /***
             ***
             ***/

            psessp->sid    = t_req;
            psessp->psid   = this->sid;
            psessp->mode   = MODE_SELF;
            psessp->level  = this->level+1;
            psessp->state  = STATE_THINK;
            psessp->last_action = this->last_action;

            gettimeofday(&(psessp->accept_time), NULL);

            psessp->reported = 0;
            psessp->reason  = -1;

            psessp->hf      = 0;

            psessp->pos     =  0;
            psessp->len     = -1;
            psessp->rcode   = -1;
            psessp->count   = 0;
            psessp->lmd     = -1;
            psessp->expire  = -1;

            psessp->cachable = SESS_CACHABLE;
            psessp->reload   = SESS_NORELOAD;
            psessp->ishit    = SESS_MISS;
            psessp->publish  = SESS_PUBLIC;

            psessp->oid     = -1;

            psessp->cfd     = -1;
            psessp->sfd     = -1;
            psessp->rfd     = -1;
            psessp->rcount  = 2;


            strcpy(psessp->clientname, "self");

            memset(psessp->loc , 0, sizeof(psessp->loc));
            memset(psessp->reqbuf, 0, sizeof(psessp->reqbuf));
            psessp->reqlen = 0;

            psessp->cver_major = 0;
            psessp->cver_minor = 0;
            psessp->sver_major = -1;
            psessp->sver_minor = -1;
            psessp->ims = -1;

            DoSetReq(dnum, psessp, nurl);

#if 0
            dump_stringchunk("generated request", psessp->reqbuf);
#endif

#ifdef TRACE_PREFETCH
/*
            Trace("nurl = %4d-%02d %p (#%d) '%s'\n",
                this->sid, nc, psessp, psessp->sid, psessp->loc);
*/
            Trace("issue %3d: sess# %d, from sess# %d addr %p '%s'\n",
        nc, this->sid, psessp->sid, psessp, psessp->loc);
#endif


            chk = DoThink(dnum, psessp);
            if(chk==0 && psessp->state==STATE_QUERY_ADDR) {
                handler_phase[dnum] = 1241;

                DoFindServer(dnum, psessp);
                if(psessp->state==STATE_CONN_SERV) {
#if 0
                    Trace("connect prefetch target '%s'\n", psessp->loc);
#endif
                    DoServerConnect(dnum, psessp);
                }

#ifdef TRACE_PREFETCH
                Trace("sess# %d, <self>   method <%s>,URL '%s' version ?\n",
                    psessp->sid, MSG_M_[psessp->method], psessp->loc);
#else
#ifdef TRACE_SESS
                Trace("sess# %d, <self>   method <%s>,URL '%s' version ?\n",
                    psessp->sid, MSG_M_[psessp->method], psessp->loc);
#endif
#endif

#if 0
                Trace("     push to think Q as sess# %d %s\n",
                    psessp->sid, MSG_STATE_[psessp->state]);
#endif
                if(psessp) {
                    chk = push_sess(think_queue, psessp);
                    if(chk) {
                        Error("DoParseAnchor: sess# %d, fail push to think Q",
                            psessp->sid);
                        sq_be_free(psessp);
                        psessp = NULL;
                    }
                    psessp = NULL;

#if 0
        MUTEX_LOCK(&think_queue->lock);
        fflush(stderr);
        sq_show(stdout, think_queue);
        fflush(stdout);
        MUTEX_UNLOCK(&think_queue->lock);
#endif

                }
            }
            else {
                handler_phase[dnum] = 1271;

                DoReleaseSess(psessp);
                psessp = NULL;
            }

#if 0
            Trace("  ..done\n");
#endif

skip:
            (void)1;    /* dummy for label */
#if 0
            Trace("  skip\n");
#endif

            nc++;
        }
        else {
            /*
            Trace("DoParseAnchor: fail cache_have(), return %d\n", ihave);
            */
        }
next:
#if 0
        Trace("  next\n");
#endif

        aurl++;
    no++;
#if 0
        Trace("  ? next\n");
#endif
    }

#ifdef TRACE_PREFETCH
    Trace("DoParseAnchor<%d>: loop end\n");
#endif

    HTML_FreeURLList(urllist);
    FREE(urllist);
    urllist = NULL;

    tags = NULL;


#ifdef TRACE_PREFETCH
    Trace("DoParseAnchor<%d>: block end\n");
#endif

    goto out;

done:

not_found:
#if 0
    /*
    Error("DoParseAnchor: cache was not found #%d [%d:%d] when hit",
        this->sid, this->fhash, this->shash);
    */
    Error("DoParseAnchor: sess#%d [%d:%d:%d] does not have cache entry",
        this->sid, this->fhash, this->shash, this->thash);
#endif
    goto out;


out:

out_nothing:

    return 0;


out_pending:

    return 1;

}



/*
 * Hmain
 *
 */

static
void*
Hmain(int dnum, sess_t *sessp, time_t now)
{
    int chk;
    int cv;
    int pending;
    int qn;

    int m_sid;

    if(sessp==NULL)
        return NULL;

#if 0
    if(sessp && sessp->method==M_POST) {
    Trace("hand: th# %x, sess# %d, state %s\n", 
        pthread_self(), sessp->sid, MSG_STATE_[sessp->state]);
    }
#endif

    handler_phase[dnum] = 100;

    FCHK();

    m_sid = sessp->sid;

    sessp->last_action = now;
    sessp->tic++;

    switch(sessp->state) {
    /*
     * like manager
     */
    case STATE_ACCEPT:
    case STATE_RECV_REQ:
        handler_phase[dnum] = 110;

        if(sessp->mode==MODE_CLIENT && sessp->cfd>=0) {
#if 0
            Trace("client request (%d) and client fd (%d) is normal\n",
                    sessp->mode, sessp->cfd);
#endif

            if(sessp->reqlen<4) {
                chk = DoReadReqFirst(dnum, sessp);
            }
            else
            if(sessp->reqlen > L_REQBUF) {
                Error("request is too large");
                sessp->reason = R_TOOLONG_URL;
                goto ignore;
            }
            else {
                chk = DoReadReqRest(dnum, sessp);
            }

            if(sessp->state==STATE_MESSAGE)
                goto ignore;

            if(chk) {
                Error("handler: fail client request parsing");
                goto fail;
            }
        }

        if(sessp->state!=STATE_THINK) {
            if(sessp->state==STATE_RECV_REQ) {
                Error(
"listener: sess# %d, sread %ld cwrite %ld, still in STATE_RECV_REQ",
                    sessp->sid, (long)sessp->sread, (long)sessp->cwrite);
            }
            else {
                Trace("listener: after ReadReqXXX, sess# %d, state %d\n",
                    sessp->sid, MSG_STATE_[sessp->state]);
            }
            break;
        }

    case STATE_THINK:
        handler_phase[dnum] = 120;

        chk = DoThink(dnum, sessp);
        if(chk) {
            if(chk==-1) {
                sessp->reason = R_SOME_FATAL_ERROR;
                sessp->state = STATE_MESSAGE;
                goto ignore;
            }

            Error("Hmain: fail session dicision");
            goto fail;
        }

        handler_phase[dnum] = 1201;

        switch(sessp->state) {
        case STATE_REPORT:
            handler_phase[dnum] = 1211;
            DoReport(sessp);
            DoCloseSess(sessp);
            DoReleaseSess(sessp);
            sessp = NULL;
            handler_phase[dnum] = 1219;
            goto out;

        case STATE_WAIT_FRIEND:
            break;

        case STATE_WAIT_SWAPIN:
            handler_phase[dnum] = 1221;
            qn = SWSOLV(sessp->fhash);

            chk = push_sess(swap_queue[qn], sessp);
            if(chk) {
                Error("Hmain: fail push bk# %d, sess# %d, to swapin Q[%d]",
                    sessp->fhash, sessp->sid, qn);
            }
            sessp = NULL;
            handler_phase[dnum] = 1229;
            goto out;

            break;

        case STATE_QUERY_ADDR:
            handler_phase[dnum] = 1231;
            DoFindServer(dnum, sessp);

            if(sessp->state==STATE_CONN_SERV) {
                DoServerConnect(dnum, sessp);
            }

            handler_phase[dnum] = 1239;
            break;

        case STATE_SEND_CACHE:
            handler_phase[dnum] = 1241;
            DoSendCache(dnum, sessp);

            if(sessp->state==STATE_QUERY_ADDR) {
                goto start_fetch;
            }
            handler_phase[dnum] = 1249;
            break;

        case STATE_MESSAGE:
            goto ignore;

 /*NOTREACHED*/
            break;

        case STATE_DONE:
        case STATE_CLOSE:
            goto done;

        /* XXX */
        case STATE_THINK:
            handler_phase[dnum] = 1280;
            goto conn;

        default:
            Error("Hmain: sess# %d, strange state (%d) after DoThink() ",
                sessp->sid, sessp->state);
            goto fail;
        }

        handler_phase[dnum] = 1209;
        break;

    case STATE_CLOSE:
    case STATE_DONE:
        handler_phase[dnum] = 190;
        goto done;

 /*NOTREACHED*/
        break;

    case STATE_WAIT_FRIEND:
        handler_phase[dnum] = 130;
        DoCheckEndFriendSess(dnum, sessp);

        break;

    case STATE_SEND_CACHE:
        handler_phase[dnum] = 150;
        DoSendCache(dnum, sessp);

        if(sessp->state==STATE_QUERY_ADDR) {
            goto start_fetch;
        }

        break;

    case STATE_QUERY_ADDR:
start_fetch: (void)1;
        handler_phase[dnum] = 140;

        DoFindServer(dnum, sessp);
        if(sessp->state==STATE_CONN_SERV) {
            DoServerConnect(dnum, sessp);
        }

        break;

    case STATE_WAIT_ADDR:
        handler_phase[dnum] = 141;

        chk = hcache_recv_response_addr_direct(sessp->servername,
            &(sessp->serveraddr), &sessp->rfd);
        if(chk) {
            Error("fail hcache_recv_response_addr_direct() to '%s', ret %d <%d>",
                sessp->servername, chk, sessp->rcount);

            sessp->rcount--;
            if(sessp->rcount>0) {
                sessp->state = STATE_QUERY_ADDR;
                goto start_fetch;
            }

            sessp->reason = R_RESOLVER_ERROR;
            sessp->state = STATE_MESSAGE;
        }
        else {
            struct timeval curtime;
            int takes;

            gettimeofday(&curtime, NULL);
            takes = KOTETU_SUB_TIME(curtime, sessp->r_start);

            if(takes>0) {
                sim_stat_add_value(&hname_rtime_stat, (long)takes);
            }
            
#ifdef TRACE_HCACHE
#endif
#if 0
            Trace("hand: got address in %d msec for '%s'\n",
                takes, sessp->servername);
#endif

            chk = hcache_set_addr_incache(
                    sessp->servername, &(sessp->serveraddr));
            sessp->state = STATE_CONN_SERV;
        }

        if(sessp->rfd>=0) {
            shutdown(sessp->rfd, 2);
            close(sessp->rfd);
            sessp->rfd = -1;
        }

        if(sessp->state!=STATE_CONN_SERV) {
            goto ignore;
        }

    case STATE_CONN_SERV:
        handler_phase[dnum] = 142;

        DoServerConnect(dnum, sessp);

        break;

    case STATE_WAIT_CONN_SERV:
    case STATE_SEND_REQUEST:
        handler_phase[dnum] = 143;
        DoSendRequest(dnum, sessp);

        break;

    case STATE_RECV_RES:
        handler_phase[dnum] = 200;

        DoServerReply(dnum, sessp);

        break;

    case STATE_RELAY_DIRECT:
        handler_phase[dnum] = 160;

        DoRelayDirect(dnum, sessp);

        handler_phase[dnum] = 167;
        break;


    default:
        handler_phase[dnum] = 200;
        Error("Hmain: strange state (%d) ", sessp->state);
        goto fail;

    } /* end of state switch */


    if(sessp!=NULL &&
        sessp->state==STATE_MESSAGE) {
        goto ignore;
    }

#if 0
    if(sessp && sessp->method==M_POST) {
    Trace("hand: th# %x, sess# %d, state %s\n", 
        pthread_self(), sessp->sid, MSG_STATE_[sessp->state]);
    }
#endif

done:
    handler_phase[dnum] = 193;


    if(sessp!=NULL &&
        (sessp->state==STATE_CLOSE || sessp->state==STATE_DONE)) {

#if 0
    Trace("Hmain: done, sess# %d, re-push to think Q\n", sessp->sid);
#endif

#if 0
        if(sessp && sessp->method==M_POST) {
        Trace("hand: th# %x, sess# %d, state %s ; call DoCloseSess()\n", 
            pthread_self(), sessp->sid, MSG_STATE_[sessp->state]);
        }
#endif

        DoCloseSess(sessp);

        chk = MUTEX_LOCK(&config_lock);
        cv = prefetch_flag;
        chk = MUTEX_UNLOCK(&config_lock);

#ifdef TRACE_PREFETCH
        if(!cv) {
            Trace("Hmain: prefetch is disabled\n");
        }
        else
#endif

        if(cv &&
            (sessp->level<2 && sessp->rcode>=200 && sessp->rcode<=399) ) {
/*
        sessp->sread > 8
        sessp->swrite > 10
 */

            pending = DoParseAnchor(dnum, sessp);
            if(pending) {
                Trace("Hmain: pending sess# %d\n", sessp->sid);
            }
        }
#ifdef TRACE_PREFETCH
        else {
            Trace("Hmain: sess# %d, skip parse object content [level %d, rcode %d]\n",
                sessp->sid, sessp->level, sessp->rcode);
        }
#endif

        MUTEX_LOCK(&stat_lock);
        process_request_count++;
        MUTEX_UNLOCK(&stat_lock);

        release_buf(sessp, 1);

        DoReleaseSess(sessp);
        sessp = NULL;

        goto out;
    }


    goto conn;

ignore:
#if 0
    Trace("Hmain: ignore, sess# %d, close.\n", sessp->sid);
#endif


    DoSendMessage(sessp);
    sessp->state = STATE_CLOSE;

    DoCloseSess(sessp);
    DoReleaseSess(sessp);
    sessp = NULL;

    goto out;

fail:
#if 0
    Trace("Hmain: fail, sess# %d, close.\n", sessp->sid);
#endif


    DoCloseSess(sessp);
    DoReleaseSess(sessp);
    sessp = NULL;


    goto out;

conn:
    handler_phase[dnum] = 197;
    if(sessp!=NULL) {

        chk = push_sess(think_queue, sessp);
        if(chk) {
            Error("Hmain: sess# %d, fail re-push to think Q", sessp->sid);

            sessp->reason = R_MEMORY_OVERFLOW;
            DoSendMessage(dnum, sessp);
            DoCloseSess(sessp);
            DoReleaseSess(sessp);
            sessp = NULL;
        }
        else {
            sessp = NULL;
        }

    }

    goto out;

out:
    chk = 0;
    handler_phase[dnum] = 199;

    return NULL;
}

/* end of Hmain */



#ifndef GC_MIN_INTERVAL
#define GC_MIN_INTERVAL (2)
#endif

int gc_min_interval = GC_MIN_INTERVAL; /* in seconds */

int
BucketKicker(int dnum)
{
    int rb, bb;
    int b;
    bucket_t *bk;
    int chk;
    int reason;
    int pb;
    int pb_use;
    int now;

    handler_phase[dnum] = 800;

    rb = rand()%radix_h1;
    bb = rb+radix_h1;
    pb = -1;
    pb_use = -1;
    now = time(NULL);

    handler_phase[dnum] = 807;

    for(;rb<bb;rb++) {
        b = rb%radix_h1;
        bk = &skcache_bucket_base[b];
        
#if 0
        Trace(" %4d: %d: use %7d, diff %5d %d\n",
            b, bk->gc_push, bk->entry_use,
            now - bk->gc_last, gc_min_interval);
#endif
        if(bk->gc_last>0 && bk->gc_push <=0
            && now - bk->gc_last > gc_min_interval) {
            if(bk->entry_use > pb_use) {
                pb = b;
                pb_use = bk->entry_use;
            }
        }
    }


    if(pb>=0) {
        bk = &skcache_bucket_base[pb];

        Trace("BucketKicker: hand# %d, target bk# %d,\n", dnum, bk->bid);
        reason = 11;
        sim_stat_add_value(&reaper_call_reason, (long)reason);
        handler_phase[dnum] = 810;
        LOCK_BK(bk);
        chk = reaper(dnum, bk, bk->entry_all/4, 1, 1, pthread_self());
        UNLOCK_BK(bk);
        Trace("BucketKicker: hand# %d, returned %d\n", chk);
    }

out:
    handler_phase[dnum] = 899;

    return 0;
}






inline
int
check_timeout(sess_t *sessp, time_t now)
{
    int ret;
    int idle, elap;

    ret = 0;

    idle = now - sessp->last_action;
    elap = now - sessp->accept_time.tv_sec;

    switch(sessp->state) {
    case STATE_ACCEPT:
    case STATE_RECV_REQ:
#if 0
    Trace("check_timeout: sess# %d, now %d, idle %d, elap %d, reqlen %d\n",
        sessp->sid, now, idle, elap, sessp->reqlen);
#endif
        if(sessp->last_action == sessp->accept_time.tv_sec) {

            if(sessp->reqlen>0) {
#if 0
    Trace("    Is it empty request ?\n");
#endif
            }

            if(idle > RECEPT_TIMEOUT*3) {
                sessp->reason = R_CLIENT_TIMEOUT;
                ret = 1;
            }
        }
        else
        if(idle > RECEPT_TIMEOUT) {
            sessp->reason = R_CLIENT_TIMEOUT;
            ret = 1;
        }
        break;
    case STATE_WAIT_FRIEND:
        if(idle > WFRIEND_TIMEOUT) {
            sessp->reason = R_WFRIEND_TIMEOUT;
            ret = 1;
        }
        break;
    case STATE_WAIT_CONN_SERV:
    case STATE_RECV_RES:
        if(idle > FETCH_TIMEOUT) {
            sessp->reason = R_SERVER_TIMEOUT;
            ret = 1;
        }
        break;
    default:
        if(idle > ELSE_TIMEOUT) {
            sessp->reason = R_TIMEOUT;
            ret = 1;
        }
        break;
    }

    if(ret==0) {
        if(elap > SESSION_TOTAL_TIMEOUT) {
            sessp->reason = R_TIMEOUT;
            ret = 1;
        }
    }

#if 0
if(ret!=0) {
    Trace("sess# %d, elap/idle %d/%d -> reason %d, ret %d\n",
        sessp->sid, elap, idle, sessp->reason, ret);
}
#endif

    return ret;
}






#ifndef BMRADIX
#define BMRADIX     (53)
#endif
#define DFC         ((bk->bid)%BMRADIX==1)

static pthread_mutex_t reaper_gate_lock = PTHREAD_MUTEX_INITIALIZER;
static int reaper_gate[RADIX_H1_MAX];


/*
 *
 * dnum     - number of order. 0 means first thread.
 * bk_use   - bitmask, bucket is used or not.
 */


void
check_ocache_area(int dnum, int bk_use[])
{
    time_t now;
    int i;
    int focus;

    /*** 
     *** clean-up bucket on memory and directories in disk
     ***/

    now = time(NULL);



    /******
     ****** Apply reaper() to bucket.
     ****** Since entry lack is depend on bucket,
     ****** target is selected by utilization.
     ******/


    for(i=0;i<radix_h1;i++) {
        bucket_t *bk;
        int chk;
        sess_t *tsessp;
        int qn;
        int xn;
        int reason;
        int diff_chk, diff_last;

        reason = 0;
        tsessp = NULL;
        qn = -1;

        bk = &skcache_bucket_base[i];
        handler_focus[dnum] = bk->bid;

        diff_chk = now - (bk->gc_checkpoint>0 ?
                bk->gc_checkpoint: boot_date);
        if(diff_chk < 0) {
            diff_chk = 0;
        }

        diff_last = now - (bk->gc_last>0 ? bk->gc_last : boot_date);

#if 1
        if(bk_use[i]<=0) {
            continue;
        }
#endif

        if(bk->gc_push) {
            continue;
        }
        if(bk->entry_use > bk->entry_hhwater) {
            reason = 22;
        }

#if 0
        if(bk_use[i]<=0 && reason==0) {
            continue;
        }
#endif

#if 0
 if(dnum==0) {
        Trace("enter reaper calling %d bk# %d, reason %d\n",
            i, bk->bid, reason);
 }
#endif

        /* if gc_push is setted, the bucket is busy, maybe */
        if(bk->gc_push) {
            goto next_bk;
        }



        handler_phase[dnum] = 70;

        chk = hold_screend_flag(&reaper_gate_lock,
                &reaper_gate[bk->bid], dnum);

        /* loose or fail */
        if(chk) {
            handler_phase[dnum] = 77;
#if 0
            Trace("slave# %d, hold bk# %d, loose\n", dnum, bk->bid);
#endif
            if(chk<0) {
                Error("slave# %d, hold bk# %d, fail", dnum, bk->bid);
            }
            goto next_bk;
        }

#if 0
        Trace("slave# %d, win bk# %d, shift locking of bucket\n", 
            dnum, bk->bid);
#endif



        handler_phase[dnum] = 71;
        LOCK_BK(bk);
        handler_phase[dnum] = 72;

#if 0
        if(bk->gc_push) {
            goto skip_reaper_reservation;
        }
#endif

        if(reason) {
            goto reserve_reaper;
        }

        if(diff_last < gc_min_interval) {
            /* nothing */
        }
        else 
        if(bk->gc_ntarget>0) {
            reason = 100;
        }
        else
        if(bk->entry_use > bk->entry_hwater) {
            reason = 21;
        }
        else {
            /* nothing */
        }

#if 0
/*
if(dnum==0 && reason>0) 
*/
if(dnum==0)
 {
        Trace("enter reaper calling %d bk# %d, bk_use %d, reason %d\n",
            i, bk->bid, bk_use[i], reason);
 }
#endif

        if(reason>0) {

reserve_reaper:
            qn = SWSOLV(bk->bid);

            if(reason==12) {
             Trace(
    " *** emargency, frag lack 2 bk# %d, swQ# %d, frag use %d water hh/h %d/%d\n",
                bk->bid, qn,
                frag_use, frag_hhwater, frag_hwater);
            }
            if(reason==22) {
             Trace(
    " *** emargency, entry lack 2 bk# %d, swQ# %d, entry use %d water hh/h %d/%d\n",
                bk->bid, qn,
                bk->entry_use, bk->entry_hhwater, bk->entry_hwater);
            }


#ifdef TRACE_REAPER
#endif
 if(DFC) {
 Trace("slave# %d: reserve reaper calling bk# %d, reason %d, entry u %d h %d ; nt %d ; p %d ; diff_chk %d, diff_last %d\n",
 dnum, bk->bid, reason,
 bk->entry_use, bk->entry_hwater, bk->gc_ntarget,  bk->gc_push,
 diff_chk, diff_last);
 }

            sim_stat_add_value(&reaper_call_reason, (long)reason);


            MUTEX_LOCK(&stat_lock);
            reaper_called++;
            MUTEX_UNLOCK(&stat_lock);

            bk->own = 'M';

#if 0
            if(reason==12 || reason==22 || reason==11 || reason==21)
#endif
            if(reason==12 || reason==22)
            {
#if 0
Trace("  bk# %d, quick sweeping\n", bk->bid);
#endif

                handler_phase[dnum] = 13;
                chk = reaper(dnum, bk, -1, 1, DFC, pthread_self());
            }
            else {
                handler_phase[dnum] = 14;
                chk = reaper(dnum, bk, -1, 0, DFC, pthread_self());

            }
#if 0
#ifdef TRACE_REAPER
Trace("slave: th# %d, reaper() done %d\n", dnum, chk);
#endif
#endif

            bk->own = ' ';
            bk->gc_push = 0;
        }

skip_reaper_reservation:
        handler_phase[dnum] = 15;

        bk->dirpos = (bk->dirpos + 1 ) %radix_h2;
        focus = bk->dirpos;

        UNLOCK_BK(bk);


        handler_phase[dnum] = 78;

        chk = release_screend_flag(&reaper_gate_lock,
                &reaper_gate[bk->bid], dnum);

        /* loose or fail */
        if(chk) {
            handler_phase[dnum] = 77;
            Trace("slave# %d, release bk# %d, loose\n", dnum, bk->bid);
            if(chk<0) {
                Error("slave# %d, release bk# %d, fail", dnum, bk->bid);
            }
        }

        handler_phase[dnum] = 79;




#if 1

        /***
         *** sweep directories
         ***/

      {
        int p, q, r, qrange;
        int e2, e1, e3;
        int dcount, dtime;
        int dlack;
        long long dsize;
        time_t now;
        int difftime;

        now = time(NULL);

#if 0
        dlack_limit = 3*OFILE_NBLK_FILE/100;
#endif
#if 0
        dlack_limit = 8;
#endif
#if 1
        dlack_limit = 10*OFILE_NBLK_FILE/100;
#endif

        qrange = radix_h2;

        q = focus;
        r = -1;

        e1 = bk->bid;
        e2 = q;
        e3 = 0;
        p = DSIG_POS(e1, e2, e3);

#if 0
        Trace("slave# %d: e1,e2,e3 = %d,%d,%d\n", dnum, e1, e2, e3);
#endif
        handler_phase[dnum] = 82;
        MUTEX_LOCK(&dir_mutex);
        handler_phase[dnum] = 83;

        dtime   = dir_time[p];
        dcount  = dir_count[p];
        dsize   = (long long) dir_sz[p];
        dlack   = dir_lack[p];
        
        if(dir_lock[p]> 0) {
            r  = -1;
            handler_phase[dnum] = 84;
            goto dir_notfound;
        }

        /* not GCed */
        if(dtime<0) {
            difftime = now - boot_date;
        }
        else {
            difftime = now - dtime;
        }
        if(difftime >= DSIG_MIN_GAP && dsize > dir_size_hwater ) {
            r = p;
            goto dir_found;
        }
#if 0
        /* add random factor */
        difftime += rand()%(skcache_signature_refresh/5);
#endif

        if(difftime >= skcache_signature_refresh) {
            r = p;
            goto dir_found;
        }

        if(dlack> dlack_limit) {
            Trace("slave# %d, dir# %d, too many lack %d/%d\n",
                dnum, p, dlack, dlack_limit);
            r = p;
            goto dir_found;
        }

        handler_phase[dnum] = 85;
        goto dir_notfound;

dir_found:
        handler_phase[dnum] = 87;
        dir_lock[p] = pthread_self();
        r = p;

dir_notfound:
        MUTEX_UNLOCK(&dir_mutex);


        if(r>=0) {
#ifdef TRACE_CHKDIR
Trace("  call chkdir slave# %d, dir# %d, [%d:%d:%d] time %d [%d,%d] %df %lldB %.2fKB / %.2fKB\n", 
                dnum, r, e1, e2, e3,
                difftime, DSIG_MIN_GAP, skcache_signature_refresh,
                dcount,
                (long long)dsize, fdK(dsize), fdK(dir_size_hwater));
#endif

            handler_phase[dnum] = 25;
            chk = skcache_check_dir(e1, e2, e3, 1);
            handler_phase[dnum] = 26;

            MUTEX_LOCK(&dir_mutex);
            handler_phase[dnum] = 27;
            dir_lock[r] = 0;
            MUTEX_UNLOCK(&dir_mutex);
        }

        handler_phase[dnum] = 29;

      }

#endif


next_bk:
    (void)0;

    } /* for, clean-up loop */

}








#if 0
#define CHECK {\
    int k;\
    Trace("w_sess_count %d, w_fd_count %d\n", w_sess_count, w_fd_count);\
    if(w_sess_count>0) {\
        Trace("index sess     sid#  state           |cfd   sfd\n");\
        for(k=0;k<w_sess_count;k++) {\
            if(sess_chunk[k]) \
                Trace("%5d %8x %5d %-15s |%5d %5d \n",\
                    k, sess_chunk[k],\
                    sess_chunk[k]->sid, MSG_STATE_[sess_chunk[k]->state],\
                    sess_chunk[k]->cfd, sess_chunk[k]->sfd\
                    );\
            else\
                Trace("%5d empty\n", k);\
        }\
    }\
    else {\
        Trace("***no sessions\n");\
    }\
    if(w_fd_count>0) {\
        Trace("\nindex fd    |sess   sid# state\n");\
        for(k=0;k<w_fd_count;k++) {\
            if(bound[k]) \
                Trace("%5d %5d |%8x %5d %-15s\n",\
                    k, fdrec[k].fd,\
                    bound[k], bound[k]->sid, MSG_STATE_[bound[k]->state]);\
            else\
                Trace("%5d %5d empty\n", k, fdrec[k].fd);\
        }\
    }\
    else {\
        Trace("***no fds\n");\
    }\
    Trace("= = \n");\
}

#else
#define CHECK   ((void)0)
#endif

static
int
sess_comp(const void *ap, const void *bp)
{
    sess_t *a = *(sess_t**)ap;
    sess_t *b = *(sess_t**)bp;

    if(a->fhash==b->fhash) {
        return a->shash - b->shash;
    }
    else {
        return a->fhash - b->fhash;
    }
}



/***
 *** Handler is most diffcult code in KOTETU.
 *** It get many sessions and make structure for poll().
 *** After poll(), it dispatches bounded sessions to Hmain().
 ***/


void*
Handler(void *dummy)
{
    time_t now;
    int w_sess_max;
    int w_sess_count;
    int w_fd_count;
    int timeout_count;
    sess_t *sess_chunk[NSESS_HANDLER_MAX];
    int proc_class[NSESS_HANDLER_MAX];
    struct pollfd fdrec[NSESS_HANDLER_MAX*2];
    sess_t *bound[NSESS_HANDLER_MAX*2];
    int bk_use[RADIX_H1_MAX];
    int i, j;
    int chk;
    int try;
    int touched;
    int same;

    int focus;
    int c;

    int miss_capability=4;

    int sq_show_w_lock(FILE*, sess_queue_t*);

    int w;
    int dnum;
    int htic=0;


    dnum = (int)dummy;

#if 0
Trace("Handler: pr %d, th %d\n", getpid(), pthread_self());
#endif

    w_sess_max = require_nsess_handler;

    /* forever loop */
    while(1) {
        htic++;
        handler_focus[dnum] = -1;
        handler_phase[dnum] = -1;
/*
        MUTEX_LOCK(&config_lock);
        MUTEX_UNLOCK(&config_lock);
*/
        FCHK();

        timeout_count = 0;
        w_sess_count = 0;
        w_fd_count = 0;

        for(i=0;i<NSESS_HANDLER_MAX;i++) {
            sess_chunk[i] = NULL;
            proc_class[i] = 0;
        }
        for(i=0;i<NSESS_HANDLER_MAX*2;i++) {
            bound[i] = NULL;
        }
        for(i=0;i<RADIX_H1_MAX;i++) {
            bk_use[i] = 0;
        }

        w_sess_count = sq_pullchunk(think_queue, sess_chunk, w_sess_max);

        handler_phase[dnum] = 1;

        if(w_sess_count<=0) {
            goto next_turn;
        }
        now = time(NULL);
        handler_beacon[dnum] = now;

#if 1
        if(frag_use<0 || frag_use>frag_all) {
            Error("hand: epoch %d, frag part was broken", now);
        }
#endif


#if 0
        j = 0;
        for(i=0;i<w_sess_count;i++) {
            if(sess_chunk[i]) {
                j++;
                Trace("hand: BEGIN th# %x, %d:%d, sess# %d, %s,fd# %d/%d/%d\n",
                    pthread_self(), htic, i,
                    sess_chunk[i]->sid,
                    MSG_STATE_[sess_chunk[i]->state],
                    sess_chunk[i]->cfd, sess_chunk[i]->sfd, sess_chunk[i]->rfd);
            }
        }
        Trace("hand: BEGIN th# %x, %d:-, j %d\n",
            pthread_self(), htic, j);
#endif

#if 0
        for(i=0;i<w_sess_count;i++) {
            if(sess_chunk[i] && sess_chunk[i]->method==M_POST) {

                /* count other fds is bounded to same session */
                same = 0;
                for(j=0;j<w_fd_count;j++) {
                    if(j!=i && sess_chunk[j]
                            && sess_chunk[j]==sess_chunk[i]) {
                        same++;
                    }
                }
                Trace(
    "hand: th# %d, %d:%d, got POST from thinkQ; sess# %d, same %d\n",
                    pthread_self(), htic, i, sess_chunk[i]->sid, same);
            }
        }
#endif

        /*
         *
         */
        for(i=0;i<w_sess_count;i++) {
            if(sess_chunk[i]) {
                if(sess_chunk[i]->fhash>=0) {
                    bk_use[sess_chunk[i]->fhash]++;
                }
            }

            if(sess_chunk[i]->last_action>0
                && check_timeout(sess_chunk[i], now)) {

#if 1
                /* XXX */
                if(sess_chunk[i]->reason==R_WFRIEND_TIMEOUT) {
Trace("sess# %d, switch wait FRIEND to retrieve\n", sess_chunk[i]->sid);
Log("sess# %d, switch wait FRIEND to retrieve", sess_chunk[i]->sid);
/*
*/
                    proc_class[i] = 0x2000;
                    sess_chunk[i]->state = STATE_QUERY_ADDR;
                    sess_chunk[i]->cachable = SESS_UNCACHABLE;

                    continue;
                }
#endif

#if 0
        if(sess_chunk[i]->cache_entry &&
            ((skcache_entry_t*)sess_chunk[i]->cache_entry)->ref<=0) {
            Trace("target is already reg ref %p %d %s %d\n",
                sess_chunk[i]->cache_entry,
                ((skcache_entry_t*)sess_chunk[i]->cache_entry)->ref,
                __FILE__, __LINE__ );
        }
#endif

                proc_class[i] = 0x008;

                release_buf(sess_chunk[i], 1);
                DoTimeoutClose(sess_chunk[i]);
                DoReleaseSess(sess_chunk[i]);
                timeout_count++;

                sess_chunk[i] = NULL;

                continue;
            }


            switch(sess_chunk[i]->state) {
            case STATE_IDLE:
                break;
            case STATE_ACCEPT:
            case STATE_RECV_REQ:
                fdrec[w_fd_count].fd = sess_chunk[i]->cfd;
                fdrec[w_fd_count].events = POLLIN | POLLRDNORM;
                fdrec[w_fd_count].events |= POLLERR;

                bound[w_fd_count] = sess_chunk[i];
                w_fd_count++;
                break;

            case STATE_WAIT_ADDR:
                fdrec[w_fd_count].fd = sess_chunk[i]->rfd;
                fdrec[w_fd_count].events = POLLIN | POLLRDNORM;
                fdrec[w_fd_count].events |= POLLERR;

                bound[w_fd_count] = sess_chunk[i];
                w_fd_count++;
                break;

            case STATE_WAIT_CONN_SERV:
                fdrec[w_fd_count].fd = sess_chunk[i]->sfd;
                fdrec[w_fd_count].events = POLLOUT | POLLWRNORM;
                fdrec[w_fd_count].events |= POLLERR;

                bound[w_fd_count] = sess_chunk[i];
                w_fd_count++;
                break;

            case STATE_RECV_RES:
                fdrec[w_fd_count].fd = sess_chunk[i]->sfd;
                fdrec[w_fd_count].events = POLLIN | POLLRDNORM;
                fdrec[w_fd_count].events |= POLLERR;

                bound[w_fd_count] = sess_chunk[i];
                w_fd_count++;
                break;

            case STATE_RELAY_DIRECT:
                fdrec[w_fd_count].fd = sess_chunk[i]->cfd;
                fdrec[w_fd_count].events = POLLIN | POLLRDNORM;
                fdrec[w_fd_count].events |= POLLERR;

                bound[w_fd_count] = sess_chunk[i];
                w_fd_count++;

                fdrec[w_fd_count].fd = sess_chunk[i]->sfd;
                fdrec[w_fd_count].events = POLLIN | POLLRDNORM;
                fdrec[w_fd_count].events |= POLLERR;

#if 1
                bound[w_fd_count] = NULL;
#else
                bound[w_fd_count] = sess_chunk[i];
#endif
                w_fd_count++;
                break;

            default:
#ifdef TRACE_SCHEDULE
                Trace("Handler: thread %x, sess# %d, mode %c, state strange %s\n",
                    pthread_self(),
                    sess_chunk[i]->sid,
                    sess_chunk[i]->mode==MODE_CLIENT ? 'c': 's',
                    MSG_STATE_[sess_chunk[i]->state]);
#endif
                break;
            }
        }


#ifdef TRACE_SCHEDULE
#if 0
        Trace("th %d, w_sess_count/max %d/%d w_fd_count %d\n",
            pthread_self(), w_sess_count, w_sess_max, w_fd_count);
#endif

        /*
        Trace("\nbefore ***\n");
        CHECK;
        */
#endif


        if(w_fd_count<1) {
            goto dispatch_by_sess;
        }

        handler_phase[dnum] = 2;

        /***
         *** the poll()
         ***/
        c = 0;
try_poll:
        c++;
        chk = poll(fdrec, w_fd_count, 1000); /* 1000msec = 1sec */

        handler_phase[dnum] = 97;

#ifdef TRACE_SCHEDULE
        if(timeout_count) {
            Trace("Handler: <%08x> query/receive/timeout %4d/%4d/%4d\n",
                pthread_self(), w_fd_count, chk, timeout_count);
        }
#endif

        /***
         *** fail poll()
         ***/
        if(chk<=0) {
            if(chk<0) {
                if(errno==EINTR && c<24) {
                    goto try_poll;
                }
                Error("fail poll() %d (%d)", c, errno);
                if(errno==ENOMEM) {
                    msleep(1);
                }
            }

            for(i=0;i<w_fd_count;i++) {
                if(bound[i] && bound[i]->state==STATE_RELAY_DIRECT
                    && fdrec[i].fd==bound[i]->sfd) {
#if 0
                    Trace("hand: th# %d, i %d, sess# %d, remove\n",
                        pthread_self(), i, bound[i]->sid);
#endif
                    bound[i] = NULL;
                }
            }

            for(i=0;i<w_fd_count;i++) {
                if(bound[i]) {
                    chk = push_sess(think_queue, bound[i]);
                    if(chk) {
                        bound[i]->reason = R_MEMORY_OVERFLOW;

                        DoSendMessage(bound[i]);
                        DoCloseSess(bound[i]);

#if 0
        if(bound[i]->cache_entry &&
            ((skcache_entry_t*)bound[i]->cache_entry)->ref<=0) {
            Trace("target is already reg ref %p %d %s %d\n",
                bound[i]->cache_entry,
                ((skcache_entry_t*)bound[i]->cache_entry)->ref,
                __FILE__, __LINE__ );
        }
#endif


                        release_buf(bound[i], 1);
                        DoReleaseSess(bound[i]);
                    }
                    for(j=0;j<w_sess_count;j++) {
                        if(sess_chunk[j] && sess_chunk[j]==bound[i]) {
                            proc_class[j] += 0x1000;
                            sess_chunk[j] = NULL;
                        }
                    }
                    bound[i] = NULL;
                }
            }

            goto dispatch_by_sess;
        }


dispatch_by_fd:

        /***
         *** success poll()
         ***/

        handler_phase[dnum] = 3;

#if 0
        for(i=0;i<w_sess_count;i++) {
            if(sess_chunk[i]) 
                Trace("th# %x, b sessmap %d, sess# %d, %s fd# c/s/r %d %d %d\n",
                    pthread_self(), i, 
                    sess_chunk[i]->sid, MSG_STATE_[sess_chunk[i]->state],
                    sess_chunk[i]->cfd, sess_chunk[i]->sfd, sess_chunk[i]->rfd
                );
            else
                Trace("th# %x, b sessmap %d, sess# %d,\n",
                    pthread_self(), i, -1);
        }
        for(i=0;i<w_fd_count;i++) {
            Trace("th# %x, b fdmap %d, fd# %d, %03x; sess# %d,\n",
                pthread_self(), i, fdrec[i].fd, fdrec[i].revents,
                bound[i] ? bound[i]->sid : -1);
        }
#endif

        for(i=0;i<w_fd_count;i++) {
            if(!bound[i])
                continue;

            /* XXX little trick */
            /*
             * if current session is client side session for POST
             * and next session is server side session,
             * fake next session as 'client readable'
             * and clear server side session.
             * because it is maybe danger.
             * if server side session is alive,
             * this routine means sesssion amplifier.
             */
            if(bound[i]->state==STATE_RELAY_DIRECT
                && fdrec[i].fd==bound[i]->cfd) {

#if 0
                Trace(
    "hand: th# %x, i# %d, fd# %d, c-side of sess %p, sess# %d, fd# %d/%d\n",
        pthread_self(), i, fdrec[i].fd,
        bound[i], bound[i]->sid, bound[i]->cfd, bound[i]->sfd);
#endif

                for(j=0;j<w_fd_count;j++) {
#if 0
    if(bound[j]) {
                    Trace(
    "hand: th# %x, ?s-side j# %d, fd# %d, sess %p, sess# %d, sfd# %d\n",
        pthread_self(), j, fdrec[j].fd, bound[j], bound[j]->sid, bound[j]->sfd);
    }
    else {
                    Trace(
    "hand: th# %x, ?s-side j# %d, fd# %d, sess NULL\n",
        pthread_self(), j, fdrec[j].fd);
    }
#endif

                    if(fdrec[j].fd==bound[i]->sfd
                        && fdrec[j].revents & POLLIN) {
                        fdrec[i].revents |= POLLIN;
                    }
                }
            }
        }

#if 0
        for(i=0;i<w_sess_count;i++) {
            if(sess_chunk[i]) 
                Trace("th# %x, a sessmap %d, sess# %d, %s fd# c/s/r %d %d %d\n",
                    pthread_self(), i,
                    sess_chunk[i]->sid, MSG_STATE_[sess_chunk[i]->state],
                    sess_chunk[i]->cfd, sess_chunk[i]->sfd, sess_chunk[i]->rfd
                );
            else
                Trace("th# %x, a sessmap %d, sess# %d,\n",
                    pthread_self(), i, -1);
        }
        for(i=0;i<w_fd_count;i++) {
            Trace("th# %x, a fdmap %d, fd# %d, %03x; sess# %d,\n",
                pthread_self(), i, fdrec[i].fd, fdrec[i].revents,
                bound[i] ? bound[i]->sid : -1);
        }
#endif

        for(i=0;i<w_fd_count;i++) {
            touched = 0;

            if(bound[i]==NULL) {
                continue;
            }

#if 0
            /* count other fds is bounded to same session */
            same = 0;
            for(j=0;j<w_fd_count;j++) {
                if(j!=i && bound[j] && bound[j]==bound[i]) {
                    same++;

                    Trace(
                        "hand: th# %d, %d:%d, sess# %d, same %d ; bound[%d]",
                        pthread_self(), htic, i, bound[i]->sid, same, j);
                }
            }
#endif

            /*
             * server connect when state WAIT_CONN_SERV
             * otherwise, receive anything from server or shutdown arrival
             */
            if(
                (bound[i]->state==STATE_WAIT_CONN_SERV
                    && fdrec[i].revents & (POLLOUT | POLLERR) )
                  ||(bound[i]->state!=STATE_WAIT_CONN_SERV
                    && fdrec[i].revents & (POLLHUP | POLLIN) )
                ) {

#if 0
                if(fdrec[i].revents & POLLHUP) {
                    Trace("got POLLHUP sess# %d, %s\n",
                        bound[i]->sid, MSG_STATE_[bound[i]->state]);
                }
#endif

                if(bound[i]->cache_entry) {
                    handler_focus[dnum] = bound[i]->fhash;
                }
                else {
                    handler_focus[dnum] = -1;
                }

#if 0
                Trace("hand: th# %x, %d:%d - call Hmain fd# %d, sess# %d, %s\n",
                    pthread_self(), htic, i,
                    fdrec[i].fd, bound[i]->sid,
                    MSG_STATE_[bound[i]->state]);
#endif
#ifdef TRACE_SCHEDULE
#endif

#if 1
                for(j=0;j<w_sess_count;j++) {
                    if(sess_chunk[j] && sess_chunk[j]==bound[i]) {
                        proc_class[j] += 0x001;
                    }
                }
#endif

                handler_phase[dnum] = 41;
                Hmain(dnum, bound[i], now);
                handler_phase[dnum] = 42;

#if 0
                Trace("hand: th# %x, %d:%d - done Hmain fd# %d, sess %p, sess# %d, %s\n",
                    pthread_self(), htic, i,
                    fdrec[i].fd, bound[i], bound[i]->sid,
                    MSG_STATE_[bound[i]->state]);
#endif
#ifdef TRACE_SCHEDULE
#endif

                touched = 1;

            }
            else {

#if 1
                if(fdrec[i].revents & POLLHUP) {
                    Trace("got POLLHUP sess# %d, %s\n",
                        bound[i]->sid, MSG_STATE_[bound[i]->state]);
                }
#endif
#if 1
                if(fdrec[i].revents & POLLERR) {
                    Trace("got POLLERR sess# %d, %s\n",
                        bound[i]->sid, MSG_STATE_[bound[i]->state]);
                }
#endif

#if 1
                for(j=0;j<w_sess_count;j++) {
                    if(sess_chunk[j] && sess_chunk[j]==bound[i]) {
                        proc_class[j] += 0x002;
                    }
                }
#endif


                /* nobody is bounded to same session */

#if 0
                Trace("hand: th# %x, push sess# %d, to thinkQ\n",
                    pthread_self(), bound[i]->sid);
#endif

                chk = push_sess(think_queue, bound[i]);
                if(chk) {
                        bound[i]->reason = R_MEMORY_OVERFLOW;
                        DoSendMessage(bound[i]);
                        DoCloseSess(bound[i]);
                        DoReleaseSess(bound[i]);
                }

            }

            /* clear a processed session */
            if(bound[i]) {
                for(j=0;j<w_sess_count;j++) {
                    if(sess_chunk[j] && sess_chunk[j]==bound[i]) {
                        proc_class[j] += 0x010;
                        sess_chunk[j] = NULL;
                    }
                }
#if 0
                if(touched && same) {
                    for(j=0;j<w_fd_count;j++) {
                        if(j!=i && bound[i] && bound[j] && bound[j]==bound[i]) {
                            bound[j] = NULL;
                        }
                    }
                }
#endif
                bound[i] = NULL;
            }
        }

#if 0
        j = 0;
        for(i=0;i<w_sess_count;i++) {
            if(sess_chunk[i]) {
                j++;
                Trace("hand: MID   th# %x, %d:%d, sess# %d, %s\n",
                    pthread_self(), htic, i,
                    sess_chunk[i]->sid,
                    MSG_STATE_[sess_chunk[i]->state]);
            }
        }
        Trace("hand: MID   th# %x, %d:-, j %d\n",
            pthread_self(), htic, j);
#endif


dispatch_by_sess:
        handler_phase[dnum] = 4;

        for(i=0;i<w_sess_count;i++) {
            if(sess_chunk[i]) {

                if(sess_chunk[i]->cache_entry) {
                    handler_focus[dnum] = sess_chunk[i]->fhash;
                }
                else {
                    handler_focus[dnum] = -1;
                }

#if 1
                proc_class[i] += 0x004;
#endif

#if 0
                Trace(
                  "hand: th# %x, %d:%d - call Hmain sess# %d, %s\n",
                    pthread_self(), htic, i,
                    sess_chunk[i]->sid,
                    MSG_STATE_[sess_chunk[i]->state]);
#endif
#ifdef TRACE_SCHEDULE
#endif

                handler_phase[dnum] = 51;
                Hmain(dnum, sess_chunk[i], now);
                handler_phase[dnum] = 52;
#if 0
                Trace(
                  "hand: th# %x, %d:%d - done Hmain sess %p, sess# %d, %s\n",
                    pthread_self(), htic, i,
                    sess_chunk[i], sess_chunk[i]->sid,
                    MSG_STATE_[sess_chunk[i]->state]);
#endif
#ifdef TRACE_SCHEDULE
#endif

                for(j=0;j<w_sess_count;j++) {
                    if(i!=j && sess_chunk[i] && sess_chunk[j]
                            && sess_chunk[i]==sess_chunk[j]) {
                        proc_class[j] += 0x100;
                        sess_chunk[j] = NULL;
                    }
                }
                proc_class[i] += 0x020;
                sess_chunk[i] = NULL;
            }
        }

next_turn:
        (void)0; /* dummy */

#if 0
        j = 0;
        for(i=0;i<w_sess_count;i++) {
#if 0
            if(sess_chunk[i]) {
                j++;
                Trace("hand: END   th# %x, %d:%d, proc %03x sess# %d, %s\n",
                    pthread_self(), htic, i,
                    proc_class[i],
                    sess_chunk[i]->sid,
                    MSG_STATE_[sess_chunk[i]->state]);
            }
#else
                j++;
                Trace("hand: END   th# %x, %d:%d, proc %04x\n",
                    pthread_self(), htic, i,
                    proc_class[i]);
#endif
        }
        Trace("hand: END   th# %x, %d:-, j %d\n",
            pthread_self(), htic, j);
#endif

        handler_focus[dnum] = -1;
        /*
         *
         */

        handler_phase[dnum] = 5;

        /* XYZ */
        check_ocache_area(dnum, bk_use);

next_chunk:
        (void)1;
    } /* while, forever loop */

}
/* end of Handler*/



void* Swapper(void* dummy);
void* DSweeper(void* dummy);

extern volatile int disk_sweep_interval;

void*
DSweeper(void* dummy)
{
    int chk;
    struct timespec join_time;

    /* msec, how many times in 1000msec */
    int interval = disk_sweep_interval;
    int tint;

#if 0
Trace("DSweeper: pr %d, th %d\n", getpid(), pthread_self());
#endif

    while(1) {
        skcache_dir_sweeper();

        if(dsweeper_phase<=1) {
            tint = MAX(interval/10, 10);
        }
        else {
            tint = interval;
        }
#if 0
        Trace("DSweeper: phase %4d, interval %9d/%d\n",
            dsweeper_phase, tint, interval);
#endif
        chk = msleep(tint);
    }
}




/*
 * return:
 *      <0  error
 *      0   busy
 *      >0  idle
 */
static
int
check_mutex(pthread_mutex_t *mx)
{
    int chk;

    chk = MUTEX_TRYLOCK(mx);
    if(chk) {
        if(chk==EBUSY)
            return 0;
        else
            return -chk;
    }
    MUTEX_UNLOCK(mx);
    return 1;
}


static char *_msg_idle  = "IDLE ";
static char *_msg_busy  = "BUSY ";
static char *_msg_err   = "ERROR";

static
int
report_check_mutex(FILE *fp, char *msg, pthread_mutex_t *mx)
{
    int chk;
    char *rep;

    chk = check_mutex(mx);
    if(chk<0)   rep=_msg_err;
    if(chk==0)  rep=_msg_busy;
    if(chk>0)   rep=_msg_idle;

    fprintf(fp, "$$$ %s %s\n", msg, rep);

    return 0;
}

void print_sess(FILE *ofp, void* raw_addr, struct timeval *reftime)
{
    sess_t *self;
    int chk, err;
    char *rep;
    struct timeval reftime_local;
    int elap;

    if(reftime==NULL) {
        gettimeofday(&reftime_local, NULL);
        reftime = &reftime_local;
    }

    self = (sess_t*) raw_addr;

    chk = check_mutex(&(self->busy));
    if(chk<0)   rep=_msg_err;
    if(chk==0)  rep=_msg_busy;
    if(chk>0)   rep=_msg_idle;

    elap = reftime->tv_sec - self->accept_time.tv_sec;

    fprintf(ofp, "%3d %s %c %3d %3d <%s>\n",
        self->sid, rep, self->mode==MODE_CLIENT ? 'c': '-', elap, self->fhash, self->loc);
#if 0
    fprintf(ofp, "%3d ", self->reqlen);
    fprintf(ofp, "<%s> ", self->loc);
    fprintf(ofp, "\n");
#endif
}

int
check_buckets()
{
    int i;
    bucket_t *bk;
    int f;

    for(i=0;i<radix_h1;i++) {
        bk = &skcache_bucket_base[i];
        f = check_mutex(&bk->mutex);
        Trace("bk# %4d: %d\n", i, f);
    }

    return 1;
}

int
check_busy_buckets(int *to, int *ms, int *ot)
{
    int i;
    bucket_t *bk;
    int f;
    int c;
    char band[RADIX_H1_MAX];
    char fill[RADIX_H1_MAX];
    char outline[L_BUF];
    char tmp[L_BUF];

    outline[0] = '\0';

    *to = 0;
    *ms = 0;
    *ot = 0;
    c = 0;
    for(i=0;i<radix_h1;i++) {
        bk = &skcache_bucket_base[i];

/*
        fill[i] = "_ueX"[(bk->entry_use>0)*1+(bk->gc_checkpoint>0)*2];
*/
        fill[i] = "0123456789X"[10*bk->entry_use/bk->entry_all];

        f = check_mutex(&bk->mutex);
        if(f==0) {
            (*to)++;
#if 0
            if(c==0) {
                Trace("busy buckets:\n");
            }
#endif
#if 0
            Trace("busy bk# %-3d: %d %d\n", i, f, bk->gc_last);
#endif
            c++;
            if(bk->own=='M' || bk->own=='D') {
                (*ms)++;
                band[i] = bk->own;
            }
            else {
                (*ot)++;
                band[i] = '*';
            }
            sprintf(tmp, "bk# %d, ", bk->bid);
            strcat(outline, tmp);
        }
        else
        if(f<0) {
            band[i] = '?';
        }
        else {
            band[i] = '.';
        }
    }
    band[radix_h1] = '\0';
    fill[radix_h1] = '\0';

    if(c>0) {
#if 0
        Trace("busy %d threads\n", c);
#endif
#if 0
    Trace("busy band %d %3d %s\n", time(NULL), c, band);
#endif
    }

#if 1
    Trace("busy bucket %d %3d %s\n", time(NULL), c, band);
    if(outline[0] && c<16) {        /* too mach message is not worth X-) */
        Trace("  So, %s\n", outline);
    }
#endif
#if 1
    Trace("fill bucket %d %3d %s\n", time(NULL), c, fill);
#endif

    return 1;
}


int
check_busy_queues()
{
    int r;
    int cthink;
    int chk;
    int i;
    int nq;
    int cswap;
    char line[N_SWAPPER_MAX+20];
    register char *p, *q;


    q = line;

    p = "thk ";
    while(*p) {
        *q++ = *p++;
    }
    cthink = 0;
    chk = check_mutex(&think_queue->lock);
    if(chk==0) {
        *q++ = '*';
        cthink++;
    }
    else
    if(chk<0) {
        *q++ = 'e';
    }
    else {
        *q++ = '_';
    }
    *q++ = ' ';


    p = "dir ";
    while(*p) {
        *q++ = *p++;
    }
    chk = check_mutex(&dir_mutex);
    if(chk==0) {
        *q++ = '*';
    }
    else
    if(chk<0) {
        *q++ = 'e';
    }
    else {
        *q++ = '_';
    }
    *q++ = ' ';



    p = "swp ";
    while(*p) {
        *q++ = *p++;
    }

#if 0
    nq = MAX(radix_disk,1);
#endif
    nq = n_swappers;

    cswap = 0;
    for(i=0;i<nq;i++) {
        chk = check_mutex(&(swap_queue[i]->lock));
        if(chk==0) {
            *q++ = '*';
            cswap++;
        }
        else
        if(chk<0) {
            *q++ = 'e';
        }
        else {
            *q++ = '_';
        }
    }

    *q++ = '\0';

    r = cthink + cswap;
    Trace("busy queue  %d %3d %s\n", time(NULL), r, line);

    return r;
}




extern sim_stat_rec hres_stat;




#define SESS_N  (64)

void
ana_sess_queue(int t, int elap, char *str_elap)
{
    int i;
    int cur, sum;
    int scount[SESS_N];
    int icount;
    int chk;
    sess_t *p;
    char line[L_BUF], tmp[L_BUF];
    extern sess_queue_t *think_queue;

    int c_all, c_pos, c_neg;
    
    memset(scount, 0, sizeof(int)*SESS_N);
    icount = 0;

    i = 5;
try:
    i--;
    chk = pthread_mutex_trylock(&think_queue->lock);
    if(chk==EBUSY) {
        if(i>0) {
            goto try;
        }
        goto out;
    }

    cur = think_queue->count;

    c_all = 0;
    c_pos = 0;
    c_neg = 0;

    sum = 0;
    p = (sess_t*) think_queue->head;
    while(p) {
        c_all++;
        if(p->sid>=0) {
            c_pos++;
        }
        else {
            c_neg++;
        }
        if(p->state >= 0 && p->state < SESS_N) {
            scount[p->state]++;
        }
        else {
            icount++;
        }
        p = p->next;
        sum++;
    }

    chk = pthread_mutex_unlock(&think_queue->lock);

    line[0] = '\0';
    for(i=0;i<STATE_DUMMY_END;i++) {
        sprintf(tmp, "%s %d ", MSG_STATE_[i], scount[i]);
        strcat(line, tmp);
    }
    sprintf(tmp, "%s %d ", "IGNORE", icount);
    strcat(line, tmp); 
    Trace("; state %d %d %s sum %d %d : %s\n",
        t, elap, str_elap, cur, sum, line);
        
#if 0
    Trace("; pos/neg counting, all %d, pos %d %.2f%% neg %d %.2f%%\n",
        c_all, c_pos, (100.0*c_pos)/c_all, c_neg, (100.0*c_neg)/c_all);
#endif

out:

    (void)0;
}

void
mon_hand(int elap, int ref)
{
    int i;
    bucket_t *fbk;
    int diff;

    for(i=0;i<n_handlers;i++) {
        if(handler_focus[i]>=0) {
            fbk = &skcache_bucket_base[handler_focus[i]];

#if 1
            if(fbk->entry_all<=0) {
                Error("bk# %d, entry_all %d\n", fbk->bid, fbk->entry_all);
            }
#endif
        }
        else {
            fbk = NULL;
        }
        diff = ref - handler_beacon[i];


        Trace("  =hand %3d: th# %d: elap %d: last %d diff %5d %c ; bk# %d, use %d%%, phase %d\n",
            i, th_handlers[i], elap,
            handler_beacon[i], diff, diff >= 3 ? '*' : '-' ,
            handler_focus[i],
            fbk ?
                (fbk->entry_all>0 ?
                        100*fbk->entry_use/fbk->entry_all : -7)
                : -1,
            handler_phase[i]);
    }

}


void
mon_sw(int elap)
{
    int i;

    for(i=0;i<n_swappers;i++)
    {
        if(swapper_focus_bk[i]>=0) {
        }

Trace("  =sw %2d: th# %d: elap %d: swapin come %lld gone %lld %lld prog %.2f%% diff %lld; left %ld; ave. %6.1f; bk# %d, oid# %d, phase %d\n",
            i, th_swapper[i], elap,
            swap_op_th_count[i][1],
            swap_op_repush_th_count[i], swap_op_retry_th_count[i],
            100.0*swap_op_retry_th_count[i]/swap_op_th_count[i][1],
            swap_op_th_count[i][1] - swap_op_repush_th_count[i],
            swap_queue[i]->count,
            sim_hist_average_d(&swapper_swi_hist[i]),
            swapper_focus_bk[i], swapper_focus_oid[i],
            swapper_phase[i]
            );

    }

}


void
mon_fs(int elap)
{
    int i;

    for(i=0;i<MAX(radix_disk,1);i++) {
        Trace("  =fs %2d: elap %d: swapin %d %.1f ; swapout %d %.1f\n",
            i, elap,
            fs_swapin_count[i],
                sim_hist_average_d(&fs_swapin_hist[i]),
            fs_swapout_count[i],
                sim_hist_average_d(&fs_swapout_hist[i])
        );
    }
}

void*
Monitor(void *dummy)
{

/* create */
#define C(x)    int c_##x=0, last_##x=0, delta_##x; \
                double r_##x=-1.0, rmax_##x

/* process */
#define P(x) \
                delta_##x = c_##x - last_##x; \
                r_##x = ((double)delta_##x*1000)/delta_t; \
                if(r_##x>rmax_##x) { \
                    rmax_##x = r_##x; \
                }

/* values */
#define V(x)    r_##x, rmax_##x, (long)c_##x, delta_##x

/* last */
#define L(x)    last_##x = c_##x

#define XRATIO(xhit, xmiss) \
    (((xhit)+(xmiss))<=0 ? -1.0 : (100.0*(xhit))/((xhit)+(xmiss)))

    char *fmt =
": time %d %d %s %c\
 : thru arr %.1f/%.1f %ld %d, pro %.1f/%.1f %ld %d, prog %.1f, err %.1f/%.1f %ld %d\
 : takes rep %.1f hname %.1f msw %.1f dsw %.1f swi %.1f swo %.1f\
 : ocache hit/miss %d %d, hit%% %.2f %.2f\
 : hcache hit/miss %d %d, hit%% %.2f %.2f\
 : sess %d %d, queue %d %d %d, bk %d %d, buf fail/success %d %d\
 : msweep %.1f/%.1f %ld %d, comp %.1f/%.1f %ld %d\
 : swapin %.1f/%.1f %ld %d success %.1f/%.1f %ld %d\
 : swapout %.1f/%.1f %ld %d success %.1f/%.1f %ld %d\
 : frag %d %d %.2f%%\
 : dsweep bg %.1f/%.1f %ld %d %d %d,\
 chkdir dir %.1f/%.1f %ld %d rfile %.1f/%.1f %ld %d hfile %.1f/%.1f %ld %d\
 : capacity %lld %d %lld"
    ;

    char outline[L_BUF];
    char elap_str[STRING_SIZE];
    struct timeval last_print_t;

    int count;
    int last_keep_depth;
    int keep_check_interval;

    /* time */
    struct timeval last_t, t0, t1, t2, t3, t4, t5, t6;
    int delta_t;
    int t_nhot, t_nfriend;
    char mark;

    int print_count;
    time_t elap;

    /* average in shortime: retrieval, reaper and check dir. */
    double av_rtime;
    double av_ntime;
    double av_reaper;
    double av_chkdir;
    double av_swapin, av_swapout;

    int c_rjq;

    unsigned int sig, last_sig;

    double ohrate, ohratio;
    double hhrate, hhratio;

    int  c_think, c_send, c_fetch, c_prompt;
    int  s_think, s_send, s_fetch, s_prompt;
/*
    int  c_msweep;
*/
    int  c_wait;
    int  c_swap;

    int c_expire_normal_idle_th, c_expire_cracked_idle_th;
#if 0
    int h_expire[COMP_HIST_WIDTH];
#endif
    double expire_k;
    int expire_raise_tick;
    int expire_min;

    double fratio;

    C(arr);             /* arrival      */
    C(pro);             /* process      */
    C(err);             /* error        */
    C(hit);             /* object-hit   */
    C(miss);            /* miss         */
    C(hhit);            /* hname-hit    */
    C(hmiss);           /* miss         */
    C(comp);            /* compaction   */
    C(expire);          /* expiration   */
    C(swapin);          /* swapin           */
    C(swapinsuc);       /* swapin success   */
    C(swapout);         /* swapout          */
    C(swapoutsuc);      /* swapout success  */
    C(dsweep);          /* disk sweep   */
    C(msweep);          /* memoey sweep */
    C(chdcount);        /* check_dir    dir */
    C(chfrcount);       /* check_dir    file */
    C(chfhcount);       /* check_dir    file */

    int kn,ukn;
    long long guess_size;
    long long dir_size_sum;

    int to, ms, ot;




    count = 0;
    print_count = 0;
    last_keep_depth = 0;
    keep_check_interval = 4;

    last_sig = 0xf0f0;

    /* EX TH */
    expire_k = 2.0;
    expire_raise_tick = 60;
    expire_min = 60;


    gettimeofday(&last_t, NULL);
    while(1) {
        /* interval */
        sleep(MONITOR_INTERVAL);

        gettimeofday(&t0, NULL);
        MUTEX_LOCK(&stat_lock);
        elap    = t0.tv_sec - boot_date;
        c_arr   = receive_request_count;
        c_pro   = process_request_count;
        c_err   = error_reply_count;
        c_rjq   = reject_request_count;
        c_comp  = compaction_count;
        c_expire  = expire_count;

        c_hit   = hit_reply_count;
        c_miss  = miss_reply_count;
        c_hhit  = hname_hit_count;
        c_hmiss = hname_miss_count;

        c_swapin    = swapin_count;
        c_swapinsuc = swapin_success;
        c_swapout   = swapout_count;
        c_swapoutsuc= swapout_success;

        c_dsweep     = dsweeper_count;
        c_msweep     = msweeper_count;

        c_chdcount = checkdir_dir_count;
        c_chfrcount = checkdir_file_read_count;
        c_chfhcount = checkdir_file_handle_count;

        MUTEX_UNLOCK(&stat_lock);

        av_rtime = sim_stat_get_ave(&ret_time_short);
        av_ntime = sim_stat_get_ave(&hname_rtime_stat);

        av_reaper = sim_stat_get_ave(&msweep_time_short);
        av_chkdir = sim_stat_get_ave(&checkdir_time_short);

        av_swapin = sim_hist_average_d(&swapin_hist);
        av_swapout = sim_hist_average_d(&swapout_hist);

        MUTEX_LOCK(&sess_lock);
        t_nhot = nhot;
        t_nfriend = nfriend;
        MUTEX_UNLOCK(&sess_lock);

        MUTEX_LOCK(&think_queue->lock);
        c_think = think_queue->count;
        s_think = think_queue->sig;
        MUTEX_UNLOCK(&think_queue->lock);

#ifdef USE_WQUEUE
        MUTEX_LOCK(&wait_queue->lock);
        c_wait = wait_queue->count;
        MUTEX_UNLOCK(&wait_queue->lock);
#else
        c_wait = 0;
#endif

        {
            int i;

            c_swap = 0;
            for(i=0;i<MAX(radix_disk,1);i++) {
                c_swap += swap_queue[i]->count;
            }
        }
        

        c_send   = s_send   = 0;
        c_fetch  = s_fetch  = 0;
        c_prompt = s_prompt = 0;


        gettimeofday(&t6, NULL);

        sig = c_arr | c_pro | t_nhot | s_think | s_send | s_fetch | s_prompt;



        delta_t = KOTETU_SUB_TIME(t0, last_t);

        P(arr);
        P(pro);
        P(err);
        P(hit);
        P(miss);
        P(hhit);
        P(hmiss);
        P(comp);
        P(msweep);
        P(dsweep);
        P(swapin);      P(swapinsuc);
        P(swapout);     P(swapoutsuc);
        P(chdcount);
        P(chfrcount);
        P(chfhcount);

        ohrate  = XRATIO(delta_hit,         delta_miss);
        ohratio = XRATIO(hit_reply_count,   miss_reply_count);
        hhrate  = XRATIO(delta_hhit,        delta_hmiss);
        hhratio = XRATIO(hname_hit_count,   hname_miss_count);

/*
        fratio = ((double)frag_use*100.0)/(frag_use+frag_free);
*/
        fratio = ((double)frag_use*100.0)/(frag_all);


        MUTEX_LOCK(&config_lock);
        c_expire_normal_idle_th   = skcache_mem_keep_cur;
        c_expire_cracked_idle_th  = -1;
        MUTEX_UNLOCK(&config_lock);


#if 0
        if(t0.tv_sec-last_print_t.tv_sec>=MONITOR_INTERVAL|| sig!=last_sig)
#endif
        if(1)
        {
            if(sig!=last_sig) {
                mark = '=';
            }
            else {
#if 0
s_show_freelist();
#endif
                mark = '-';
            }

            conv_sectoshortstr(elap_str, elap);

            check_busy_buckets(&to, &ms, &ot);
            check_busy_queues();

            MUTEX_LOCK(&stat_lock);

#if 1
Trace("Traffic:\n\
    intra_incoming %12lld B %10.2f MB %7.2f GB\n\
    extra_outgoing %12lld B %10.2f MB %7.2f GB\n\
    extra_incoming %12lld B %10.2f MB %7.2f GB\n\
    intra_outgoing %12lld B %10.2f MB %7.2f GB\n",
  (long long)intra_incoming, fdM(intra_incoming), fdG(intra_incoming),
  (long long)extra_outgoing, fdM(extra_outgoing), fdG(extra_outgoing),
  (long long)extra_incoming, fdM(extra_incoming), fdG(extra_incoming),
  (long long)intra_outgoing, fdM(intra_outgoing), fdG(intra_outgoing)
        );
#endif
#if 0
Trace("swap: count %lld (%.2f M), size %lld B %8.2f MB, %5.2f GB\n",
        swap_count, fdM(swap_count),
        swap_size, fdM(swap_size), fdG(swap_size) );
#endif
#if 1
 {
    int i;

    kn = ukn = 0;
    dir_size_sum = 0LL;
    for(i=0;i<dir_num;i++) {
        /* up */
        if(dir_sz[i]>=(off_t)0L) {
            kn++;
            dir_size_sum += dir_sz[i];
        }
        else {
            ukn++;
        }
    }

    if(kn>0) {
        guess_size = ((long long)dir_size_sum*dir_num)/kn;
    }
    else {
        guess_size = -1LL;
    }

Trace("DiskUtil:\n\
    scaned %d dir.(known %u, unknown %u) used size %lld B, %8.2f MB, %5.2f GB\n\
    guessed total used size %lld B, %8.2f MB, %8.2f GB\n",
        dir_num, kn, ukn, dir_size_sum, fdM(dir_size_sum), fdG(dir_size_sum),
        guess_size, fdM(guess_size), fdG(guess_size));

#if 0
    if(ukn<10) {
        Trace("  unknown directories:\n");
        for(i=0;i<dir_num;i++) {
            if(dir_sz[i]<(off_t)0L) {
                Trace("    dir# %d, time %d, size %lld\n",
                    i, dir_time[i], (long long)dir_sz[i]);
            }
        }
    }
#endif


 }
#endif

#ifndef NDEBUG
 {
    int i;
    bucket_t *bk;
    int guess_count;

    guess_count = 0;
    for(i=0;i<radix_h1;i++) {
        bk = &skcache_bucket_base[i];
        
        guess_count += bk->own_frag;
    }

    Trace("Check:\n\
  frag verify: %d : recorded in buckets %d (ave. %.2f) : actual used %d free %d : diff %d\n",
        t0.tv_sec,
        guess_count, (double)guess_count/radix_h1,
        frag_use, frag_free, frag_use - guess_count);
 }
#endif

#if 1
 {
    extern volatile int check_dir_ignore_hash_count;
    extern int dir_conflict;

Trace("  directory conflict: %d\n", dir_conflict);
Trace("  ignore hash count:  %d\n", check_dir_ignore_hash_count);

    sim_stat_show_lock(&reaper_call_reason,     stderr);
    sim_stat_show_lock(&swapin_fail_reason,     stderr);
    sim_stat_show_lock(&swapout_fail_reason,    stderr);
    sim_stat_show_lock(&rcode_stat,             stderr);
    sim_stat_showX_lock(&req_field_type_stat,   stderr);

 }

#endif


            sprintf(outline, fmt,
                t0.tv_sec,
                elap, elap_str,
                mark,

                V(arr),
                V(pro),
                c_arr>0 ?  ((double)c_pro*100.0)/c_arr : -100.0,
                V(err),

                av_rtime,
                av_ntime,
                av_reaper,
                av_chkdir,
                av_swapin,
                av_swapout,
    
                hit_reply_count, miss_reply_count,
                ohrate, ohratio,

                hname_hit_count, hname_miss_count,
                hhrate, hhratio,

                t_nhot,
                t_nfriend,

                c_think,
                c_wait,
                c_swap,

                to,
                ms,

                alloc_tmp_buf_count,
                alloc_sess_buf_count,

                V(msweep),
                V(comp),
                V(swapin), V(swapinsuc),
                V(swapout), V(swapoutsuc),

                frag_use, frag_free, fratio,

                V(dsweep), dsweeper_phase, dsweeper_pos, 
                V(chdcount),
                V(chfrcount),
                V(chfhcount),
                
                dir_size_sum, ukn, guess_size

                );

            MUTEX_UNLOCK(&stat_lock);

            LogLine(outline);
            LogSync();

#ifndef LOG_REPORT_CONSOLE
            Trace("%s\n", outline);
#endif

            sim_stat_reset(&ret_time_short);
            sim_stat_reset(&msweep_time_short);
            sim_stat_reset(&checkdir_time_short);

            sim_hist_add_value(&fratio_hist, (long)fratio);

            skcache_update_keeptime(delta_t);


            last_sig = sig;
#if 0
            last_print_t = t0;
#endif
            memcpy(&last_print_t, &t0, sizeof(struct timeval));
            print_count++;
        }

        {
            sim_hist_add_value(&comp_hist, (long)delta_comp);
            sim_hist_add_value(&expire_hist, (long)delta_expire);

#if 0
            sim_hist_show(&comp_hist, stdout);
            sim_hist_show(&expire_hist, stdout);
#endif

#if 0
            r_comp = sim_hist_average_d(&comp_hist);
            r_expire = sim_hist_average_d(&expire_hist);
            Trace("  $$ rate comp %.2f, expire %.2f\n", r_comp, r_expire);
#endif
        }


#if 1
    if(print_count%6==0) 
    {
        mon_hand(elap, t0.tv_sec);
        mon_sw(elap);
        mon_fs(elap);
    }
#endif

#if 1
 if(print_count%30==0) 
 {
    sim_stat_show91_lock(&ret_time,         stderr);
    sim_stat_show91_lock(&msweep_time,      stderr);
    sim_stat_show91_lock(&checkdir_time,    stderr);

    sim_stat_show91_lock(&swapin_time,      stderr);
    sim_stat_show91_lock(&swapout_time,     stderr);

    sim_stat_show_lock(&method_stat,        stderr);

#if 0
    sim_stat_show91_lock(&swo_t01,  stderr);
    sim_stat_show91_lock(&swo_t12,  stderr);
    sim_stat_show91_lock(&swo_t23,  stderr);
    sim_stat_show91_lock(&swo_t34,  stderr);
    sim_stat_show91_lock(&swo_t45,  stderr);
#endif
 }
#endif


        /* store last values */
        last_t = t0;

        L(arr);
        L(pro);
        L(err);
        L(hit);
        L(miss);
        L(hhit);
        L(hmiss);
        L(comp);
        L(msweep);
        L(expire);
        L(swapin);
        L(swapinsuc);
        L(swapout);
        L(swapoutsuc);
        L(dsweep);
        L(chdcount);
        L(chfrcount);
        L(chfhcount);

#if 0
        check_checkpoints();
#endif

#if 1
        if(fratio<0.0) {
            Error("ratio of frag is negative, it is may error");
        }
#endif

        ana_sess_queue(t0.tv_sec, elap, elap_str);

        count++;
    }


#undef C
#undef P
#undef V
#undef L

#undef XRATIO

}




static pthread_mutex_t logging_lock = PTHREAD_MUTEX_INITIALIZER;

RETSIGTYPE
Logging_Queues()
{
    FILE *fp;
    int i;
    struct timeval now;
    int t_nhot;

    MUTEX_LOCK(&logging_lock);

    gettimeofday(&now, NULL);

    Trace("logggin queues\n");

    fp = fopen("queues.log", "w");
    if(fp==NULL) {
        goto out;
    }

    fprintf(fp, "process %d, thread %x\n\n", getpid(), pthread_self());

        fprintf(fp, " monitor           %x\n", th_monitor);
        fprintf(fp, " listener          %x\n", th_listener);
    fprintf(fp, " manager  %d/%d\n", require_n_handler, N_HANDLER_MAX);
    for(i=0;i<require_n_handler;i++) {
        fprintf(fp, "   %3d             %x\n", i, th_handlers[i]);
    }
    fprintf(fp, "\n");

    MUTEX_LOCK(&sess_lock);
    t_nhot = nhot;
    MUTEX_UNLOCK(&sess_lock);

    fprintf(fp, "hot session %d\n\n", t_nhot);

    fprintf(fp, "== think queue\n");
    sq_show_mapfunc(fp, think_queue,    print_sess, &now);
#if 0
    fprintf(fp, "== send queue\n");
    sq_show_mapfunc(fp, send_queue,     print_sess, &now);
    fprintf(fp, "== fetch queue\n");
    sq_show_mapfunc(fp, fetch_queue,    print_sess, &now);
    fprintf(fp, "== prompt queue\n");
    sq_show_mapfunc(fp, prompt_queue,   print_sess, &now);
#endif


    report_check_mutex(fp, "mutex stat   ", &stat_lock);
    report_check_mutex(fp, "mutex sess   ", &sess_lock);
    report_check_mutex(fp, "mutex config ", &config_lock);
    report_check_mutex(fp, "mutex logging", &logging_lock);


done:

    fflush(fp);
    fclose(fp);

out:

    MUTEX_UNLOCK(&logging_lock);
}


/*
 *
 */
RETSIGTYPE
TERM_Trap()
{
    Log("; Catch signal for termination");
    MUTEX_LOCK(&stat_lock);
    catch_termination = 1;
    MUTEX_UNLOCK(&stat_lock);
    exit(127);
}

void*
signal_watcher(void *arg)
{
    int sig;
    int chk;

    while(1) {
        chk = sigwait(&handler_sig_mask, &sig);
        if(chk) {
            Trace("signal_watcher: chk %d\n", chk);
            continue;
        }

        Trace("signal_watcher: get signal %d\n", sig);

        switch(sig) {
        case SIGPIPE:
            MUTEX_LOCK(&stat_lock);
            session_queue_report_flag = 1;
            MUTEX_UNLOCK(&stat_lock);
            break;
        case SIGUSR2:
            MUTEX_LOCK(&stat_lock);
            session_queue_report_flag = 1;
            MUTEX_UNLOCK(&stat_lock);
            break;
        case SIGHUP:
            LogSync();
            break;
        case SIGINT:
        case SIGTERM:
            MUTEX_LOCK(&stat_lock);
            catch_termination = 1;
            MUTEX_UNLOCK(&stat_lock);
            Log("END");
            LogSync();
            exit(137);
            break;
        case SIGCHLD:
          {
            int stat;
            pid_t pid;

            do {
try_waitpid:
                pid = waitpid((pid_t)-1, &stat, WNOHANG | WUNTRACED);

                if(pid < 0) {
                    if(errno==EINTR) {
                        goto try_waitpid;
                    }
                    printf("error with errno=%d\n", errno);
                    break;
                }
                if (pid > 0) {
                    printf("child %d terminated\n", pid);
                }
            } while(pid>0);

          }
            break;
        default:
            break;
        }
    }

 /*NOTREACHED*/
    return (void*)NULL;
}



/*
 *
 * if fdcap is -1, this routine will set maximum value from getrlimit()
 */
void
ToBeMaximumFDCapacity(int fdcap)
{
    struct rlimit nfile;
    int last_nofile;

#ifdef RLIMIT_NOFILE
#define X   RLIMIT_NOFILE
#else
#define X   RLIMIT_OFILE
#endif

    if(getrlimit(X, &nfile)<0) {
        Error("getrlimit() for current check was fail (%d)", errno);
    }
    else {
        last_nofile = nfile.rlim_cur;
    }

    if(fdcap<0) {
        nfile.rlim_cur = nfile.rlim_max;
    }
    else {
        nfile.rlim_cur = fdcap;
    }

    if(setrlimit(X, &nfile)<0) {
        Error("settrlimit() fail (%d)", errno);
    }

    if(getrlimit(X, &nfile)<0) {
        Error("getrlimit() for verify was fail (%d)", errno);
    }
    else {
        Trace("ToBeMaximumFDCapacity: current to %d (max %d), last %d, specified %d\n",
            nfile.rlim_cur, nfile.rlim_max,
            last_nofile, fdcap);
    }

#undef X

}



void
mutex_bench()
{
    struct timeval begin, end;
    int i, dummy;
    int diff, iter;
    double ave;

    dummy = time(NULL);
    iter = 5000000; /* 5 milions */

    gettimeofday(&begin, NULL);
    for(i=0;i<iter;i++) {
        MUTEX_LOCK(&stat_lock);
        dummy = dummy << 2;         /* avoid special optimize :-) */
        MUTEX_UNLOCK(&stat_lock);
    }
    gettimeofday(&end, NULL);

    diff = KOTETU_SUB_TIME(end, begin);
    ave = ((double)diff*1000000.0)/iter;

    Trace("mutex_bench: takes %d msec for %d times lock and unlock\n\
  average %.1f nsec\n", diff, iter, ave);
}

pthread_attr_t *p_th_attr_high=NULL, *p_th_attr_mid=NULL, *p_th_attr_low=NULL;

static
void
setup_thread_attrs()
{
    pthread_attr_t th_attr_high, th_attr_mid, th_attr_low;

#ifdef USE_THREAD_ATTR 
    chk = pthread_attr_init(&th_attr_high);
    chk = pthread_attr_init(&th_attr_mid);
    chk = pthread_attr_init(&th_attr_low);
    Trace("ret pthread_attr_init() %d (%d)\n", chk, errno);

    chk = pthread_attr_getschedparam(&th_attr_high, &th_param);
    Trace("default (initialized) priority value %d\n",
        th_param.sched_priority);
    th_param.sched_priority += th_param.sched_priority; /* double */
    chk = pthread_attr_setschedparam(&th_attr_high, &th_param);

    chk = pthread_attr_getschedparam(&th_attr_mid, &th_param);
    th_param.sched_priority = th_param.sched_priority; /* thru */
    chk = pthread_attr_setschedparam(&th_attr_mid, &th_param);

    chk = pthread_attr_getschedparam(&th_attr_low, &th_param);
    th_param.sched_priority = th_param.sched_priority/2; /* half */
    chk = pthread_attr_setschedparam(&th_attr_low, &th_param);

    chk = pthread_attr_getschedpolicy(&th_attr_mid, &th_policy_type);
    Trace("ret pthread_attr_getschedpolicy() %d (%d)\n", chk, errno);
    Trace("default value %d\n", th_policy_type);

#if 1
    th_policy_type = SCHED_FIFO;
    chk = pthread_attr_setschedpolicy(&th_attr_high, th_policy_type);
    th_policy_type = SCHED_RR;
    chk = pthread_attr_setschedpolicy(&th_attr_mid, th_policy_type);
    th_policy_type = SCHED_RR;
    chk = pthread_attr_setschedpolicy(&th_attr_low, th_policy_type);
#endif

    p_th_attr_high  = &th_attr_high;
    p_th_attr_mid   = &th_attr_mid;
    p_th_attr_low   = &th_attr_low;

#else

    p_th_attr_high  = NULL;
    p_th_attr_mid   = NULL;
    p_th_attr_low   = NULL;

#endif /* USE_THREAD_ATTR */

}


static
void
setup_qs(void)
{
    int sum;
    int len_sw;
    int len_th;
    int i;
    int xn_swappers;
    int pfactor = 2;

    xn_swappers = MAX(radix_disk,1)*swfactor;
    /*
    len_sw = require_nsess_total/(xn_swappers+2);
    */
    len_sw = (require_nsess_total/2)/xn_swappers;

    sum = 0;
    for(i=0;i<xn_swappers;i++) {
        sum += len_sw;
    }

    len_th = require_nsess_total - sum;

    for(i=0;i<xn_swappers;i++) {
        sq_init(&X_swap_queue[i], len_sw*pfactor);
        swap_queue[i] = &X_swap_queue[i];
    }

    think_queue_length = len_th;
    sq_init(&X_think_queue,     think_queue_length*pfactor);
    think_queue = &X_think_queue;

    Trace("\n\
Queue length (session list) pfactor %d : allocate %d\n\
                %7s %7s\n\
    ------------\n\
    think       %7d %7d\n\
    swapper     %7d %7d\n\
      @thread   %7d %7d\n\
    ------------\n\
    total       %7d\n\
\n\
",
        pfactor,
        require_nsess_total, 
        "base", "limit",
        len_th, len_th*pfactor,
        sum,    sum*pfactor,
        len_sw, len_sw*pfactor,
        len_th+sum);

}

static
void
setup_objcache(void)
{
    int xbk_num;
    int xbk_sk_level, xbk_sk_len;
    int xfrag_size, xfrag_freelist_len;
    long long xU;

    xbk_num      = require_nbucket;
    xbk_sk_level = require_level_bucket_skiplist;
    xfrag_size   = require_frag_size;
    xfrag_freelist_len = -1;
    xbk_sk_len   = require_nentry_per_bucket;

    nentry_bucket = xbk_sk_len;

#if 1
    Trace("\
Cache parameters:\n\
  *** given ***\n\
  require_total_memory_size %lld\n\
  structures\n\
    bucket                    %7d\n\
    entry                     %7d ; %d x %d\n\
    frag                      %7s ; %d x (not clear, automatic solved)\n\
\n",
        (long long)require_total_memory_size,
        xbk_num,
        xbk_sk_len * xbk_num, xbk_sk_len, xbk_num, 
        "unkown", xfrag_size
    );
    Trace("\
   ***\n\
   boot date %d, keep offset %d -> min date %d\n\
\n",
        boot_date, keep_offset, boot_date-keep_offset);
#endif

    xU = skcache_alloc_cacheareas(boot_date-keep_offset,
            xbk_num, xbk_sk_level, xbk_sk_len, xfrag_freelist_len, xfrag_size);

    cache_memory_size = xU;

}



static
volatile
char *compile_magic = "This program was compiled at " __DATE__ ", " __TIME__;
int listen_fd;

#ifdef DISK_BENCH
#include "disk_bench.c"
#endif

void kotetu_mem_check_lockable(void);
void check_disk_spliting(void);

int
main(int argc, char **argv)
{
    int i, j;
    int chk;
    struct sched_param th_param;
    int th_policy_type;


    /***
     *** Initialize
     ***/

    TRACE_RECEIPT;

    MUTEX_LOCK(&stat_lock);
    boot_date = time(NULL);
    MUTEX_UNLOCK(&stat_lock);

    srand(time(NULL));

    kotetu_mem_check_lockable();

    swapper_init();
    skcache_mem_init();
    skcache_disk_init();
    hcache_init();

    /* trace masking */
    {
        char *env_str;

        env_str = getenv("KOTETU_TRACE");
        if(env_str!=NULL) {
fprintf(stderr, "set global_trace_mask as '%s'\n\
  from env.var. KOTETU_TRACE\n", env_str);
            global_trace_mask=(char*)strdup((const char*)env_str);
        }
        else {
/*
            global_trace_mask="proxy_main.c,objcache";
            global_trace_mask="dummy";
*/
            global_trace_mask="all";
        }
    }

    wake_traces();

    SetSignalHandler(SIGPIPE, SIG_IGN);

    /***
     *** Configuration
     ***/

    SetGlobalDefaults();
    if(getenv(DEFAULT_CONFIG_ENVNAME)!=NULL) {
        strcpy(config_filename, getenv(DEFAULT_CONFIG_ENVNAME));
    }
    if(config_filename[0]) {
        ReadConfigFile(config_filename);
    }
    ReadCommandlineOptions(argc, argv);

    FixGlobals();


    wake_traces();

    /***
     *** Logging
     ***/
    InitLogger("kotetuserv");
    Log("START %s %s %s ", KOTETU_VER,  __DATE__, __TIME__);
    LogSync();
    Trace("booting %s ...\n", KOTETU_VER);

    if(trace_flag) {
        TraceOn();
    }
    else {
        TraceOff();
    }

    if(trace_flag) {
        fflush(stderr);
        ShowGlobals(stdout);
        fflush(stdout);
    }

    date_zone_offset_init();

#if 1
    mutex_bench();
#endif

#ifndef NDEBUG
    Trace("not set NDEBUG, so it is debug mode\n\
If you want an actual performance, you should re-compile with -DNDEBUG\n");
#endif
#ifdef USE_MLOCK
    Trace("compiled for memory locking with mlock()\n");
#endif
    Trace("use swapper threads always\n");
#ifdef USE_NULLSWAPOUT
    Trace("use null swapout\n");
#else
    Trace("*not* use null swapout\n");
#endif

#if 1
    Trace("parameters:\n\
    L_URL       %6d\n\
    L_HOST      %6d\n\
    L_PATH      %6d\n\
    L_BUF       %6d\n\
    L_REQBUF    %6d\n", L_URL, L_HOST, L_PATH, L_BUF, L_REQBUF);

    Trace("size of structures:\n\
    session         %6d\n\
    skiplist cell   %6d\n\
    skiplist        %6d\n\
    entry           %6d\n\
    frag            %6d\n\
    bucket          %6d\n",
        sizeof(sess_t),
        sizeof(skiplist_cell_t), sizeof(skiplist_t),
        ESIZE, sizeof(skcache_frag_t),
        sizeof(bucket_t));

#endif

    ToBeMaximumFDCapacity(-1);
    check_disk_spliting();

    /* boot listener, use maximum value of OS */
    listen_fd = TCP_bind_port(service_portno, -1);
    Trace("listen_fd %d, chk %d\n", listen_fd, chk);
    if(listen_fd<0) {
        Error("service port(%d) is already use", service_portno);
        exit(4);
    }

#ifndef USE_REQUEST_THRU
    Trace("handle all request, no thru\n");
#else
    Trace("handle w/ random thru. thru_factor = %d\n",
        thru_factor);
    if(thru_factor<=0) {
        Trace("  but thru_factor is too small.  it means no thru\n"); 
    }
#endif

    /***
     *** misc. statistically
     ***/

    sim_stat_alloc_new(&method_stat,            "method",
        M_XDUMMY,  method_stat_count);

    sim_stat_alloc_new(&len_perread_stat,       "length of per read(2)",
        K(32),  server_buffer_stat_count);
    sim_stat_U_alloc_new(&object_size_stat,     "object size [KB]",
        1024, K(1),   object_size_stat_count);

    sim_stat_alloc_new(&rcode_stat,             "session response code",
        1000,   rcode_stat_count);

    sim_stat_alloc_new(&url_first_hash_stat,    "first hash value",
        K(2),   url_first_hash_stat_count);
    sim_stat_alloc_new(&url_second_hash_stat,   "second hash value",
        K(2),   url_second_hash_stat_count);
    sim_stat_alloc_new(&url_third_hash_stat,    "third hash value",
        K(2),   url_third_hash_stat_count);
    sim_stat_alloc_new(&url_fourth_hash_stat,   "fourth hash value",
        K(2),   url_fourth_hash_stat_count);

    sim_stat_alloc_new(&req_field_type_stat,    "request field type",
        256,   req_field_type_stat_count);

    sim_stat_alloc_new(&object_alloc_stat,      "object alloc",
        K(10),  object_alloc_stat_count);

    sim_stat_U_alloc_new(&ret_time,         "retrieval time [msec]", 
        50, K(5), ret_time_count);
    sim_stat_U_alloc_new(&ret_time_short,   "retrieval time (short) [msec]",
        1, K(12), ret_time_short_count);

    sim_stat_alloc_new(&hname_rtime_stat,  "hostname resolve time [msec]",
        K(10), hname_rtime_stat_count);
    sim_stat_U_alloc_new(&hname_rtime,      "hostname retrieval time [msec]",
        50, K(5), hname_rtime_count);
    sim_stat_U_alloc_new(&hname_rtime_short,    "hostname retrieval time (short) [msec]",
        1, K(12), hname_rtime_short_count);

    sim_stat_alloc_new(&reaper_call_reason,"reaper call reason",
        K(1),   reaper_call_reason_count);

#if 0
    sim_stat_U_alloc_new(&msweep_time,            "mark time [msec]",
        1, K(10), msweep_time_count);
    sim_stat_U_alloc_new(&msweep_time_short,      "mark time (short) [msec]",
        1, K(10), msweep_time_short_count);
#endif

    /* history */
    sim_hist_alloc_new(&comp_hist,              "compaction history",
        30,  comp_hist_area);
    sim_hist_alloc_new(&expire_hist,            "expiration history",
        30,  expire_hist_area);



    Trace("  %d handlers x %d sessions => %d concurrent sessions on time\n",
        require_n_handler, require_nsess_handler,
        require_n_handler*require_nsess_handler);

    /***
     *** Allocate Queues
     ***/
    /***
     *** sessions and queues
     ***/

    InitSession(require_nsess_total);

    setup_qs();

    /***
     *** Allocate DNS Cache Area
     ***/

    hcache_setup();

    /***
     *** Allocate WWW Object Cache Area
     ***/

    setup_objcache();


#if 0
    Trace("Memory allocation:\n\
\ttotal        %12lld // %5ldM+%06ld\n\
\tsession      %12lld // %5ldM+%06ld %6.2f%%\n\
\tobject cache %12lld // %5ldM+%06ld %6.2f%%\n",
        (long long)require_total_memory_size,
          (long)dM(require_total_memory_size),
          (long)mM(require_total_memory_size),
        (long long)sess_memory_size,
          (long)dM(sess_memory_size), (long)mM(sess_memory_size),
          100.0*sess_memory_size/require_total_memory_size,
        (long long)cache_memory_size,
          (long)dM(cache_memory_size), (long)mM(cache_memory_size),
          100.0*cache_memory_size/require_total_memory_size);
#endif

#if 1
    mlist_show();
#endif

    nfrag_obj       = require_nfrag_obj;
    nfrag_dwrite    = require_nfrag_dwrite;
    nfrag_dread     = require_nfrag_dread;
    nfrag_nwrite    = require_nfrag_nwrite;
    nfrag_nread     = require_nfrag_nread;

    nindex_dread    = require_nindex_dread;
    nindex_bdread   = require_nindex_bdread;

#if 1

    Trace(
"\n\
I/O information:\n\
  Frags:\n\
    the max number of frags\n\
      (per object)\n\
      object           %3d (%7ldB %6.1fKB) // hard %4d\n\
      (per operation)\n\
      network write    %3d (%7ldB %6.1fKB) // hard %4d\n\
      network read     %3d (%7ldB %6.1fKB) // hard %4d\n\
      disk write       %3d (%7ldB %6.1fKB) // hard %4d\n\
      disk read        %3d (%7ldB %6.1fKB) // hard %4d\n\
\n\
  Index:\n\
      disk read        %3d (%7ldB %6.1fKB) // hard %4d\n\
      bulk disk read   %3d (%7ldB %6.1fKB) // hard %4d\n\
\n",
        nfrag_obj, (long)nfrag_obj*require_frag_size,
            fdK(nfrag_obj*require_frag_size), HARD_NFRAG_OBJ,
        nfrag_nwrite, (long)nfrag_nwrite*require_frag_size, 
            fdK(nfrag_nwrite*require_frag_size), HARD_NFRAG_NWRITE,
        nfrag_nread, (long)nfrag_nread*require_frag_size, 
            fdK(nfrag_nread*require_frag_size), HARD_NFRAG_NREAD,
        nfrag_dwrite, (long)nfrag_dwrite*require_frag_size, 
            fdK(nfrag_dwrite*require_frag_size), HARD_NFRAG_DWRITE,
        nfrag_dread, (long)nfrag_dread*require_frag_size, 
            fdK(nfrag_dread*require_frag_size), HARD_NFRAG_DREAD,

        nindex_dread, (long)(ESIZE*nindex_dread),
            fdK(ESIZE*nindex_dread), HARD_NINDEX_DREAD,
        nindex_bdread, (long)(ESIZE*nindex_bdread),
            fdK(ESIZE*nindex_bdread), HARD_NINDEX_BDREAD
    );

#endif

#if 1
    Trace(
"\n\
Timeout:\n\
    SESSION_TOTAL_TIMEOUT   %4d\n\
    RECEPT_TIMEOUT          %4d\n\
    SEND_TIMEOUT            %4d\n\
    FETCH_TIMEOUT           %4d\n\
    WFRIEND_TIMEOUT         %4d\n\
    ELSE_TIMEOUT            %4d\n\
\n",
    SESSION_TOTAL_TIMEOUT, RECEPT_TIMEOUT, SEND_TIMEOUT,
    FETCH_TIMEOUT, WFRIEND_TIMEOUT, ELSE_TIMEOUT);
#endif

#if 1
    Trace("\n\
  bucket have %dentries and is splitted by h2(%d)\n\
    it means %dentiries per file\n\
  swapper have %dbuckets\n\
    it means %dfiles per swapper\n\
",
        nentry_bucket, radix_h2, nentry_bucket/radix_h2,
        (radix_h1+MAX(radix_disk, 1)-1)/MAX(radix_disk, 1),
        (radix_h1+MAX(radix_disk, 1)-1)/MAX(radix_disk, 1)*radix_h2
    );
    
#endif

#if 0
    {
        struct timeval now;
        gettimeofday(&now, NULL);
        client_scramble_key = now.tv_usec;
    }
#endif
#if 1
        client_scramble_key = 0xabba;
#endif


#if 1
    ShowParent();
#endif


#if 1
    if(require_n_msweeper>1) {
        wake_traces();
        Trace("\n\n-=-=-\nmemory sweeper is obsoluted parameter.\n");
        exit(0);
    }
#endif



    /***
     *** Thread launching
     ***/
    msleep(100);

    setup_thread_attrs();
/*
*/


#ifdef DISK_BENCH
    monitor_flag = 0;
#endif


    chk = pthread_create(&th_listener, p_th_attr_high,
                Listener, (void*)&listen_fd);
    n_listener++;


    /* boot monitor */
    if(monitor_flag) {
        chk = pthread_create(&th_monitor, p_th_attr_mid,
                Monitor, NULL);
#ifdef TRACE_THREADS
        Trace("launch - monitor %d\n", chk);
#endif
        n_monitors++;
    }


    /* clear gate for calling reaper() */
    for(i=0;i<radix_h1;i++) {
        reaper_gate[i] = -1;
    }

    /* boot handlers */
    for(i=0;i<require_n_handler;i++) {
        handler_beacon[i] = boot_date;
        chk = pthread_create(&th_handlers[i], p_th_attr_mid,
                Handler, (void*)i);
        if(chk) {
            Error("main: fail boot %d th handler", i);
        }
        else {
            n_handlers++;
        }
    }

    /* boot disk sweeper*/
    for(i=0;i<require_n_dsweeper;i++) {
        chk = pthread_create(&th_dsweepers[i], p_th_attr_low,
                DSweeper, (void*)i);
        if(chk) {
            Error("main: fail boot %d th background swapper", i);
        }
        else {
            n_dsweepers++;
        }
    }

    /* boot swapper */
    for(i=0;i<MAX(radix_disk,1)*swfactor;i++) 
    {
        for(j=0;j<6;j++) {
            swap_op_th_count[i][j] = 0LL;
        }
        swap_op_repush_th_count[i]  = 0LL;
        swap_op_release_th_count[i] = 0LL;
        swap_op_retry_th_count[i]   = 0LL;

        sim_hist_alloc_new(&swapper_swo_hist[i], "swapper swapout history",
            SWO_HISTLEN,  swapper_swo_hist_area[i]);
        sim_hist_alloc_new(&swapper_swi_hist[i], "swapper swapin history",
            SWI_HISTLEN,  swapper_swi_hist_area[i]);

        swapper_focus_bk[i] = -132;
        swapper_focus_oid[i] = -431;
        swapper_phase[i] = -719;

        chk = pthread_create(&th_swapper[i], p_th_attr_mid, Swapper, (void*)i);
        if(chk) {
            Error("main: fail boot %d th swapper", i);
        }
        else {
#if 0
            Trace("main: boot %d/%d <%d>\n", i, k, require_n_handler);
#endif
            n_swappers++;
        }
    }

    for(j=0;j<6;j++) {
        swap_op_all_count[j] = 0LL;
    }

    Trace("\nbooted threads (swfactor %d)\n\
    HTTP:   listener %d, heandler %d\n\
    disk:   dsweeper %d, swapper %d\n\
    others: monitor %d\n",
        swfactor,
        n_listener, n_handlers,
        n_dsweepers, n_swappers,
        n_monitors);


    wake_traces();

    MUTEX_LOCK(&stat_lock);
    service_start_date = time(NULL);
    MUTEX_UNLOCK(&stat_lock);


    /***
     ***
     ***/
#if 0
    pthread_sigmask(SIG_BLOCK, &handler_sig_mask, NULL);
    pthread_create(&th_signalhandler, p_th_attr_low, signal_watcher, NULL);
    pthread_sigmask(SIG_UNBLOCK, &handler_sig_mask, NULL);
#endif

    atexit(LogSync);


    MUTEX_LOCK(&stat_lock);
    Trace("initalize take %d sec(s)\n", time(NULL) - boot_date);
    MUTEX_UNLOCK(&stat_lock);

#ifdef DISK_BENCH
    chk = pthread_create(&th_monitor, p_th_attr_mid,
            DiskJudge, NULL);
#endif


    /***
     *** forever loop
     ***/
    msleep(100);

    /* for child reaping, this thread should be awake at sometime */
    while(1) {
        sleep(300);
    }
}

